XrEye

Enum XrEye 

#[non_exhaustive]
pub enum XrEye { None = 0, Left = 1, Right = 2, }
The XrEye enum.

This API requires the following crate features to be activated: XrEye

This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as described in the wasm-bindgen guide

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


None = 0



Left = 1



Right = 2

Implementations