pub struct AddEventListenerOptions { /* private fields */ }Expand description
The AddEventListenerOptions dictionary.
This API requires the following crate features to be activated: AddEventListenerOptions
Implementations
Sourceimpl AddEventListenerOptions
impl AddEventListenerOptions
pub fn get_capture(&self) -> Option<bool>
Sourceimpl AddEventListenerOptions
impl AddEventListenerOptions
pub fn set_capture(&self, val: bool)
Sourceimpl AddEventListenerOptions
impl AddEventListenerOptions
pub fn get_passive(&self) -> Option<bool>
Sourceimpl AddEventListenerOptions
impl AddEventListenerOptions
pub fn set_passive(&self, val: bool)
Sourceimpl AddEventListenerOptions
impl AddEventListenerOptions
pub fn get_signal(&self) -> Option<AbortSignal>
Sourceimpl AddEventListenerOptions
impl AddEventListenerOptions
pub fn set_signal(&self, val: &AbortSignal)
Sourceimpl AddEventListenerOptions
impl AddEventListenerOptions
Sourcepub fn new() -> Self
pub fn new() -> Self
Construct a new AddEventListenerOptions.
This API requires the following crate features to be activated: AddEventListenerOptions
pub fn capture(&mut self, val: bool) -> &mut Self
Use set_capture() instead.
pub fn once(&mut self, val: bool) -> &mut Self
Use set_once() instead.
pub fn passive(&mut self, val: bool) -> &mut Self
Use set_passive() instead.
pub fn signal(&mut self, val: &AbortSignal) -> &mut Self
Use set_signal() instead.
Methods from Deref<Target = Object>
pub fn constructor(&self) -> Function
pub fn has_own_property(&self, property: &JsValue) -> bool
Use Object::hasOwn instead.
pub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn to_locale_string(&self) -> JsString
pub fn to_string(&self) -> JsString
pub fn to_js_string(&self) -> JsString
pub fn value_of(&self) -> Object
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Check if this value is null or undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.