pub struct CssRule { /* private fields */ }Expand description
The CssRule class.
This API requires the following crate features to be activated: CssRule
Implementations
Sourceimpl CssRule
impl CssRule
pub fn parent_style_sheet(&self) -> Option<CssStyleSheet>
Sourceimpl CssRule
impl CssRule
Sourcepub const STYLE_RULE: u16
pub const STYLE_RULE: u16
The CSSRule.STYLE_RULE const.
This API requires the following crate features to be activated: CssRule
Sourcepub const CHARSET_RULE: u16
pub const CHARSET_RULE: u16
The CSSRule.CHARSET_RULE const.
This API requires the following crate features to be activated: CssRule
Sourcepub const IMPORT_RULE: u16
pub const IMPORT_RULE: u16
The CSSRule.IMPORT_RULE const.
This API requires the following crate features to be activated: CssRule
Sourcepub const MEDIA_RULE: u16
pub const MEDIA_RULE: u16
The CSSRule.MEDIA_RULE const.
This API requires the following crate features to be activated: CssRule
Sourcepub const FONT_FACE_RULE: u16
pub const FONT_FACE_RULE: u16
The CSSRule.FONT_FACE_RULE const.
This API requires the following crate features to be activated: CssRule
Sourcepub const PAGE_RULE: u16
pub const PAGE_RULE: u16
The CSSRule.PAGE_RULE const.
This API requires the following crate features to be activated: CssRule
Sourcepub const NAMESPACE_RULE: u16
pub const NAMESPACE_RULE: u16
The CSSRule.NAMESPACE_RULE const.
This API requires the following crate features to be activated: CssRule
Sourcepub const KEYFRAMES_RULE: u16
pub const KEYFRAMES_RULE: u16
The CSSRule.KEYFRAMES_RULE const.
This API requires the following crate features to be activated: CssRule
Sourcepub const KEYFRAME_RULE: u16
pub const KEYFRAME_RULE: u16
The CSSRule.KEYFRAME_RULE const.
This API requires the following crate features to be activated: CssRule
Sourcepub const COUNTER_STYLE_RULE: u16
pub const COUNTER_STYLE_RULE: u16
The CSSRule.COUNTER_STYLE_RULE const.
This API requires the following crate features to be activated: CssRule
Sourcepub const SUPPORTS_RULE: u16
pub const SUPPORTS_RULE: u16
The CSSRule.SUPPORTS_RULE const.
This API requires the following crate features to be activated: CssRule
Sourcepub const FONT_FEATURE_VALUES_RULE: u16
pub const FONT_FEATURE_VALUES_RULE: u16
The CSSRule.FONT_FEATURE_VALUES_RULE const.
This API requires the following crate features to be activated: CssRule
Methods from Deref<Target = Object>
pub fn constructor(&self) -> Function
pub fn has_own_property(&self, property: &JsValue) -> bool
Use Object::hasOwn instead.
pub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn to_locale_string(&self) -> JsString
pub fn to_string(&self) -> JsString
pub fn to_js_string(&self) -> JsString
pub fn value_of(&self) -> Object
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Check if this value is null or undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.