pub struct CustomEventInit { /* private fields */ }Expand description
The CustomEventInit dictionary.
This API requires the following crate features to be activated: CustomEventInit
Implementations
Sourceimpl CustomEventInit
impl CustomEventInit
pub fn get_bubbles(&self) -> Option<bool>
Sourceimpl CustomEventInit
impl CustomEventInit
pub fn set_bubbles(&self, val: bool)
Sourceimpl CustomEventInit
impl CustomEventInit
pub fn get_cancelable(&self) -> Option<bool>
Sourceimpl CustomEventInit
impl CustomEventInit
pub fn set_cancelable(&self, val: bool)
Sourceimpl CustomEventInit
impl CustomEventInit
pub fn get_composed(&self) -> Option<bool>
Sourceimpl CustomEventInit
impl CustomEventInit
pub fn set_composed(&self, val: bool)
Sourceimpl CustomEventInit
impl CustomEventInit
pub fn get_detail(&self) -> JsValue
Sourceimpl CustomEventInit
impl CustomEventInit
pub fn set_detail(&self, val: &JsValue)
Sourceimpl CustomEventInit
impl CustomEventInit
Sourcepub fn new() -> Self
pub fn new() -> Self
Construct a new CustomEventInit.
This API requires the following crate features to be activated: CustomEventInit
pub fn bubbles(&mut self, val: bool) -> &mut Self
Use set_bubbles() instead.
pub fn cancelable(&mut self, val: bool) -> &mut Self
Use set_cancelable() instead.
pub fn composed(&mut self, val: bool) -> &mut Self
Use set_composed() instead.
pub fn detail(&mut self, val: &JsValue) -> &mut Self
Use set_detail() instead.
Methods from Deref<Target = Object>
pub fn constructor(&self) -> Function
pub fn has_own_property(&self, property: &JsValue) -> bool
Use Object::hasOwn instead.
pub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn to_locale_string(&self) -> JsString
pub fn to_string(&self) -> JsString
pub fn to_js_string(&self) -> JsString
pub fn value_of(&self) -> Object
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Check if this value is null or undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.