pub struct DomException { /* private fields */ }Expand description
The DomException class.
This API requires the following crate features to be activated: DomException
Implementations
Sourceimpl DomException
impl DomException
pub fn line_number(&self) -> u32
Sourceimpl DomException
impl DomException
pub fn column_number(&self) -> u32
Sourceimpl DomException
impl DomException
pub fn new() -> Result<DomException, JsValue>
Sourceimpl DomException
impl DomException
pub fn new_with_message(message: &str) -> Result<DomException, JsValue>
Sourceimpl DomException
impl DomException
pub fn new_with_message_and_name( message: &str, name: &str, ) -> Result<DomException, JsValue>
Sourceimpl DomException
impl DomException
Sourcepub const INDEX_SIZE_ERR: u16
pub const INDEX_SIZE_ERR: u16
The DOMException.INDEX_SIZE_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const DOMSTRING_SIZE_ERR: u16
pub const DOMSTRING_SIZE_ERR: u16
The DOMException.DOMSTRING_SIZE_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const HIERARCHY_REQUEST_ERR: u16
pub const HIERARCHY_REQUEST_ERR: u16
The DOMException.HIERARCHY_REQUEST_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const WRONG_DOCUMENT_ERR: u16
pub const WRONG_DOCUMENT_ERR: u16
The DOMException.WRONG_DOCUMENT_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const INVALID_CHARACTER_ERR: u16
pub const INVALID_CHARACTER_ERR: u16
The DOMException.INVALID_CHARACTER_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const NO_DATA_ALLOWED_ERR: u16
pub const NO_DATA_ALLOWED_ERR: u16
The DOMException.NO_DATA_ALLOWED_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const NO_MODIFICATION_ALLOWED_ERR: u16
pub const NO_MODIFICATION_ALLOWED_ERR: u16
The DOMException.NO_MODIFICATION_ALLOWED_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const NOT_FOUND_ERR: u16
pub const NOT_FOUND_ERR: u16
The DOMException.NOT_FOUND_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const NOT_SUPPORTED_ERR: u16
pub const NOT_SUPPORTED_ERR: u16
The DOMException.NOT_SUPPORTED_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const INUSE_ATTRIBUTE_ERR: u16
pub const INUSE_ATTRIBUTE_ERR: u16
The DOMException.INUSE_ATTRIBUTE_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const INVALID_STATE_ERR: u16
pub const INVALID_STATE_ERR: u16
The DOMException.INVALID_STATE_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const SYNTAX_ERR: u16
pub const SYNTAX_ERR: u16
The DOMException.SYNTAX_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const INVALID_MODIFICATION_ERR: u16
pub const INVALID_MODIFICATION_ERR: u16
The DOMException.INVALID_MODIFICATION_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const NAMESPACE_ERR: u16
pub const NAMESPACE_ERR: u16
The DOMException.NAMESPACE_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const INVALID_ACCESS_ERR: u16
pub const INVALID_ACCESS_ERR: u16
The DOMException.INVALID_ACCESS_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const VALIDATION_ERR: u16
pub const VALIDATION_ERR: u16
The DOMException.VALIDATION_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const TYPE_MISMATCH_ERR: u16
pub const TYPE_MISMATCH_ERR: u16
The DOMException.TYPE_MISMATCH_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const SECURITY_ERR: u16
pub const SECURITY_ERR: u16
The DOMException.SECURITY_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const NETWORK_ERR: u16
pub const NETWORK_ERR: u16
The DOMException.NETWORK_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const ABORT_ERR: u16
pub const ABORT_ERR: u16
The DOMException.ABORT_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const URL_MISMATCH_ERR: u16
pub const URL_MISMATCH_ERR: u16
The DOMException.URL_MISMATCH_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const QUOTA_EXCEEDED_ERR: u16
pub const QUOTA_EXCEEDED_ERR: u16
The DOMException.QUOTA_EXCEEDED_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const TIMEOUT_ERR: u16
pub const TIMEOUT_ERR: u16
The DOMException.TIMEOUT_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const INVALID_NODE_TYPE_ERR: u16
pub const INVALID_NODE_TYPE_ERR: u16
The DOMException.INVALID_NODE_TYPE_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const DATA_CLONE_ERR: u16
pub const DATA_CLONE_ERR: u16
The DOMException.DATA_CLONE_ERR const.
This API requires the following crate features to be activated: DomException
Methods from Deref<Target = Object>
pub fn constructor(&self) -> Function
pub fn has_own_property(&self, property: &JsValue) -> bool
Use Object::hasOwn instead.
pub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn to_locale_string(&self) -> JsString
pub fn to_string(&self) -> JsString
pub fn to_js_string(&self) -> JsString
pub fn value_of(&self) -> Object
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Check if this value is null or undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.