Event

Struct Event 

pub struct Event { /* private fields */ }
The Event class.

MDN Documentation

This API requires the following crate features to be activated: Event

Implementations

Source

impl Event

pub fn type_(&self) -> String

Source

impl Event

pub fn target(&self) -> Option<EventTarget>

Source

impl Event

Source

impl Event

pub fn event_phase(&self) -> u16

Source

impl Event

pub fn bubbles(&self) -> bool

Source

impl Event

pub fn cancelable(&self) -> bool

Source

impl Event

pub fn default_prevented(&self) -> bool

Source

impl Event

pub fn composed(&self) -> bool

Source

impl Event

pub fn is_trusted(&self) -> bool

Source

impl Event

pub fn time_stamp(&self) -> f64

Source

impl Event

pub fn cancel_bubble(&self) -> bool

Source

impl Event

pub fn set_cancel_bubble(&self, value: bool)

Source

impl Event

pub fn new(type_: &str) -> Result<Event, JsValue>

Source

impl Event

pub fn new_with_event_init_dict( type_: &str, event_init_dict: &EventInit, ) -> Result<Event, JsValue>

Source

impl Event

pub fn composed_path(&self) -> Array

Source

impl Event

pub fn init_event(&self, type_: &str)

Source

impl Event

pub fn init_event_with_bubbles(&self, type_: &str, bubbles: bool)

Source

impl Event

pub fn init_event_with_bubbles_and_cancelable( &self, type_: &str, bubbles: bool, cancelable: bool, )

Source

impl Event

pub fn prevent_default(&self)

Source

impl Event

Source

impl Event

Source

impl Event

pub const NONE: u16

The Event.NONE const.

This API requires the following crate features to be activated: Event

pub const CAPTURING_PHASE: u16

The Event.CAPTURING_PHASE const.

This API requires the following crate features to be activated: Event

pub const AT_TARGET: u16

The Event.AT_TARGET const.

This API requires the following crate features to be activated: Event

pub const BUBBLING_PHASE: u16

The Event.BUBBLING_PHASE const.

This API requires the following crate features to be activated: Event

Methods from Deref<Target = Object>

pub fn constructor(&self) -> Function

pub fn has_own_property(&self, property: &JsValue) -> bool

👎Deprecated:

Use Object::hasOwn instead.

pub fn is_prototype_of(&self, value: &JsValue) -> bool

pub fn property_is_enumerable(&self, property: &JsValue) -> bool

pub fn to_locale_string(&self) -> JsString

pub fn to_string(&self) -> JsString

pub fn to_js_string(&self) -> JsString

pub fn value_of(&self) -> Object

Methods from Deref<Target = JsValue>

pub const NULL: JsValue

pub const UNDEFINED: JsValue

pub const TRUE: JsValue

pub const FALSE: JsValue

pub fn unchecked_into_f64(&self) -> f64

Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.

pub fn has_type<T>(&self) -> bool
where T: JsCast,

Check if this value is an instance of a specific JS type.

pub fn checked_div(&self, rhs: &JsValue) -> JsValue

Checked division.

pub fn pow(&self, rhs: &JsValue) -> JsValue

Power operation.

pub fn bit_and(&self, rhs: &JsValue) -> JsValue

Bitwise AND.

pub fn bit_or(&self, rhs: &JsValue) -> JsValue

Bitwise OR.

pub fn bit_xor(&self, rhs: &JsValue) -> JsValue

Bitwise XOR.

pub fn bit_not(&self) -> JsValue

Bitwise NOT.

pub fn shl(&self, rhs: &JsValue) -> JsValue

Left shift.

pub fn shr(&self, rhs: &JsValue) -> JsValue

Signed right shift.

pub fn unsigned_shr(&self, rhs: &JsValue) -> u32

Unsigned right shift.

pub fn add(&self, rhs: &JsValue) -> JsValue

Add.

pub fn sub(&self, rhs: &JsValue) -> JsValue

Subtract.

pub fn mul(&self, rhs: &JsValue) -> JsValue

Multiply.

pub fn div(&self, rhs: &JsValue) -> JsValue

Divide.

pub fn rem(&self, rhs: &JsValue) -> JsValue

Remainder.

pub fn neg(&self) -> JsValue

Negate.

pub fn lt(&self, other: &JsValue) -> bool

Less than comparison.

pub fn le(&self, other: &JsValue) -> bool

Less than or equal comparison.

pub fn gt(&self, other: &JsValue) -> bool

Greater than comparison.

pub fn ge(&self, other: &JsValue) -> bool

Greater than or equal comparison.

pub fn loose_eq(&self, other: &JsValue) -> bool

Loose equality (==).

pub fn is_falsy(&self) -> bool

Check if this value is a falsy value in JavaScript.

pub fn is_truthy(&self) -> bool

Check if this value is a truthy value in JavaScript.

pub fn is_object(&self) -> bool

Check if this value is an object.

pub fn is_function(&self) -> bool

Check if this value is a function.

pub fn is_string(&self) -> bool

Check if this value is a string.

pub fn is_symbol(&self) -> bool

Check if this value is a symbol.

pub fn is_bigint(&self) -> bool

Check if this value is a bigint.

pub fn is_array(&self) -> bool

Check if this value is an Array.

pub fn is_undefined(&self) -> bool

Check if this value is undefined.

pub fn is_null(&self) -> bool

Check if this value is null.

pub fn is_null_or_undefined(&self) -> bool

Check if this value is null or undefined.

pub fn js_typeof(&self) -> JsValue

Get the typeof this value as a string.

pub fn js_in(&self, obj: &JsValue) -> bool

Check if this value has a property with the given name.

pub fn as_bool(&self) -> Option<bool>

Get the value as a bool.

pub fn as_f64(&self) -> Option<f64>

Get the value as an f64.

pub fn as_string(&self) -> Option<String>

Get the value as a string.

pub fn as_debug_string(&self) -> String

Get a debug string representation of the value.