pub struct File { /* private fields */ }Expand description
The File class.
This API requires the following crate features to be activated: File
Implementations
Sourceimpl File
impl File
pub fn new_with_buffer_source_sequence_and_options( file_bits: &JsValue, file_name: &str, options: &FilePropertyBag, ) -> Result<File, JsValue>
Sourceimpl File
impl File
pub fn new_with_u8_slice_sequence_and_options( file_bits: &JsValue, file_name: &str, options: &FilePropertyBag, ) -> Result<File, JsValue>
Sourceimpl File
impl File
pub fn new_with_u8_array_sequence_and_options( file_bits: &JsValue, file_name: &str, options: &FilePropertyBag, ) -> Result<File, JsValue>
Methods from Deref<Target = Blob>
pub fn size(&self) -> f64
pub fn type_(&self) -> String
pub fn array_buffer(&self) -> Promise
pub fn bytes(&self) -> Promise
pub fn slice(&self) -> Result<Blob, JsValue>
pub fn slice_with_i32(&self, start: i32) -> Result<Blob, JsValue>
pub fn slice_with_f64(&self, start: f64) -> Result<Blob, JsValue>
pub fn slice_with_i32_and_i32( &self, start: i32, end: i32, ) -> Result<Blob, JsValue>
pub fn slice_with_f64_and_i32( &self, start: f64, end: i32, ) -> Result<Blob, JsValue>
pub fn slice_with_i32_and_f64( &self, start: i32, end: f64, ) -> Result<Blob, JsValue>
pub fn slice_with_f64_and_f64( &self, start: f64, end: f64, ) -> Result<Blob, JsValue>
pub fn slice_with_i32_and_i32_and_content_type( &self, start: i32, end: i32, content_type: &str, ) -> Result<Blob, JsValue>
pub fn slice_with_f64_and_i32_and_content_type( &self, start: f64, end: i32, content_type: &str, ) -> Result<Blob, JsValue>
pub fn slice_with_i32_and_f64_and_content_type( &self, start: i32, end: f64, content_type: &str, ) -> Result<Blob, JsValue>
pub fn slice_with_f64_and_f64_and_content_type( &self, start: f64, end: f64, content_type: &str, ) -> Result<Blob, JsValue>
pub fn stream(&self) -> ReadableStream
pub fn text(&self) -> Promise
Methods from Deref<Target = Object>
pub fn constructor(&self) -> Function
pub fn has_own_property(&self, property: &JsValue) -> bool
👎Deprecated:
Use Object::hasOwn instead.
pub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn to_locale_string(&self) -> JsString
pub fn to_string(&self) -> JsString
pub fn to_js_string(&self) -> JsString
pub fn value_of(&self) -> Object
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Check if this value is null or undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.