Struct web_sys::GpuRenderBundleEncoder
source · [−]#[repr(transparent)]pub struct GpuRenderBundleEncoder { /* private fields */ }Expand description
The GpuRenderBundleEncoder class.
This API requires the following crate features to be activated: GpuRenderBundleEncoder
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Implementations
Getter for the label field of this object.
This API requires the following crate features to be activated: GpuRenderBundleEncoder
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Setter for the label field of this object.
This API requires the following crate features to be activated: GpuRenderBundleEncoder
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
The finish() method.
This API requires the following crate features to be activated: GpuRenderBundle, GpuRenderBundleEncoder
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
pub fn finish_with_descriptor(
&self,
descriptor: &GpuRenderBundleDescriptor
) -> GpuRenderBundle
pub fn finish_with_descriptor(
&self,
descriptor: &GpuRenderBundleDescriptor
) -> GpuRenderBundle
The finish() method.
This API requires the following crate features to be activated: GpuRenderBundle, GpuRenderBundleDescriptor, GpuRenderBundleEncoder
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
The insertDebugMarker() method.
This API requires the following crate features to be activated: GpuRenderBundleEncoder
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
The popDebugGroup() method.
This API requires the following crate features to be activated: GpuRenderBundleEncoder
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
The pushDebugGroup() method.
This API requires the following crate features to be activated: GpuRenderBundleEncoder
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
The setBindGroup() method.
This API requires the following crate features to be activated: GpuBindGroup, GpuRenderBundleEncoder
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
pub fn set_bind_group_with_u32_sequence(
&self,
index: u32,
bind_group: &GpuBindGroup,
dynamic_offsets: &JsValue
)
pub fn set_bind_group_with_u32_sequence(
&self,
index: u32,
bind_group: &GpuBindGroup,
dynamic_offsets: &JsValue
)
The setBindGroup() method.
This API requires the following crate features to be activated: GpuBindGroup, GpuRenderBundleEncoder
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
pub fn set_bind_group_with_u32_array_and_u32_and_dynamic_offsets_data_length(
&self,
index: u32,
bind_group: &GpuBindGroup,
dynamic_offsets_data: &[u32],
dynamic_offsets_data_start: u32,
dynamic_offsets_data_length: u32
)
pub fn set_bind_group_with_u32_array_and_u32_and_dynamic_offsets_data_length(
&self,
index: u32,
bind_group: &GpuBindGroup,
dynamic_offsets_data: &[u32],
dynamic_offsets_data_start: u32,
dynamic_offsets_data_length: u32
)
The setBindGroup() method.
This API requires the following crate features to be activated: GpuBindGroup, GpuRenderBundleEncoder
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
pub fn set_bind_group_with_u32_array_and_f64_and_dynamic_offsets_data_length(
&self,
index: u32,
bind_group: &GpuBindGroup,
dynamic_offsets_data: &[u32],
dynamic_offsets_data_start: f64,
dynamic_offsets_data_length: u32
)
pub fn set_bind_group_with_u32_array_and_f64_and_dynamic_offsets_data_length(
&self,
index: u32,
bind_group: &GpuBindGroup,
dynamic_offsets_data: &[u32],
dynamic_offsets_data_start: f64,
dynamic_offsets_data_length: u32
)
The setBindGroup() method.
This API requires the following crate features to be activated: GpuBindGroup, GpuRenderBundleEncoder
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
The draw() method.
This API requires the following crate features to be activated: GpuRenderBundleEncoder
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
The draw() method.
This API requires the following crate features to be activated: GpuRenderBundleEncoder
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
pub fn draw_with_instance_count_and_first_vertex(
&self,
vertex_count: u32,
instance_count: u32,
first_vertex: u32
)
pub fn draw_with_instance_count_and_first_vertex(
&self,
vertex_count: u32,
instance_count: u32,
first_vertex: u32
)
The draw() method.
This API requires the following crate features to be activated: GpuRenderBundleEncoder
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
The draw() method.
This API requires the following crate features to be activated: GpuRenderBundleEncoder
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
The drawIndexed() method.
This API requires the following crate features to be activated: GpuRenderBundleEncoder
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
The drawIndexed() method.
This API requires the following crate features to be activated: GpuRenderBundleEncoder
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
pub fn draw_indexed_with_instance_count_and_first_index(
&self,
index_count: u32,
instance_count: u32,
first_index: u32
)
pub fn draw_indexed_with_instance_count_and_first_index(
&self,
index_count: u32,
instance_count: u32,
first_index: u32
)
The drawIndexed() method.
This API requires the following crate features to be activated: GpuRenderBundleEncoder
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
The drawIndexed() method.
This API requires the following crate features to be activated: GpuRenderBundleEncoder
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
The drawIndexed() method.
This API requires the following crate features to be activated: GpuRenderBundleEncoder
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
pub fn draw_indexed_indirect_with_u32(
&self,
indirect_buffer: &GpuBuffer,
indirect_offset: u32
)
pub fn draw_indexed_indirect_with_u32(
&self,
indirect_buffer: &GpuBuffer,
indirect_offset: u32
)
The drawIndexedIndirect() method.
This API requires the following crate features to be activated: GpuBuffer, GpuRenderBundleEncoder
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
pub fn draw_indexed_indirect_with_f64(
&self,
indirect_buffer: &GpuBuffer,
indirect_offset: f64
)
pub fn draw_indexed_indirect_with_f64(
&self,
indirect_buffer: &GpuBuffer,
indirect_offset: f64
)
The drawIndexedIndirect() method.
This API requires the following crate features to be activated: GpuBuffer, GpuRenderBundleEncoder
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
The drawIndirect() method.
This API requires the following crate features to be activated: GpuBuffer, GpuRenderBundleEncoder
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
The drawIndirect() method.
This API requires the following crate features to be activated: GpuBuffer, GpuRenderBundleEncoder
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
The setIndexBuffer() method.
This API requires the following crate features to be activated: GpuBuffer, GpuIndexFormat, GpuRenderBundleEncoder
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
pub fn set_index_buffer_with_u32(
&self,
buffer: &GpuBuffer,
index_format: GpuIndexFormat,
offset: u32
)
pub fn set_index_buffer_with_u32(
&self,
buffer: &GpuBuffer,
index_format: GpuIndexFormat,
offset: u32
)
The setIndexBuffer() method.
This API requires the following crate features to be activated: GpuBuffer, GpuIndexFormat, GpuRenderBundleEncoder
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
pub fn set_index_buffer_with_f64(
&self,
buffer: &GpuBuffer,
index_format: GpuIndexFormat,
offset: f64
)
pub fn set_index_buffer_with_f64(
&self,
buffer: &GpuBuffer,
index_format: GpuIndexFormat,
offset: f64
)
The setIndexBuffer() method.
This API requires the following crate features to be activated: GpuBuffer, GpuIndexFormat, GpuRenderBundleEncoder
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
pub fn set_index_buffer_with_u32_and_u32(
&self,
buffer: &GpuBuffer,
index_format: GpuIndexFormat,
offset: u32,
size: u32
)
pub fn set_index_buffer_with_u32_and_u32(
&self,
buffer: &GpuBuffer,
index_format: GpuIndexFormat,
offset: u32,
size: u32
)
The setIndexBuffer() method.
This API requires the following crate features to be activated: GpuBuffer, GpuIndexFormat, GpuRenderBundleEncoder
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
pub fn set_index_buffer_with_f64_and_u32(
&self,
buffer: &GpuBuffer,
index_format: GpuIndexFormat,
offset: f64,
size: u32
)
pub fn set_index_buffer_with_f64_and_u32(
&self,
buffer: &GpuBuffer,
index_format: GpuIndexFormat,
offset: f64,
size: u32
)
The setIndexBuffer() method.
This API requires the following crate features to be activated: GpuBuffer, GpuIndexFormat, GpuRenderBundleEncoder
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
pub fn set_index_buffer_with_u32_and_f64(
&self,
buffer: &GpuBuffer,
index_format: GpuIndexFormat,
offset: u32,
size: f64
)
pub fn set_index_buffer_with_u32_and_f64(
&self,
buffer: &GpuBuffer,
index_format: GpuIndexFormat,
offset: u32,
size: f64
)
The setIndexBuffer() method.
This API requires the following crate features to be activated: GpuBuffer, GpuIndexFormat, GpuRenderBundleEncoder
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
pub fn set_index_buffer_with_f64_and_f64(
&self,
buffer: &GpuBuffer,
index_format: GpuIndexFormat,
offset: f64,
size: f64
)
pub fn set_index_buffer_with_f64_and_f64(
&self,
buffer: &GpuBuffer,
index_format: GpuIndexFormat,
offset: f64,
size: f64
)
The setIndexBuffer() method.
This API requires the following crate features to be activated: GpuBuffer, GpuIndexFormat, GpuRenderBundleEncoder
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
The setPipeline() method.
This API requires the following crate features to be activated: GpuRenderBundleEncoder, GpuRenderPipeline
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
The setVertexBuffer() method.
This API requires the following crate features to be activated: GpuBuffer, GpuRenderBundleEncoder
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
The setVertexBuffer() method.
This API requires the following crate features to be activated: GpuBuffer, GpuRenderBundleEncoder
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
The setVertexBuffer() method.
This API requires the following crate features to be activated: GpuBuffer, GpuRenderBundleEncoder
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
The setVertexBuffer() method.
This API requires the following crate features to be activated: GpuBuffer, GpuRenderBundleEncoder
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
The setVertexBuffer() method.
This API requires the following crate features to be activated: GpuBuffer, GpuRenderBundleEncoder
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
The setVertexBuffer() method.
This API requires the following crate features to be activated: GpuBuffer, GpuRenderBundleEncoder
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
The setVertexBuffer() method.
This API requires the following crate features to be activated: GpuBuffer, GpuRenderBundleEncoder
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Methods from Deref<Target = Object>
The constructor property returns a reference to the Object constructor
function that created the instance object.
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
The toString() method returns a string representing the object.
The valueOf() method returns the primitive value of the
specified object.
Methods from Deref<Target = JsValue>
Returns the f64 value of this JS value if it’s an instance of a
number.
If this JS value is not an instance of a number then this returns
None.
If this JS value is a string value, this function copies the JS string
value into wasm linear memory, encoded as UTF-8, and returns it as a
Rust String.
To avoid the copying and re-encoding, consider the
JsString::try_from() function from js-sys
instead.
If this JS value is not an instance of a string or if it’s not valid
utf-8 then this returns None.
UTF-16 vs UTF-8
JavaScript strings in general are encoded as UTF-16, but Rust strings
are encoded as UTF-8. This can cause the Rust string to look a bit
different than the JS string sometimes. For more details see the
documentation about the str type which contains a few
caveats about the encodings.
Returns the bool value of this JS value if it’s an instance of a
boolean.
If this JS value is not an instance of a boolean then this returns
None.
Tests whether this JS value is undefined
Tests whether the type of this JS value is function.
Applies the unary typeof JS operator on a JsValue.
Applies the binary in JS operator on the two JsValues.
Compare two JsValues for equality, using the == operator in JS.
Applies the unary ~ JS operator on a JsValue.
Applies the binary >>> JS operator on the two JsValues.
Applies the binary / JS operator on two JsValues, catching and returning any RangeError thrown.
Applies the binary ** JS operator on the two JsValues.
Applies the binary < JS operator on the two JsValues.
Applies the binary <= JS operator on the two JsValues.
Applies the binary >= JS operator on the two JsValues.
Applies the binary > JS operator on the two JsValues.
Applies the unary + JS operator on a JsValue. Can throw.