pub struct HashChangeEvent { /* private fields */ }Expand description
The HashChangeEvent class.
This API requires the following crate features to be activated: HashChangeEvent
Implementations
Sourceimpl HashChangeEvent
impl HashChangeEvent
pub fn init_hash_change_event(&self, type_arg: &str)
Sourceimpl HashChangeEvent
impl HashChangeEvent
pub fn init_hash_change_event_with_can_bubble_arg( &self, type_arg: &str, can_bubble_arg: bool, )
Sourceimpl HashChangeEvent
impl HashChangeEvent
pub fn init_hash_change_event_with_can_bubble_arg_and_cancelable_arg( &self, type_arg: &str, can_bubble_arg: bool, cancelable_arg: bool, )
Methods from Deref<Target = Event>
pub fn type_(&self) -> String
pub fn target(&self) -> Option<EventTarget>
pub fn current_target(&self) -> Option<EventTarget>
pub fn event_phase(&self) -> u16
pub fn bubbles(&self) -> bool
pub fn cancelable(&self) -> bool
pub fn default_prevented(&self) -> bool
pub fn composed(&self) -> bool
pub fn is_trusted(&self) -> bool
pub fn time_stamp(&self) -> f64
pub fn cancel_bubble(&self) -> bool
pub fn set_cancel_bubble(&self, value: bool)
pub fn composed_path(&self) -> Array
pub fn init_event(&self, type_: &str)
pub fn init_event_with_bubbles(&self, type_: &str, bubbles: bool)
pub fn init_event_with_bubbles_and_cancelable( &self, type_: &str, bubbles: bool, cancelable: bool, )
pub fn prevent_default(&self)
pub fn stop_immediate_propagation(&self)
pub fn stop_propagation(&self)
pub const NONE: u16
pub const CAPTURING_PHASE: u16
pub const AT_TARGET: u16
pub const BUBBLING_PHASE: u16
Methods from Deref<Target = Object>
pub fn constructor(&self) -> Function
pub fn has_own_property(&self, property: &JsValue) -> bool
👎Deprecated:
Use Object::hasOwn instead.
pub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn to_locale_string(&self) -> JsString
pub fn to_string(&self) -> JsString
pub fn to_js_string(&self) -> JsString
pub fn value_of(&self) -> Object
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Check if this value is null or undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.