pub struct MouseEventInit { /* private fields */ }Expand description
The MouseEventInit dictionary.
This API requires the following crate features to be activated: MouseEventInit
Implementations
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn get_bubbles(&self) -> Option<bool>
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn set_bubbles(&self, val: bool)
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn get_cancelable(&self) -> Option<bool>
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn set_cancelable(&self, val: bool)
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn get_composed(&self) -> Option<bool>
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn set_composed(&self, val: bool)
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn get_detail(&self) -> Option<i32>
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn set_detail(&self, val: i32)
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn get_alt_key(&self) -> Option<bool>
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn set_alt_key(&self, val: bool)
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn get_ctrl_key(&self) -> Option<bool>
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn set_ctrl_key(&self, val: bool)
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn get_meta_key(&self) -> Option<bool>
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn set_meta_key(&self, val: bool)
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn get_modifier_alt_graph(&self) -> Option<bool>
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn set_modifier_alt_graph(&self, val: bool)
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn get_modifier_caps_lock(&self) -> Option<bool>
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn set_modifier_caps_lock(&self, val: bool)
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn get_modifier_fn(&self) -> Option<bool>
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn set_modifier_fn(&self, val: bool)
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn get_modifier_fn_lock(&self) -> Option<bool>
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn set_modifier_fn_lock(&self, val: bool)
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn get_modifier_num_lock(&self) -> Option<bool>
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn set_modifier_num_lock(&self, val: bool)
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn get_modifier_os(&self) -> Option<bool>
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn set_modifier_os(&self, val: bool)
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn get_modifier_scroll_lock(&self) -> Option<bool>
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn set_modifier_scroll_lock(&self, val: bool)
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn get_modifier_symbol(&self) -> Option<bool>
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn set_modifier_symbol(&self, val: bool)
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn get_modifier_symbol_lock(&self) -> Option<bool>
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn set_modifier_symbol_lock(&self, val: bool)
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn get_shift_key(&self) -> Option<bool>
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn set_shift_key(&self, val: bool)
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn get_client_x(&self) -> Option<i32>
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn set_client_x(&self, val: i32)
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn get_client_y(&self) -> Option<i32>
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn set_client_y(&self, val: i32)
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn get_movement_x(&self) -> Option<i32>
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn set_movement_x(&self, val: i32)
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn get_movement_y(&self) -> Option<i32>
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn set_movement_y(&self, val: i32)
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn get_screen_x(&self) -> Option<i32>
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn set_screen_x(&self, val: i32)
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn get_screen_y(&self) -> Option<i32>
Sourceimpl MouseEventInit
impl MouseEventInit
pub fn set_screen_y(&self, val: i32)
Sourceimpl MouseEventInit
impl MouseEventInit
Sourcepub fn new() -> Self
pub fn new() -> Self
Construct a new MouseEventInit.
This API requires the following crate features to be activated: MouseEventInit
pub fn bubbles(&mut self, val: bool) -> &mut Self
Use set_bubbles() instead.
pub fn cancelable(&mut self, val: bool) -> &mut Self
Use set_cancelable() instead.
pub fn composed(&mut self, val: bool) -> &mut Self
Use set_composed() instead.
pub fn detail(&mut self, val: i32) -> &mut Self
Use set_detail() instead.
pub fn view(&mut self, val: Option<&Window>) -> &mut Self
Use set_view() instead.
pub fn alt_key(&mut self, val: bool) -> &mut Self
Use set_alt_key() instead.
pub fn ctrl_key(&mut self, val: bool) -> &mut Self
Use set_ctrl_key() instead.
pub fn meta_key(&mut self, val: bool) -> &mut Self
Use set_meta_key() instead.
pub fn modifier_alt_graph(&mut self, val: bool) -> &mut Self
Use set_modifier_alt_graph() instead.
pub fn modifier_caps_lock(&mut self, val: bool) -> &mut Self
Use set_modifier_caps_lock() instead.
pub fn modifier_fn(&mut self, val: bool) -> &mut Self
Use set_modifier_fn() instead.
pub fn modifier_fn_lock(&mut self, val: bool) -> &mut Self
Use set_modifier_fn_lock() instead.
pub fn modifier_num_lock(&mut self, val: bool) -> &mut Self
Use set_modifier_num_lock() instead.
pub fn modifier_os(&mut self, val: bool) -> &mut Self
Use set_modifier_os() instead.
pub fn modifier_scroll_lock(&mut self, val: bool) -> &mut Self
Use set_modifier_scroll_lock() instead.
pub fn modifier_symbol(&mut self, val: bool) -> &mut Self
Use set_modifier_symbol() instead.
pub fn modifier_symbol_lock(&mut self, val: bool) -> &mut Self
Use set_modifier_symbol_lock() instead.
pub fn shift_key(&mut self, val: bool) -> &mut Self
Use set_shift_key() instead.
Use set_button() instead.
Use set_buttons() instead.
pub fn client_x(&mut self, val: i32) -> &mut Self
Use set_client_x() instead.
pub fn client_y(&mut self, val: i32) -> &mut Self
Use set_client_y() instead.
pub fn movement_x(&mut self, val: i32) -> &mut Self
Use set_movement_x() instead.
pub fn movement_y(&mut self, val: i32) -> &mut Self
Use set_movement_y() instead.
Use set_related_target() instead.
pub fn screen_x(&mut self, val: i32) -> &mut Self
Use set_screen_x() instead.
pub fn screen_y(&mut self, val: i32) -> &mut Self
Use set_screen_y() instead.
Methods from Deref<Target = Object>
pub fn constructor(&self) -> Function
pub fn has_own_property(&self, property: &JsValue) -> bool
Use Object::hasOwn instead.
pub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn to_locale_string(&self) -> JsString
pub fn to_string(&self) -> JsString
pub fn to_js_string(&self) -> JsString
pub fn value_of(&self) -> Object
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Check if this value is null or undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.