pub struct MutationObserverInit { /* private fields */ }Expand description
The MutationObserverInit dictionary.
This API requires the following crate features to be activated: MutationObserverInit
Implementations
Sourceimpl MutationObserverInit
impl MutationObserverInit
pub fn get_animations(&self) -> Option<bool>
Sourceimpl MutationObserverInit
impl MutationObserverInit
pub fn set_animations(&self, val: bool)
Sourceimpl MutationObserverInit
impl MutationObserverInit
pub fn get_attribute_filter(&self) -> Option<Array>
Sourceimpl MutationObserverInit
impl MutationObserverInit
pub fn set_attribute_filter(&self, val: &JsValue)
Sourceimpl MutationObserverInit
impl MutationObserverInit
pub fn get_attribute_old_value(&self) -> Option<bool>
Sourceimpl MutationObserverInit
impl MutationObserverInit
pub fn set_attribute_old_value(&self, val: bool)
Sourceimpl MutationObserverInit
impl MutationObserverInit
pub fn get_attributes(&self) -> Option<bool>
Sourceimpl MutationObserverInit
impl MutationObserverInit
pub fn set_attributes(&self, val: bool)
Sourceimpl MutationObserverInit
impl MutationObserverInit
pub fn get_character_data(&self) -> Option<bool>
Sourceimpl MutationObserverInit
impl MutationObserverInit
pub fn set_character_data(&self, val: bool)
Sourceimpl MutationObserverInit
impl MutationObserverInit
pub fn get_character_data_old_value(&self) -> Option<bool>
Sourceimpl MutationObserverInit
impl MutationObserverInit
pub fn set_character_data_old_value(&self, val: bool)
Sourceimpl MutationObserverInit
impl MutationObserverInit
pub fn get_child_list(&self) -> Option<bool>
Sourceimpl MutationObserverInit
impl MutationObserverInit
pub fn set_child_list(&self, val: bool)
Sourceimpl MutationObserverInit
impl MutationObserverInit
pub fn get_native_anonymous_child_list(&self) -> Option<bool>
Sourceimpl MutationObserverInit
impl MutationObserverInit
pub fn set_native_anonymous_child_list(&self, val: bool)
Sourceimpl MutationObserverInit
impl MutationObserverInit
pub fn get_subtree(&self) -> Option<bool>
Sourceimpl MutationObserverInit
impl MutationObserverInit
pub fn set_subtree(&self, val: bool)
Sourceimpl MutationObserverInit
impl MutationObserverInit
Sourcepub fn new() -> Self
pub fn new() -> Self
Construct a new MutationObserverInit.
This API requires the following crate features to be activated: MutationObserverInit
pub fn animations(&mut self, val: bool) -> &mut Self
Use set_animations() instead.
pub fn attribute_filter(&mut self, val: &JsValue) -> &mut Self
Use set_attribute_filter() instead.
pub fn attribute_old_value(&mut self, val: bool) -> &mut Self
Use set_attribute_old_value() instead.
pub fn attributes(&mut self, val: bool) -> &mut Self
Use set_attributes() instead.
pub fn character_data(&mut self, val: bool) -> &mut Self
Use set_character_data() instead.
pub fn character_data_old_value(&mut self, val: bool) -> &mut Self
Use set_character_data_old_value() instead.
pub fn child_list(&mut self, val: bool) -> &mut Self
Use set_child_list() instead.
pub fn native_anonymous_child_list(&mut self, val: bool) -> &mut Self
Use set_native_anonymous_child_list() instead.
pub fn subtree(&mut self, val: bool) -> &mut Self
Use set_subtree() instead.
Methods from Deref<Target = Object>
pub fn constructor(&self) -> Function
pub fn has_own_property(&self, property: &JsValue) -> bool
Use Object::hasOwn instead.
pub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn to_locale_string(&self) -> JsString
pub fn to_string(&self) -> JsString
pub fn to_js_string(&self) -> JsString
pub fn value_of(&self) -> Object
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Check if this value is null or undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.