pub struct NavigateEventInit { /* private fields */ }Expand description
The NavigateEventInit dictionary.
This API requires the following crate features to be activated: NavigateEventInit
Implementations
Sourcepub fn get_bubbles(&self) -> Option<bool>
pub fn get_bubbles(&self) -> Option<bool>
Get the bubbles field of this object.
This API requires the following crate features to be activated: NavigateEventInit
Sourcepub fn set_bubbles(&self, val: bool)
pub fn set_bubbles(&self, val: bool)
Change the bubbles field of this object.
This API requires the following crate features to be activated: NavigateEventInit
Sourcepub fn get_cancelable(&self) -> Option<bool>
pub fn get_cancelable(&self) -> Option<bool>
Get the cancelable field of this object.
This API requires the following crate features to be activated: NavigateEventInit
Sourcepub fn set_cancelable(&self, val: bool)
pub fn set_cancelable(&self, val: bool)
Change the cancelable field of this object.
This API requires the following crate features to be activated: NavigateEventInit
Sourcepub fn get_composed(&self) -> Option<bool>
pub fn get_composed(&self) -> Option<bool>
Get the composed field of this object.
This API requires the following crate features to be activated: NavigateEventInit
Sourcepub fn set_composed(&self, val: bool)
pub fn set_composed(&self, val: bool)
Change the composed field of this object.
This API requires the following crate features to be activated: NavigateEventInit
Sourcepub fn get_can_intercept(&self) -> Option<bool>
pub fn get_can_intercept(&self) -> Option<bool>
Get the canIntercept field of this object.
This API requires the following crate features to be activated: NavigateEventInit
Sourcepub fn set_can_intercept(&self, val: bool)
pub fn set_can_intercept(&self, val: bool)
Change the canIntercept field of this object.
This API requires the following crate features to be activated: NavigateEventInit
Sourcepub fn get_destination(&self) -> NavigationDestination
pub fn get_destination(&self) -> NavigationDestination
Get the destination field of this object.
This API requires the following crate features to be activated: NavigateEventInit, NavigationDestination
Sourcepub fn set_destination(&self, val: &NavigationDestination)
pub fn set_destination(&self, val: &NavigationDestination)
Change the destination field of this object.
This API requires the following crate features to be activated: NavigateEventInit, NavigationDestination
Sourcepub fn get_download_request(&self) -> Option<String>
pub fn get_download_request(&self) -> Option<String>
Get the downloadRequest field of this object.
This API requires the following crate features to be activated: NavigateEventInit
Sourcepub fn set_download_request(&self, val: Option<&str>)
pub fn set_download_request(&self, val: Option<&str>)
Change the downloadRequest field of this object.
This API requires the following crate features to be activated: NavigateEventInit
Sourcepub fn get_form_data(&self) -> Option<FormData>
pub fn get_form_data(&self) -> Option<FormData>
Get the formData field of this object.
This API requires the following crate features to be activated: FormData, NavigateEventInit
Sourcepub fn set_form_data(&self, val: Option<&FormData>)
pub fn set_form_data(&self, val: Option<&FormData>)
Change the formData field of this object.
This API requires the following crate features to be activated: FormData, NavigateEventInit
Sourcepub fn get_has_ua_visual_transition(&self) -> Option<bool>
pub fn get_has_ua_visual_transition(&self) -> Option<bool>
Get the hasUAVisualTransition field of this object.
This API requires the following crate features to be activated: NavigateEventInit
Sourcepub fn set_has_ua_visual_transition(&self, val: bool)
pub fn set_has_ua_visual_transition(&self, val: bool)
Change the hasUAVisualTransition field of this object.
This API requires the following crate features to be activated: NavigateEventInit
Sourcepub fn get_hash_change(&self) -> Option<bool>
pub fn get_hash_change(&self) -> Option<bool>
Get the hashChange field of this object.
This API requires the following crate features to be activated: NavigateEventInit
Sourcepub fn set_hash_change(&self, val: bool)
pub fn set_hash_change(&self, val: bool)
Change the hashChange field of this object.
This API requires the following crate features to be activated: NavigateEventInit
Get the navigationType field of this object.
This API requires the following crate features to be activated: NavigateEventInit, NavigationApiType
Change the navigationType field of this object.
This API requires the following crate features to be activated: NavigateEventInit, NavigationApiType
Sourcepub fn get_signal(&self) -> AbortSignal
pub fn get_signal(&self) -> AbortSignal
Get the signal field of this object.
This API requires the following crate features to be activated: AbortSignal, NavigateEventInit
Sourcepub fn set_signal(&self, val: &AbortSignal)
pub fn set_signal(&self, val: &AbortSignal)
Change the signal field of this object.
This API requires the following crate features to be activated: AbortSignal, NavigateEventInit
Sourcepub fn get_source_element(&self) -> Option<Element>
pub fn get_source_element(&self) -> Option<Element>
Get the sourceElement field of this object.
This API requires the following crate features to be activated: Element, NavigateEventInit
Sourcepub fn set_source_element(&self, val: Option<&Element>)
pub fn set_source_element(&self, val: Option<&Element>)
Change the sourceElement field of this object.
This API requires the following crate features to be activated: Element, NavigateEventInit
Sourcepub fn get_user_initiated(&self) -> Option<bool>
pub fn get_user_initiated(&self) -> Option<bool>
Get the userInitiated field of this object.
This API requires the following crate features to be activated: NavigateEventInit
Sourcepub fn set_user_initiated(&self, val: bool)
pub fn set_user_initiated(&self, val: bool)
Change the userInitiated field of this object.
This API requires the following crate features to be activated: NavigateEventInit
Sourcepub fn new(destination: &NavigationDestination, signal: &AbortSignal) -> Self
pub fn new(destination: &NavigationDestination, signal: &AbortSignal) -> Self
Construct a new NavigateEventInit.
This API requires the following crate features to be activated: AbortSignal, NavigateEventInit, NavigationDestination
pub fn bubbles(&mut self, val: bool) -> &mut Self
Use set_bubbles() instead.
pub fn cancelable(&mut self, val: bool) -> &mut Self
Use set_cancelable() instead.
pub fn composed(&mut self, val: bool) -> &mut Self
Use set_composed() instead.
pub fn can_intercept(&mut self, val: bool) -> &mut Self
Use set_can_intercept() instead.
pub fn destination(&mut self, val: &NavigationDestination) -> &mut Self
Use set_destination() instead.
pub fn download_request(&mut self, val: Option<&str>) -> &mut Self
Use set_download_request() instead.
pub fn form_data(&mut self, val: Option<&FormData>) -> &mut Self
Use set_form_data() instead.
pub fn has_ua_visual_transition(&mut self, val: bool) -> &mut Self
Use set_has_ua_visual_transition() instead.
pub fn hash_change(&mut self, val: bool) -> &mut Self
Use set_hash_change() instead.
pub fn info(&mut self, val: &JsValue) -> &mut Self
Use set_info() instead.
Use set_navigation_type() instead.
pub fn signal(&mut self, val: &AbortSignal) -> &mut Self
Use set_signal() instead.
pub fn source_element(&mut self, val: Option<&Element>) -> &mut Self
Use set_source_element() instead.
pub fn user_initiated(&mut self, val: bool) -> &mut Self
Use set_user_initiated() instead.
Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
👎Deprecated: Use Object::hasOwn instead.
pub fn has_own_property(&self, property: &JsValue) -> bool
Use Object::hasOwn instead.
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Sourcepub fn to_js_string(&self) -> JsString
pub fn to_js_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn as_f64(&self) -> Option<f64>
pub fn as_f64(&self) -> Option<f64>
Returns the f64 value of this JS value if it’s an instance of a
number.
If this JS value is not an instance of a number then this returns
None.
Sourcepub fn as_string(&self) -> Option<String>
pub fn as_string(&self) -> Option<String>
If this JS value is a string value, this function copies the JS string
value into Wasm linear memory, encoded as UTF-8, and returns it as a
Rust String.
To avoid the copying and re-encoding, consider the
JsString::try_from() function from js-sys
instead.
If this JS value is not an instance of a string or if it’s not valid
utf-8 then this returns None.
UTF-16 vs UTF-8
JavaScript strings in general are encoded as UTF-16, but Rust strings
are encoded as UTF-8. This can cause the Rust string to look a bit
different than the JS string sometimes. For more details see the
documentation about the str type which contains a few
caveats about the encodings.
Sourcepub fn as_bool(&self) -> Option<bool>
pub fn as_bool(&self) -> Option<bool>
Returns the bool value of this JS value if it’s an instance of a
boolean.
If this JS value is not an instance of a boolean then this returns
None.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Tests whether this JS value is undefined
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Tests whether this JS value is null or undefined
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Tests whether the type of this JS value is function.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Applies the binary in JS operator on the two JsValues.
Sourcepub fn loose_eq(&self, other: &JsValue) -> bool
pub fn loose_eq(&self, other: &JsValue) -> bool
Compare two JsValues for equality, using the == operator in JS.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Applies the binary >>> JS operator on the two JsValues.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Applies the binary / JS operator on two JsValues, catching and returning any RangeError thrown.
Sourcepub fn pow(&self, rhs: &JsValue) -> JsValue
pub fn pow(&self, rhs: &JsValue) -> JsValue
Applies the binary ** JS operator on the two JsValues.
Sourcepub fn lt(&self, other: &JsValue) -> bool
pub fn lt(&self, other: &JsValue) -> bool
Applies the binary < JS operator on the two JsValues.
Sourcepub fn le(&self, other: &JsValue) -> bool
pub fn le(&self, other: &JsValue) -> bool
Applies the binary <= JS operator on the two JsValues.
Sourcepub fn ge(&self, other: &JsValue) -> bool
pub fn ge(&self, other: &JsValue) -> bool
Applies the binary >= JS operator on the two JsValues.
Sourcepub fn gt(&self, other: &JsValue) -> bool
pub fn gt(&self, other: &JsValue) -> bool
Applies the binary > JS operator on the two JsValues.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Applies the unary + JS operator on a JsValue. Can throw.