pub struct Node { /* private fields */ }Expand description
The Node class.
This API requires the following crate features to be activated: Node
Implementations
Sourceimpl Node
impl Node
Sourcepub const ELEMENT_NODE: u16
pub const ELEMENT_NODE: u16
The Node.ELEMENT_NODE const.
This API requires the following crate features to be activated: Node
Sourcepub const ATTRIBUTE_NODE: u16
pub const ATTRIBUTE_NODE: u16
The Node.ATTRIBUTE_NODE const.
This API requires the following crate features to be activated: Node
Sourcepub const TEXT_NODE: u16
pub const TEXT_NODE: u16
The Node.TEXT_NODE const.
This API requires the following crate features to be activated: Node
Sourcepub const CDATA_SECTION_NODE: u16
pub const CDATA_SECTION_NODE: u16
The Node.CDATA_SECTION_NODE const.
This API requires the following crate features to be activated: Node
Sourcepub const ENTITY_REFERENCE_NODE: u16
pub const ENTITY_REFERENCE_NODE: u16
The Node.ENTITY_REFERENCE_NODE const.
This API requires the following crate features to be activated: Node
Sourcepub const ENTITY_NODE: u16
pub const ENTITY_NODE: u16
The Node.ENTITY_NODE const.
This API requires the following crate features to be activated: Node
Sourcepub const PROCESSING_INSTRUCTION_NODE: u16
pub const PROCESSING_INSTRUCTION_NODE: u16
The Node.PROCESSING_INSTRUCTION_NODE const.
This API requires the following crate features to be activated: Node
Sourcepub const COMMENT_NODE: u16
pub const COMMENT_NODE: u16
The Node.COMMENT_NODE const.
This API requires the following crate features to be activated: Node
Sourcepub const DOCUMENT_NODE: u16
pub const DOCUMENT_NODE: u16
The Node.DOCUMENT_NODE const.
This API requires the following crate features to be activated: Node
Sourcepub const DOCUMENT_TYPE_NODE: u16
pub const DOCUMENT_TYPE_NODE: u16
The Node.DOCUMENT_TYPE_NODE const.
This API requires the following crate features to be activated: Node
Sourcepub const DOCUMENT_FRAGMENT_NODE: u16
pub const DOCUMENT_FRAGMENT_NODE: u16
The Node.DOCUMENT_FRAGMENT_NODE const.
This API requires the following crate features to be activated: Node
Sourcepub const NOTATION_NODE: u16
pub const NOTATION_NODE: u16
The Node.NOTATION_NODE const.
This API requires the following crate features to be activated: Node
Sourcepub const DOCUMENT_POSITION_DISCONNECTED: u16
pub const DOCUMENT_POSITION_DISCONNECTED: u16
The Node.DOCUMENT_POSITION_DISCONNECTED const.
This API requires the following crate features to be activated: Node
Sourcepub const DOCUMENT_POSITION_PRECEDING: u16
pub const DOCUMENT_POSITION_PRECEDING: u16
The Node.DOCUMENT_POSITION_PRECEDING const.
This API requires the following crate features to be activated: Node
Sourcepub const DOCUMENT_POSITION_FOLLOWING: u16
pub const DOCUMENT_POSITION_FOLLOWING: u16
The Node.DOCUMENT_POSITION_FOLLOWING const.
This API requires the following crate features to be activated: Node
Sourcepub const DOCUMENT_POSITION_CONTAINS: u16
pub const DOCUMENT_POSITION_CONTAINS: u16
The Node.DOCUMENT_POSITION_CONTAINS const.
This API requires the following crate features to be activated: Node
Sourcepub const DOCUMENT_POSITION_CONTAINED_BY: u16
pub const DOCUMENT_POSITION_CONTAINED_BY: u16
The Node.DOCUMENT_POSITION_CONTAINED_BY const.
This API requires the following crate features to be activated: Node
Sourcepub const DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC: u16
pub const DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC: u16
The Node.DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC const.
This API requires the following crate features to be activated: Node
Methods from Deref<Target = EventTarget>
pub fn add_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener( &self, type_: &str, listener: &EventListener, ) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_add_event_listener_options( &self, type_: &str, listener: &Function, options: &AddEventListenerOptions, ) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_add_event_listener_options( &self, type_: &str, listener: &EventListener, options: &AddEventListenerOptions, ) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_bool( &self, type_: &str, listener: &EventListener, options: bool, ) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_add_event_listener_options_and_wants_untrusted( &self, type_: &str, listener: &Function, options: &AddEventListenerOptions, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_add_event_listener_options_and_wants_untrusted( &self, type_: &str, listener: &EventListener, options: &AddEventListenerOptions, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_bool_and_wants_untrusted( &self, type_: &str, listener: &Function, options: bool, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_bool_and_wants_untrusted( &self, type_: &str, listener: &EventListener, options: bool, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>
pub fn dispatch_event(&self, event: &Event) -> Result<bool, JsValue>
pub fn remove_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>
pub fn remove_event_listener_with_event_listener( &self, type_: &str, listener: &EventListener, ) -> Result<(), JsValue>
pub fn remove_event_listener_with_callback_and_event_listener_options( &self, type_: &str, listener: &Function, options: &EventListenerOptions, ) -> Result<(), JsValue>
pub fn remove_event_listener_with_event_listener_and_event_listener_options( &self, type_: &str, listener: &EventListener, options: &EventListenerOptions, ) -> Result<(), JsValue>
pub fn remove_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>
pub fn remove_event_listener_with_event_listener_and_bool( &self, type_: &str, listener: &EventListener, options: bool, ) -> Result<(), JsValue>
Methods from Deref<Target = Object>
pub fn constructor(&self) -> Function
pub fn has_own_property(&self, property: &JsValue) -> bool
Use Object::hasOwn instead.
pub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn to_locale_string(&self) -> JsString
pub fn to_string(&self) -> JsString
pub fn to_js_string(&self) -> JsString
pub fn value_of(&self) -> Object
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Check if this value is null or undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.