pub struct NotificationOptions { /* private fields */ }Expand description
The NotificationOptions dictionary.
This API requires the following crate features to be activated: NotificationOptions
Implementations
Sourceimpl NotificationOptions
impl NotificationOptions
pub fn get_actions(&self) -> Option<Array>
Sourceimpl NotificationOptions
impl NotificationOptions
pub fn set_actions(&self, val: &JsValue)
Sourceimpl NotificationOptions
impl NotificationOptions
pub fn get_renotify(&self) -> Option<bool>
Sourceimpl NotificationOptions
impl NotificationOptions
pub fn set_renotify(&self, val: bool)
Sourceimpl NotificationOptions
impl NotificationOptions
pub fn get_require_interaction(&self) -> Option<bool>
Sourceimpl NotificationOptions
impl NotificationOptions
pub fn set_require_interaction(&self, val: bool)
Sourceimpl NotificationOptions
impl NotificationOptions
pub fn get_silent(&self) -> Option<bool>
Sourceimpl NotificationOptions
impl NotificationOptions
pub fn set_silent(&self, val: Option<bool>)
Sourceimpl NotificationOptions
impl NotificationOptions
pub fn get_timestamp(&self) -> Option<f64>
Sourceimpl NotificationOptions
impl NotificationOptions
pub fn set_timestamp(&self, val: f64)
Sourceimpl NotificationOptions
impl NotificationOptions
pub fn set_timestamp_u32(&self, val: u32)
Sourceimpl NotificationOptions
impl NotificationOptions
pub fn set_timestamp_f64(&self, val: f64)
Sourceimpl NotificationOptions
impl NotificationOptions
pub fn get_vibrate(&self) -> JsValue
Sourceimpl NotificationOptions
impl NotificationOptions
pub fn set_vibrate(&self, val: &JsValue)
Sourceimpl NotificationOptions
impl NotificationOptions
pub fn set_vibrate_u32(&self, val: u32)
Sourceimpl NotificationOptions
impl NotificationOptions
pub fn set_vibrate_u32_sequence(&self, val: &JsValue)
Sourceimpl NotificationOptions
impl NotificationOptions
Sourcepub fn new() -> Self
pub fn new() -> Self
Construct a new NotificationOptions.
This API requires the following crate features to be activated: NotificationOptions
pub fn actions(&mut self, val: &JsValue) -> &mut Self
Use set_actions() instead.
pub fn badge(&mut self, val: &str) -> &mut Self
Use set_badge() instead.
pub fn body(&mut self, val: &str) -> &mut Self
Use set_body() instead.
pub fn data(&mut self, val: &JsValue) -> &mut Self
Use set_data() instead.
pub fn icon(&mut self, val: &str) -> &mut Self
Use set_icon() instead.
pub fn image(&mut self, val: &str) -> &mut Self
Use set_image() instead.
pub fn lang(&mut self, val: &str) -> &mut Self
Use set_lang() instead.
pub fn renotify(&mut self, val: bool) -> &mut Self
Use set_renotify() instead.
pub fn require_interaction(&mut self, val: bool) -> &mut Self
Use set_require_interaction() instead.
pub fn silent(&mut self, val: Option<bool>) -> &mut Self
Use set_silent() instead.
pub fn tag(&mut self, val: &str) -> &mut Self
Use set_tag() instead.
pub fn timestamp(&mut self, val: f64) -> &mut Self
Use set_timestamp() instead.
pub fn vibrate(&mut self, val: &JsValue) -> &mut Self
Use set_vibrate() instead.
Methods from Deref<Target = Object>
pub fn constructor(&self) -> Function
pub fn has_own_property(&self, property: &JsValue) -> bool
Use Object::hasOwn instead.
pub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn to_locale_string(&self) -> JsString
pub fn to_string(&self) -> JsString
pub fn to_js_string(&self) -> JsString
pub fn value_of(&self) -> Object
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Check if this value is null or undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.