#[repr(transparent)]pub struct OffscreenCanvasRenderingContext2d {
pub obj: Object,
}Expand description
The OffscreenCanvasRenderingContext2d class.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d
Fields
obj: ObjectImplementations
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn canvas(&self) -> OffscreenCanvas
pub fn canvas(&self) -> OffscreenCanvas
Getter for the canvas field of this object.
This API requires the following crate features to be activated: OffscreenCanvas, OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn global_alpha(&self) -> f64
pub fn global_alpha(&self) -> f64
Getter for the globalAlpha field of this object.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn set_global_alpha(&self, value: f64)
pub fn set_global_alpha(&self, value: f64)
Setter for the globalAlpha field of this object.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn global_composite_operation(&self) -> Result<String, JsValue>
pub fn global_composite_operation(&self) -> Result<String, JsValue>
Getter for the globalCompositeOperation field of this object.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn stroke_style(&self) -> JsValue
pub fn stroke_style(&self) -> JsValue
Getter for the strokeStyle field of this object.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn set_stroke_style(&self, value: &JsValue)
👎Deprecated
pub fn set_stroke_style(&self, value: &JsValue)
Setter for the strokeStyle field of this object.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn set_stroke_style_str(&self, value: &str)
pub fn set_stroke_style_str(&self, value: &str)
Setter for the strokeStyle field of this object.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn set_stroke_style_canvas_gradient(&self, value: &CanvasGradient)
pub fn set_stroke_style_canvas_gradient(&self, value: &CanvasGradient)
Setter for the strokeStyle field of this object.
This API requires the following crate features to be activated: CanvasGradient, OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn set_stroke_style_canvas_pattern(&self, value: &CanvasPattern)
pub fn set_stroke_style_canvas_pattern(&self, value: &CanvasPattern)
Setter for the strokeStyle field of this object.
This API requires the following crate features to be activated: CanvasPattern, OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn fill_style(&self) -> JsValue
pub fn fill_style(&self) -> JsValue
Getter for the fillStyle field of this object.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn set_fill_style(&self, value: &JsValue)
👎Deprecated
pub fn set_fill_style(&self, value: &JsValue)
Setter for the fillStyle field of this object.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn set_fill_style_str(&self, value: &str)
pub fn set_fill_style_str(&self, value: &str)
Setter for the fillStyle field of this object.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn set_fill_style_canvas_gradient(&self, value: &CanvasGradient)
pub fn set_fill_style_canvas_gradient(&self, value: &CanvasGradient)
Setter for the fillStyle field of this object.
This API requires the following crate features to be activated: CanvasGradient, OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn set_fill_style_canvas_pattern(&self, value: &CanvasPattern)
pub fn set_fill_style_canvas_pattern(&self, value: &CanvasPattern)
Setter for the fillStyle field of this object.
This API requires the following crate features to be activated: CanvasPattern, OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn set_filter(&self, value: &str)
pub fn set_filter(&self, value: &str)
Setter for the filter field of this object.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn image_smoothing_enabled(&self) -> bool
pub fn image_smoothing_enabled(&self) -> bool
Getter for the imageSmoothingEnabled field of this object.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn set_image_smoothing_enabled(&self, value: bool)
pub fn set_image_smoothing_enabled(&self, value: bool)
Setter for the imageSmoothingEnabled field of this object.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn line_width(&self) -> f64
pub fn line_width(&self) -> f64
Getter for the lineWidth field of this object.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn set_line_width(&self, value: f64)
pub fn set_line_width(&self, value: f64)
Setter for the lineWidth field of this object.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn set_line_cap(&self, value: &str)
pub fn set_line_cap(&self, value: &str)
Setter for the lineCap field of this object.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn set_line_join(&self, value: &str)
pub fn set_line_join(&self, value: &str)
Setter for the lineJoin field of this object.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn miter_limit(&self) -> f64
pub fn miter_limit(&self) -> f64
Getter for the miterLimit field of this object.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn set_miter_limit(&self, value: f64)
pub fn set_miter_limit(&self, value: f64)
Setter for the miterLimit field of this object.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn line_dash_offset(&self) -> f64
pub fn line_dash_offset(&self) -> f64
Getter for the lineDashOffset field of this object.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn set_line_dash_offset(&self, value: f64)
pub fn set_line_dash_offset(&self, value: f64)
Setter for the lineDashOffset field of this object.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn shadow_offset_x(&self) -> f64
pub fn shadow_offset_x(&self) -> f64
Getter for the shadowOffsetX field of this object.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn set_shadow_offset_x(&self, value: f64)
pub fn set_shadow_offset_x(&self, value: f64)
Setter for the shadowOffsetX field of this object.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn shadow_offset_y(&self) -> f64
pub fn shadow_offset_y(&self) -> f64
Getter for the shadowOffsetY field of this object.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn set_shadow_offset_y(&self, value: f64)
pub fn set_shadow_offset_y(&self, value: f64)
Setter for the shadowOffsetY field of this object.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn shadow_blur(&self) -> f64
pub fn shadow_blur(&self) -> f64
Getter for the shadowBlur field of this object.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn set_shadow_blur(&self, value: f64)
pub fn set_shadow_blur(&self, value: f64)
Setter for the shadowBlur field of this object.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn shadow_color(&self) -> String
pub fn shadow_color(&self) -> String
Getter for the shadowColor field of this object.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn set_shadow_color(&self, value: &str)
pub fn set_shadow_color(&self, value: &str)
Setter for the shadowColor field of this object.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn text_align(&self) -> String
pub fn text_align(&self) -> String
Getter for the textAlign field of this object.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn set_text_align(&self, value: &str)
pub fn set_text_align(&self, value: &str)
Setter for the textAlign field of this object.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn text_baseline(&self) -> String
pub fn text_baseline(&self) -> String
Getter for the textBaseline field of this object.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn set_text_baseline(&self, value: &str)
pub fn set_text_baseline(&self, value: &str)
Setter for the textBaseline field of this object.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn draw_image_with_html_image_element(
&self,
image: &HtmlImageElement,
dx: f64,
dy: f64,
) -> Result<(), JsValue>
pub fn draw_image_with_html_image_element( &self, image: &HtmlImageElement, dx: f64, dy: f64, ) -> Result<(), JsValue>
The drawImage() method.
This API requires the following crate features to be activated: HtmlImageElement, OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn draw_image_with_html_canvas_element(
&self,
image: &HtmlCanvasElement,
dx: f64,
dy: f64,
) -> Result<(), JsValue>
pub fn draw_image_with_html_canvas_element( &self, image: &HtmlCanvasElement, dx: f64, dy: f64, ) -> Result<(), JsValue>
The drawImage() method.
This API requires the following crate features to be activated: HtmlCanvasElement, OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn draw_image_with_html_video_element(
&self,
image: &HtmlVideoElement,
dx: f64,
dy: f64,
) -> Result<(), JsValue>
pub fn draw_image_with_html_video_element( &self, image: &HtmlVideoElement, dx: f64, dy: f64, ) -> Result<(), JsValue>
The drawImage() method.
This API requires the following crate features to be activated: HtmlVideoElement, OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn draw_image_with_image_bitmap(
&self,
image: &ImageBitmap,
dx: f64,
dy: f64,
) -> Result<(), JsValue>
pub fn draw_image_with_image_bitmap( &self, image: &ImageBitmap, dx: f64, dy: f64, ) -> Result<(), JsValue>
The drawImage() method.
This API requires the following crate features to be activated: ImageBitmap, OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn draw_image_with_offscreen_canvas(
&self,
image: &OffscreenCanvas,
dx: f64,
dy: f64,
) -> Result<(), JsValue>
pub fn draw_image_with_offscreen_canvas( &self, image: &OffscreenCanvas, dx: f64, dy: f64, ) -> Result<(), JsValue>
The drawImage() method.
This API requires the following crate features to be activated: OffscreenCanvas, OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn draw_image_with_html_image_element_and_dw_and_dh(
&self,
image: &HtmlImageElement,
dx: f64,
dy: f64,
dw: f64,
dh: f64,
) -> Result<(), JsValue>
pub fn draw_image_with_html_image_element_and_dw_and_dh( &self, image: &HtmlImageElement, dx: f64, dy: f64, dw: f64, dh: f64, ) -> Result<(), JsValue>
The drawImage() method.
This API requires the following crate features to be activated: HtmlImageElement, OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn draw_image_with_html_canvas_element_and_dw_and_dh(
&self,
image: &HtmlCanvasElement,
dx: f64,
dy: f64,
dw: f64,
dh: f64,
) -> Result<(), JsValue>
pub fn draw_image_with_html_canvas_element_and_dw_and_dh( &self, image: &HtmlCanvasElement, dx: f64, dy: f64, dw: f64, dh: f64, ) -> Result<(), JsValue>
The drawImage() method.
This API requires the following crate features to be activated: HtmlCanvasElement, OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn draw_image_with_html_video_element_and_dw_and_dh(
&self,
image: &HtmlVideoElement,
dx: f64,
dy: f64,
dw: f64,
dh: f64,
) -> Result<(), JsValue>
pub fn draw_image_with_html_video_element_and_dw_and_dh( &self, image: &HtmlVideoElement, dx: f64, dy: f64, dw: f64, dh: f64, ) -> Result<(), JsValue>
The drawImage() method.
This API requires the following crate features to be activated: HtmlVideoElement, OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn draw_image_with_image_bitmap_and_dw_and_dh(
&self,
image: &ImageBitmap,
dx: f64,
dy: f64,
dw: f64,
dh: f64,
) -> Result<(), JsValue>
pub fn draw_image_with_image_bitmap_and_dw_and_dh( &self, image: &ImageBitmap, dx: f64, dy: f64, dw: f64, dh: f64, ) -> Result<(), JsValue>
The drawImage() method.
This API requires the following crate features to be activated: ImageBitmap, OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn draw_image_with_offscreen_canvas_and_dw_and_dh(
&self,
image: &OffscreenCanvas,
dx: f64,
dy: f64,
dw: f64,
dh: f64,
) -> Result<(), JsValue>
pub fn draw_image_with_offscreen_canvas_and_dw_and_dh( &self, image: &OffscreenCanvas, dx: f64, dy: f64, dw: f64, dh: f64, ) -> Result<(), JsValue>
The drawImage() method.
This API requires the following crate features to be activated: OffscreenCanvas, OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn draw_image_with_html_image_element_and_sw_and_sh_and_dx_and_dy_and_dw_and_dh(
&self,
image: &HtmlImageElement,
sx: f64,
sy: f64,
sw: f64,
sh: f64,
dx: f64,
dy: f64,
dw: f64,
dh: f64,
) -> Result<(), JsValue>
pub fn draw_image_with_html_image_element_and_sw_and_sh_and_dx_and_dy_and_dw_and_dh( &self, image: &HtmlImageElement, sx: f64, sy: f64, sw: f64, sh: f64, dx: f64, dy: f64, dw: f64, dh: f64, ) -> Result<(), JsValue>
The drawImage() method.
This API requires the following crate features to be activated: HtmlImageElement, OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn draw_image_with_html_canvas_element_and_sw_and_sh_and_dx_and_dy_and_dw_and_dh(
&self,
image: &HtmlCanvasElement,
sx: f64,
sy: f64,
sw: f64,
sh: f64,
dx: f64,
dy: f64,
dw: f64,
dh: f64,
) -> Result<(), JsValue>
pub fn draw_image_with_html_canvas_element_and_sw_and_sh_and_dx_and_dy_and_dw_and_dh( &self, image: &HtmlCanvasElement, sx: f64, sy: f64, sw: f64, sh: f64, dx: f64, dy: f64, dw: f64, dh: f64, ) -> Result<(), JsValue>
The drawImage() method.
This API requires the following crate features to be activated: HtmlCanvasElement, OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn draw_image_with_html_video_element_and_sw_and_sh_and_dx_and_dy_and_dw_and_dh(
&self,
image: &HtmlVideoElement,
sx: f64,
sy: f64,
sw: f64,
sh: f64,
dx: f64,
dy: f64,
dw: f64,
dh: f64,
) -> Result<(), JsValue>
pub fn draw_image_with_html_video_element_and_sw_and_sh_and_dx_and_dy_and_dw_and_dh( &self, image: &HtmlVideoElement, sx: f64, sy: f64, sw: f64, sh: f64, dx: f64, dy: f64, dw: f64, dh: f64, ) -> Result<(), JsValue>
The drawImage() method.
This API requires the following crate features to be activated: HtmlVideoElement, OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn draw_image_with_image_bitmap_and_sw_and_sh_and_dx_and_dy_and_dw_and_dh(
&self,
image: &ImageBitmap,
sx: f64,
sy: f64,
sw: f64,
sh: f64,
dx: f64,
dy: f64,
dw: f64,
dh: f64,
) -> Result<(), JsValue>
pub fn draw_image_with_image_bitmap_and_sw_and_sh_and_dx_and_dy_and_dw_and_dh( &self, image: &ImageBitmap, sx: f64, sy: f64, sw: f64, sh: f64, dx: f64, dy: f64, dw: f64, dh: f64, ) -> Result<(), JsValue>
The drawImage() method.
This API requires the following crate features to be activated: ImageBitmap, OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn draw_image_with_offscreen_canvas_and_sw_and_sh_and_dx_and_dy_and_dw_and_dh(
&self,
image: &OffscreenCanvas,
sx: f64,
sy: f64,
sw: f64,
sh: f64,
dx: f64,
dy: f64,
dw: f64,
dh: f64,
) -> Result<(), JsValue>
pub fn draw_image_with_offscreen_canvas_and_sw_and_sh_and_dx_and_dy_and_dw_and_dh( &self, image: &OffscreenCanvas, sx: f64, sy: f64, sw: f64, sh: f64, dx: f64, dy: f64, dw: f64, dh: f64, ) -> Result<(), JsValue>
The drawImage() method.
This API requires the following crate features to be activated: OffscreenCanvas, OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn begin_path(&self)
pub fn begin_path(&self)
The beginPath() method.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn clip_with_canvas_winding_rule(&self, winding: CanvasWindingRule)
pub fn clip_with_canvas_winding_rule(&self, winding: CanvasWindingRule)
The clip() method.
This API requires the following crate features to be activated: CanvasWindingRule, OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn clip_with_path_2d(&self, path: &Path2d)
pub fn clip_with_path_2d(&self, path: &Path2d)
The clip() method.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d, Path2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn clip_with_path_2d_and_winding(
&self,
path: &Path2d,
winding: CanvasWindingRule,
)
pub fn clip_with_path_2d_and_winding( &self, path: &Path2d, winding: CanvasWindingRule, )
The clip() method.
This API requires the following crate features to be activated: CanvasWindingRule, OffscreenCanvasRenderingContext2d, Path2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn fill_with_canvas_winding_rule(&self, winding: CanvasWindingRule)
pub fn fill_with_canvas_winding_rule(&self, winding: CanvasWindingRule)
The fill() method.
This API requires the following crate features to be activated: CanvasWindingRule, OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn fill_with_path_2d(&self, path: &Path2d)
pub fn fill_with_path_2d(&self, path: &Path2d)
The fill() method.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d, Path2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn fill_with_path_2d_and_winding(
&self,
path: &Path2d,
winding: CanvasWindingRule,
)
pub fn fill_with_path_2d_and_winding( &self, path: &Path2d, winding: CanvasWindingRule, )
The fill() method.
This API requires the following crate features to be activated: CanvasWindingRule, OffscreenCanvasRenderingContext2d, Path2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn is_point_in_path_with_f64(&self, x: f64, y: f64) -> bool
pub fn is_point_in_path_with_f64(&self, x: f64, y: f64) -> bool
The isPointInPath() method.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn is_point_in_path_with_f64_and_canvas_winding_rule(
&self,
x: f64,
y: f64,
winding: CanvasWindingRule,
) -> bool
pub fn is_point_in_path_with_f64_and_canvas_winding_rule( &self, x: f64, y: f64, winding: CanvasWindingRule, ) -> bool
The isPointInPath() method.
This API requires the following crate features to be activated: CanvasWindingRule, OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn is_point_in_path_with_path_2d_and_f64_and_winding(
&self,
path: &Path2d,
x: f64,
y: f64,
winding: CanvasWindingRule,
) -> bool
pub fn is_point_in_path_with_path_2d_and_f64_and_winding( &self, path: &Path2d, x: f64, y: f64, winding: CanvasWindingRule, ) -> bool
The isPointInPath() method.
This API requires the following crate features to be activated: CanvasWindingRule, OffscreenCanvasRenderingContext2d, Path2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn is_point_in_stroke_with_x_and_y(&self, x: f64, y: f64) -> bool
pub fn is_point_in_stroke_with_x_and_y(&self, x: f64, y: f64) -> bool
The isPointInStroke() method.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn stroke_with_path(&self, path: &Path2d)
pub fn stroke_with_path(&self, path: &Path2d)
The stroke() method.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d, Path2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn create_linear_gradient(
&self,
x0: f64,
y0: f64,
x1: f64,
y1: f64,
) -> CanvasGradient
pub fn create_linear_gradient( &self, x0: f64, y0: f64, x1: f64, y1: f64, ) -> CanvasGradient
The createLinearGradient() method.
This API requires the following crate features to be activated: CanvasGradient, OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn create_pattern_with_html_image_element(
&self,
image: &HtmlImageElement,
repetition: &str,
) -> Result<Option<CanvasPattern>, JsValue>
pub fn create_pattern_with_html_image_element( &self, image: &HtmlImageElement, repetition: &str, ) -> Result<Option<CanvasPattern>, JsValue>
The createPattern() method.
This API requires the following crate features to be activated: CanvasPattern, HtmlImageElement, OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn create_pattern_with_html_canvas_element(
&self,
image: &HtmlCanvasElement,
repetition: &str,
) -> Result<Option<CanvasPattern>, JsValue>
pub fn create_pattern_with_html_canvas_element( &self, image: &HtmlCanvasElement, repetition: &str, ) -> Result<Option<CanvasPattern>, JsValue>
The createPattern() method.
This API requires the following crate features to be activated: CanvasPattern, HtmlCanvasElement, OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn create_pattern_with_html_video_element(
&self,
image: &HtmlVideoElement,
repetition: &str,
) -> Result<Option<CanvasPattern>, JsValue>
pub fn create_pattern_with_html_video_element( &self, image: &HtmlVideoElement, repetition: &str, ) -> Result<Option<CanvasPattern>, JsValue>
The createPattern() method.
This API requires the following crate features to be activated: CanvasPattern, HtmlVideoElement, OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn create_pattern_with_image_bitmap(
&self,
image: &ImageBitmap,
repetition: &str,
) -> Result<Option<CanvasPattern>, JsValue>
pub fn create_pattern_with_image_bitmap( &self, image: &ImageBitmap, repetition: &str, ) -> Result<Option<CanvasPattern>, JsValue>
The createPattern() method.
This API requires the following crate features to be activated: CanvasPattern, ImageBitmap, OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn create_pattern_with_offscreen_canvas(
&self,
image: &OffscreenCanvas,
repetition: &str,
) -> Result<Option<CanvasPattern>, JsValue>
pub fn create_pattern_with_offscreen_canvas( &self, image: &OffscreenCanvas, repetition: &str, ) -> Result<Option<CanvasPattern>, JsValue>
The createPattern() method.
This API requires the following crate features to be activated: CanvasPattern, OffscreenCanvas, OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn get_image_data(
&self,
sx: i32,
sy: i32,
sw: i32,
sh: i32,
) -> Result<ImageData, JsValue>
pub fn get_image_data( &self, sx: i32, sy: i32, sw: i32, sh: i32, ) -> Result<ImageData, JsValue>
The getImageData() method.
This API requires the following crate features to be activated: ImageData, OffscreenCanvasRenderingContext2d
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn put_image_data(
&self,
imagedata: &ImageData,
dx: i32,
dy: i32,
) -> Result<(), JsValue>
pub fn put_image_data( &self, imagedata: &ImageData, dx: i32, dy: i32, ) -> Result<(), JsValue>
The putImageData() method.
This API requires the following crate features to be activated: ImageData, OffscreenCanvasRenderingContext2d
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn put_image_data_with_dirty_x_and_dirty_y_and_dirty_width_and_dirty_height(
&self,
imagedata: &ImageData,
dx: i32,
dy: i32,
dirty_x: i32,
dirty_y: i32,
dirty_width: i32,
dirty_height: i32,
) -> Result<(), JsValue>
pub fn put_image_data_with_dirty_x_and_dirty_y_and_dirty_width_and_dirty_height( &self, imagedata: &ImageData, dx: i32, dy: i32, dirty_x: i32, dirty_y: i32, dirty_width: i32, dirty_height: i32, ) -> Result<(), JsValue>
The putImageData() method.
This API requires the following crate features to be activated: ImageData, OffscreenCanvasRenderingContext2d
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn close_path(&self)
pub fn close_path(&self)
The closePath() method.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn ellipse_with_anticlockwise(
&self,
x: f64,
y: f64,
radius_x: f64,
radius_y: f64,
rotation: f64,
start_angle: f64,
end_angle: f64,
anticlockwise: bool,
) -> Result<(), JsValue>
pub fn ellipse_with_anticlockwise( &self, x: f64, y: f64, radius_x: f64, radius_y: f64, rotation: f64, start_angle: f64, end_angle: f64, anticlockwise: bool, ) -> Result<(), JsValue>
The ellipse() method.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn get_line_dash(&self) -> Array
pub fn get_line_dash(&self) -> Array
The getLineDash() method.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn measure_text(&self, text: &str) -> Result<TextMetrics, JsValue>
pub fn measure_text(&self, text: &str) -> Result<TextMetrics, JsValue>
The measureText() method.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d, TextMetrics
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn reset_transform(&self) -> Result<(), JsValue>
pub fn reset_transform(&self) -> Result<(), JsValue>
The resetTransform() method.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d
Sourceimpl OffscreenCanvasRenderingContext2d
impl OffscreenCanvasRenderingContext2d
Sourcepub fn set_transform_with_default_dom_matrix_2d_init(
&self,
) -> Result<(), JsValue>
pub fn set_transform_with_default_dom_matrix_2d_init( &self, ) -> Result<(), JsValue>
The setTransform() method.
This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d
Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
👎Deprecated: Use Object::hasOwn instead.
pub fn has_own_property(&self, property: &JsValue) -> bool
Use Object::hasOwn instead.
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Sourcepub fn to_js_string(&self) -> JsString
pub fn to_js_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Check if this value is null or undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.