pub struct PerformanceTiming { /* private fields */ }Expand description
The PerformanceTiming class.
This API requires the following crate features to be activated: PerformanceTiming
Implementations
Sourceimpl PerformanceTiming
impl PerformanceTiming
pub fn unload_event_start(&self) -> f64
Sourceimpl PerformanceTiming
impl PerformanceTiming
pub fn unload_event_end(&self) -> f64
Sourceimpl PerformanceTiming
impl PerformanceTiming
pub fn redirect_start(&self) -> f64
Sourceimpl PerformanceTiming
impl PerformanceTiming
pub fn redirect_end(&self) -> f64
Sourceimpl PerformanceTiming
impl PerformanceTiming
pub fn fetch_start(&self) -> f64
Sourceimpl PerformanceTiming
impl PerformanceTiming
pub fn domain_lookup_start(&self) -> f64
Sourceimpl PerformanceTiming
impl PerformanceTiming
pub fn domain_lookup_end(&self) -> f64
Sourceimpl PerformanceTiming
impl PerformanceTiming
pub fn connect_start(&self) -> f64
Sourceimpl PerformanceTiming
impl PerformanceTiming
pub fn connect_end(&self) -> f64
Sourceimpl PerformanceTiming
impl PerformanceTiming
pub fn secure_connection_start(&self) -> f64
Sourceimpl PerformanceTiming
impl PerformanceTiming
pub fn request_start(&self) -> f64
Sourceimpl PerformanceTiming
impl PerformanceTiming
pub fn response_start(&self) -> f64
Sourceimpl PerformanceTiming
impl PerformanceTiming
pub fn response_end(&self) -> f64
Sourceimpl PerformanceTiming
impl PerformanceTiming
pub fn dom_loading(&self) -> f64
Sourceimpl PerformanceTiming
impl PerformanceTiming
pub fn dom_interactive(&self) -> f64
Sourceimpl PerformanceTiming
impl PerformanceTiming
pub fn dom_content_loaded_event_start(&self) -> f64
Sourceimpl PerformanceTiming
impl PerformanceTiming
pub fn dom_content_loaded_event_end(&self) -> f64
Sourceimpl PerformanceTiming
impl PerformanceTiming
pub fn dom_complete(&self) -> f64
Sourceimpl PerformanceTiming
impl PerformanceTiming
pub fn load_event_start(&self) -> f64
Sourceimpl PerformanceTiming
impl PerformanceTiming
pub fn load_event_end(&self) -> f64
Sourceimpl PerformanceTiming
impl PerformanceTiming
pub fn time_to_non_blank_paint(&self) -> f64
Sourceimpl PerformanceTiming
impl PerformanceTiming
pub fn time_to_dom_content_flushed(&self) -> f64
Methods from Deref<Target = Object>
pub fn constructor(&self) -> Function
pub fn has_own_property(&self, property: &JsValue) -> bool
👎Deprecated:
Use Object::hasOwn instead.
pub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn to_locale_string(&self) -> JsString
pub fn to_string(&self) -> JsString
pub fn to_js_string(&self) -> JsString
pub fn value_of(&self) -> Object
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Check if this value is null or undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.