Range

Struct Range 

#[repr(transparent)]
pub struct Range { pub obj: AbstractRange, }
The Range class.

MDN Documentation

This API requires the following crate features to be activated: Range

Fields

obj: AbstractRange

Implementations

Source

impl Range

pub fn start_container(&self) -> Result<Node, JsValue>

Getter for the startContainer field of this object.

MDN Documentation

This API requires the following crate features to be activated: Node, Range

Source

impl Range

pub fn start_offset(&self) -> Result<u32, JsValue>

Getter for the startOffset field of this object.

MDN Documentation

This API requires the following crate features to be activated: Range

Source

impl Range

pub fn end_container(&self) -> Result<Node, JsValue>

Getter for the endContainer field of this object.

MDN Documentation

This API requires the following crate features to be activated: Node, Range

Source

impl Range

pub fn end_offset(&self) -> Result<u32, JsValue>

Getter for the endOffset field of this object.

MDN Documentation

This API requires the following crate features to be activated: Range

Source

impl Range

pub fn collapsed(&self) -> bool

Getter for the collapsed field of this object.

MDN Documentation

This API requires the following crate features to be activated: Range

Source

impl Range

pub fn common_ancestor_container(&self) -> Result<Node, JsValue>

Getter for the commonAncestorContainer field of this object.

MDN Documentation

This API requires the following crate features to be activated: Node, Range

Source

impl Range

pub fn new() -> Result<Range, JsValue>

The new Range(..) constructor, creating a new instance of Range.

MDN Documentation

This API requires the following crate features to be activated: Range

Source

impl Range

pub fn clone_contents(&self) -> Result<DocumentFragment, JsValue>

The cloneContents() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment, Range

Source

impl Range

pub fn clone_range(&self) -> Range

The cloneRange() method.

MDN Documentation

This API requires the following crate features to be activated: Range

Source

impl Range

pub fn collapse(&self)

The collapse() method.

MDN Documentation

This API requires the following crate features to be activated: Range

Source

impl Range

pub fn collapse_with_to_start(&self, to_start: bool)

The collapse() method.

MDN Documentation

This API requires the following crate features to be activated: Range

Source

impl Range

pub fn compare_boundary_points( &self, how: u16, source_range: &Range, ) -> Result<i16, JsValue>

The compareBoundaryPoints() method.

MDN Documentation

This API requires the following crate features to be activated: Range

Source

impl Range

pub fn compare_point(&self, node: &Node, offset: u32) -> Result<i16, JsValue>

The comparePoint() method.

MDN Documentation

This API requires the following crate features to be activated: Node, Range

Source

impl Range

pub fn create_contextual_fragment( &self, fragment: &str, ) -> Result<DocumentFragment, JsValue>

The createContextualFragment() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment, Range

Source

impl Range

pub fn delete_contents(&self) -> Result<(), JsValue>

The deleteContents() method.

MDN Documentation

This API requires the following crate features to be activated: Range

Source

impl Range

pub fn detach(&self)

The detach() method.

MDN Documentation

This API requires the following crate features to be activated: Range

Source

impl Range

pub fn extract_contents(&self) -> Result<DocumentFragment, JsValue>

The extractContents() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment, Range

Source

impl Range

pub fn get_bounding_client_rect(&self) -> DomRect

The getBoundingClientRect() method.

MDN Documentation

This API requires the following crate features to be activated: DomRect, Range

Source

impl Range

pub fn insert_node(&self, node: &Node) -> Result<(), JsValue>

The insertNode() method.

MDN Documentation

This API requires the following crate features to be activated: Node, Range

Source

impl Range

pub fn intersects_node(&self, node: &Node) -> Result<bool, JsValue>

The intersectsNode() method.

MDN Documentation

This API requires the following crate features to be activated: Node, Range

Source

impl Range

pub fn is_point_in_range( &self, node: &Node, offset: u32, ) -> Result<bool, JsValue>

The isPointInRange() method.

MDN Documentation

This API requires the following crate features to be activated: Node, Range

Source

impl Range

pub fn select_node(&self, ref_node: &Node) -> Result<(), JsValue>

The selectNode() method.

MDN Documentation

This API requires the following crate features to be activated: Node, Range

Source

impl Range

pub fn select_node_contents(&self, ref_node: &Node) -> Result<(), JsValue>

The selectNodeContents() method.

MDN Documentation

This API requires the following crate features to be activated: Node, Range

Source

impl Range

pub fn set_end(&self, ref_node: &Node, offset: u32) -> Result<(), JsValue>

The setEnd() method.

MDN Documentation

This API requires the following crate features to be activated: Node, Range

Source

impl Range

pub fn set_end_after(&self, ref_node: &Node) -> Result<(), JsValue>

The setEndAfter() method.

MDN Documentation

This API requires the following crate features to be activated: Node, Range

Source

impl Range

pub fn set_end_before(&self, ref_node: &Node) -> Result<(), JsValue>

The setEndBefore() method.

MDN Documentation

This API requires the following crate features to be activated: Node, Range

Source

impl Range

pub fn set_start(&self, ref_node: &Node, offset: u32) -> Result<(), JsValue>

The setStart() method.

MDN Documentation

This API requires the following crate features to be activated: Node, Range

Source

impl Range

pub fn set_start_after(&self, ref_node: &Node) -> Result<(), JsValue>

The setStartAfter() method.

MDN Documentation

This API requires the following crate features to be activated: Node, Range

Source

impl Range

pub fn set_start_before(&self, ref_node: &Node) -> Result<(), JsValue>

The setStartBefore() method.

MDN Documentation

This API requires the following crate features to be activated: Node, Range

Source

impl Range

pub fn surround_contents(&self, new_parent: &Node) -> Result<(), JsValue>

The surroundContents() method.

MDN Documentation

This API requires the following crate features to be activated: Node, Range

Source

impl Range

pub const START_TO_START: u16

The Range.START_TO_START const.

This API requires the following crate features to be activated: Range

pub const START_TO_END: u16

The Range.START_TO_END const.

This API requires the following crate features to be activated: Range

pub const END_TO_END: u16

The Range.END_TO_END const.

This API requires the following crate features to be activated: Range

pub const END_TO_START: u16

The Range.END_TO_START const.

This API requires the following crate features to be activated: Range

Methods from Deref<Target = AbstractRange>

pub fn start_container(&self) -> Node

Getter for the startContainer field of this object.

MDN Documentation

This API requires the following crate features to be activated: AbstractRange, Node

pub fn start_offset(&self) -> u32

Getter for the startOffset field of this object.

MDN Documentation

This API requires the following crate features to be activated: AbstractRange

pub fn end_container(&self) -> Node

Getter for the endContainer field of this object.

MDN Documentation

This API requires the following crate features to be activated: AbstractRange, Node

pub fn end_offset(&self) -> u32

Getter for the endOffset field of this object.

MDN Documentation

This API requires the following crate features to be activated: AbstractRange

pub fn collapsed(&self) -> bool

Getter for the collapsed field of this object.

MDN Documentation

This API requires the following crate features to be activated: AbstractRange

Methods from Deref<Target = Object>

pub fn constructor(&self) -> Function

The constructor property returns a reference to the Object constructor function that created the instance object.

MDN documentation

pub fn has_own_property(&self, property: &JsValue) -> bool

👎Deprecated:

Use Object::hasOwn instead.

The hasOwnProperty() method returns a boolean indicating whether the object has the specified property as its own property (as opposed to inheriting it).

MDN documentation

pub fn is_prototype_of(&self, value: &JsValue) -> bool

The isPrototypeOf() method checks if an object exists in another object’s prototype chain.

MDN documentation

pub fn property_is_enumerable(&self, property: &JsValue) -> bool

The propertyIsEnumerable() method returns a Boolean indicating whether the specified property is enumerable.

MDN documentation

pub fn to_locale_string(&self) -> JsString

The toLocaleString() method returns a string representing the object. This method is meant to be overridden by derived objects for locale-specific purposes.

MDN documentation

pub fn to_string(&self) -> JsString

The toString() method returns a string representing the object.

MDN documentation

pub fn to_js_string(&self) -> JsString

The toString() method returns a string representing the object.

MDN documentation

pub fn value_of(&self) -> Object

The valueOf() method returns the primitive value of the specified object.

MDN documentation

Methods from Deref<Target = JsValue>

pub const NULL: JsValue

pub const UNDEFINED: JsValue

pub const TRUE: JsValue

pub const FALSE: JsValue

pub fn id(&self) -> u64

Get the heap ID for this value.

This is used internally for encoding values to send to JS.

pub fn unchecked_into_f64(&self) -> f64

Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.

pub fn has_type<T>(&self) -> bool
where T: JsCast,

Check if this value is an instance of a specific JS type.

pub fn checked_div(&self, rhs: &JsValue) -> JsValue

Checked division.

pub fn pow(&self, rhs: &JsValue) -> JsValue

Power operation.

pub fn bit_and(&self, rhs: &JsValue) -> JsValue

Bitwise AND.

pub fn bit_or(&self, rhs: &JsValue) -> JsValue

Bitwise OR.

pub fn bit_xor(&self, rhs: &JsValue) -> JsValue

Bitwise XOR.

pub fn bit_not(&self) -> JsValue

Bitwise NOT.

pub fn shl(&self, rhs: &JsValue) -> JsValue

Left shift.

pub fn shr(&self, rhs: &JsValue) -> JsValue

Signed right shift.

pub fn unsigned_shr(&self, rhs: &JsValue) -> u32

Unsigned right shift.

pub fn add(&self, rhs: &JsValue) -> JsValue

Add.

pub fn sub(&self, rhs: &JsValue) -> JsValue

Subtract.

pub fn mul(&self, rhs: &JsValue) -> JsValue

Multiply.

pub fn div(&self, rhs: &JsValue) -> JsValue

Divide.

pub fn rem(&self, rhs: &JsValue) -> JsValue

Remainder.

pub fn neg(&self) -> JsValue

Negate.

pub fn lt(&self, other: &JsValue) -> bool

Less than comparison.

pub fn le(&self, other: &JsValue) -> bool

Less than or equal comparison.

pub fn gt(&self, other: &JsValue) -> bool

Greater than comparison.

pub fn ge(&self, other: &JsValue) -> bool

Greater than or equal comparison.

pub fn loose_eq(&self, other: &JsValue) -> bool

Loose equality (==).

pub fn is_falsy(&self) -> bool

Check if this value is a falsy value in JavaScript.

pub fn is_truthy(&self) -> bool

Check if this value is a truthy value in JavaScript.

pub fn is_object(&self) -> bool

Check if this value is an object.

pub fn is_function(&self) -> bool

Check if this value is a function.

pub fn is_string(&self) -> bool

Check if this value is a string.

pub fn is_symbol(&self) -> bool

Check if this value is a symbol.

pub fn is_bigint(&self) -> bool

Check if this value is a bigint.

pub fn is_array(&self) -> bool

Check if this value is an Array.

pub fn is_undefined(&self) -> bool

Check if this value is undefined.

pub fn is_null(&self) -> bool

Check if this value is null.

pub fn is_null_or_undefined(&self) -> bool

Check if this value is null or undefined.

pub fn js_typeof(&self) -> JsValue

Get the typeof this value as a string.

pub fn js_in(&self, obj: &JsValue) -> bool

Check if this value has a property with the given name.

pub fn as_bool(&self) -> Option<bool>

Get the value as a bool.

pub fn as_f64(&self) -> Option<f64>

Get the value as an f64.

pub fn as_string(&self) -> Option<String>

Get the value as a string.

pub fn as_debug_string(&self) -> String

Get a debug string representation of the value.