pub struct ReadableWritablePair { /* private fields */ }Expand description
The ReadableWritablePair dictionary.
This API requires the following crate features to be activated: ReadableWritablePair
Implementations
Sourceimpl ReadableWritablePair
impl ReadableWritablePair
pub fn get_readable(&self) -> ReadableStream
Sourceimpl ReadableWritablePair
impl ReadableWritablePair
pub fn set_readable(&self, val: &ReadableStream)
Sourceimpl ReadableWritablePair
impl ReadableWritablePair
pub fn get_writable(&self) -> WritableStream
Sourceimpl ReadableWritablePair
impl ReadableWritablePair
pub fn set_writable(&self, val: &WritableStream)
Sourceimpl ReadableWritablePair
impl ReadableWritablePair
Sourcepub fn new(readable: &ReadableStream, writable: &WritableStream) -> Self
pub fn new(readable: &ReadableStream, writable: &WritableStream) -> Self
Construct a new ReadableWritablePair.
This API requires the following crate features to be activated: ReadableStream, ReadableWritablePair, WritableStream
pub fn readable(&mut self, val: &ReadableStream) -> &mut Self
Use set_readable() instead.
pub fn writable(&mut self, val: &WritableStream) -> &mut Self
Use set_writable() instead.
Methods from Deref<Target = Object>
pub fn constructor(&self) -> Function
pub fn has_own_property(&self, property: &JsValue) -> bool
Use Object::hasOwn instead.
pub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn to_locale_string(&self) -> JsString
pub fn to_string(&self) -> JsString
pub fn to_js_string(&self) -> JsString
pub fn value_of(&self) -> Object
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Check if this value is null or undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.