pub struct RequestInit { /* private fields */ }Expand description
The RequestInit dictionary.
This API requires the following crate features to be activated: RequestInit
Implementations
Sourceimpl RequestInit
impl RequestInit
pub fn set_body_opt_blob(&self, val: Option<&Blob>)
Sourceimpl RequestInit
impl RequestInit
pub fn set_body_opt_buffer_source(&self, val: Option<&Object>)
Sourceimpl RequestInit
impl RequestInit
pub fn set_body_opt_u8_slice(&self, val: Option<&mut [u8]>)
Sourceimpl RequestInit
impl RequestInit
pub fn set_body_opt_u8_array(&self, val: Option<&Uint8Array>)
Sourceimpl RequestInit
impl RequestInit
pub fn set_body_opt_form_data(&self, val: Option<&FormData>)
Sourceimpl RequestInit
impl RequestInit
pub fn set_body_opt_url_search_params(&self, val: Option<&UrlSearchParams>)
Sourceimpl RequestInit
impl RequestInit
pub fn set_body_opt_str(&self, val: Option<&str>)
Sourceimpl RequestInit
impl RequestInit
pub fn set_body_opt_readable_stream(&self, val: Option<&ReadableStream>)
Sourceimpl RequestInit
impl RequestInit
pub fn get_cache(&self) -> Option<RequestCache>
Sourceimpl RequestInit
impl RequestInit
pub fn set_cache(&self, val: RequestCache)
Sourceimpl RequestInit
impl RequestInit
pub fn get_credentials(&self) -> Option<RequestCredentials>
Sourceimpl RequestInit
impl RequestInit
pub fn set_credentials(&self, val: RequestCredentials)
Sourceimpl RequestInit
impl RequestInit
pub fn get_headers(&self) -> JsValue
Sourceimpl RequestInit
impl RequestInit
pub fn set_headers(&self, val: &JsValue)
Sourceimpl RequestInit
impl RequestInit
pub fn set_headers_headers(&self, val: &Headers)
Sourceimpl RequestInit
impl RequestInit
pub fn set_headers_str_sequence_sequence(&self, val: &JsValue)
Sourceimpl RequestInit
impl RequestInit
pub fn set_headers_record_from_str_to_str(&self, val: &Object)
Sourceimpl RequestInit
impl RequestInit
pub fn get_integrity(&self) -> Option<String>
Sourceimpl RequestInit
impl RequestInit
pub fn set_integrity(&self, val: &str)
Sourceimpl RequestInit
impl RequestInit
pub fn get_method(&self) -> Option<String>
Sourceimpl RequestInit
impl RequestInit
pub fn set_method(&self, val: &str)
Sourceimpl RequestInit
impl RequestInit
pub fn get_mode(&self) -> Option<RequestMode>
Sourceimpl RequestInit
impl RequestInit
pub fn set_mode(&self, val: RequestMode)
Sourceimpl RequestInit
impl RequestInit
pub fn get_observe(&self) -> Option<ObserverCallback>
Sourceimpl RequestInit
impl RequestInit
pub fn set_observe(&self, val: &ObserverCallback)
Sourceimpl RequestInit
impl RequestInit
pub fn set_observe_callback(&self, val: &Function)
Sourceimpl RequestInit
impl RequestInit
pub fn set_observe_observer_callback(&self, val: &ObserverCallback)
Sourceimpl RequestInit
impl RequestInit
pub fn get_redirect(&self) -> Option<RequestRedirect>
Sourceimpl RequestInit
impl RequestInit
pub fn set_redirect(&self, val: RequestRedirect)
Sourceimpl RequestInit
impl RequestInit
pub fn get_referrer(&self) -> Option<String>
Sourceimpl RequestInit
impl RequestInit
pub fn set_referrer(&self, val: &str)
Sourceimpl RequestInit
impl RequestInit
pub fn get_referrer_policy(&self) -> Option<ReferrerPolicy>
Sourceimpl RequestInit
impl RequestInit
pub fn set_referrer_policy(&self, val: ReferrerPolicy)
Sourceimpl RequestInit
impl RequestInit
pub fn get_signal(&self) -> Option<AbortSignal>
Sourceimpl RequestInit
impl RequestInit
pub fn set_signal(&self, val: Option<&AbortSignal>)
Sourceimpl RequestInit
impl RequestInit
Sourcepub fn new() -> Self
pub fn new() -> Self
Construct a new RequestInit.
This API requires the following crate features to be activated: RequestInit
pub fn body(&mut self, val: Option<&JsValue>) -> &mut Self
Use set_body() instead.
pub fn cache(&mut self, val: RequestCache) -> &mut Self
Use set_cache() instead.
pub fn credentials(&mut self, val: RequestCredentials) -> &mut Self
Use set_credentials() instead.
pub fn headers(&mut self, val: &JsValue) -> &mut Self
Use set_headers() instead.
pub fn integrity(&mut self, val: &str) -> &mut Self
Use set_integrity() instead.
pub fn method(&mut self, val: &str) -> &mut Self
Use set_method() instead.
pub fn mode(&mut self, val: RequestMode) -> &mut Self
Use set_mode() instead.
pub fn observe(&mut self, val: &ObserverCallback) -> &mut Self
Use set_observe() instead.
pub fn redirect(&mut self, val: RequestRedirect) -> &mut Self
Use set_redirect() instead.
pub fn referrer(&mut self, val: &str) -> &mut Self
Use set_referrer() instead.
pub fn referrer_policy(&mut self, val: ReferrerPolicy) -> &mut Self
Use set_referrer_policy() instead.
pub fn signal(&mut self, val: Option<&AbortSignal>) -> &mut Self
Use set_signal() instead.
Methods from Deref<Target = Object>
pub fn constructor(&self) -> Function
pub fn has_own_property(&self, property: &JsValue) -> bool
Use Object::hasOwn instead.
pub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn to_locale_string(&self) -> JsString
pub fn to_string(&self) -> JsString
pub fn to_js_string(&self) -> JsString
pub fn value_of(&self) -> Object
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Check if this value is null or undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.