SubtleCrypto

Struct SubtleCrypto 

pub struct SubtleCrypto { /* private fields */ }
The SubtleCrypto class.

MDN Documentation

This API requires the following crate features to be activated: SubtleCrypto

Implementations

Source

impl SubtleCrypto

pub fn decrypt_with_object_and_buffer_source( &self, algorithm: &Object, key: &CryptoKey, data: &Object, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn decrypt_with_str_and_buffer_source( &self, algorithm: &str, key: &CryptoKey, data: &Object, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn decrypt_with_object_and_u8_array( &self, algorithm: &Object, key: &CryptoKey, data: &[u8], ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn decrypt_with_str_and_u8_array( &self, algorithm: &str, key: &CryptoKey, data: &[u8], ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

Source

impl SubtleCrypto

pub fn decrypt_with_str_and_js_u8_array( &self, algorithm: &str, key: &CryptoKey, data: &Uint8Array, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn derive_bits_with_object( &self, algorithm: &Object, base_key: &CryptoKey, length: u32, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn derive_bits_with_str( &self, algorithm: &str, base_key: &CryptoKey, length: u32, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn derive_key_with_object_and_object( &self, algorithm: &Object, base_key: &CryptoKey, derived_key_type: &Object, extractable: bool, key_usages: &JsValue, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn derive_key_with_str_and_object( &self, algorithm: &str, base_key: &CryptoKey, derived_key_type: &Object, extractable: bool, key_usages: &JsValue, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn derive_key_with_object_and_str( &self, algorithm: &Object, base_key: &CryptoKey, derived_key_type: &str, extractable: bool, key_usages: &JsValue, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn derive_key_with_str_and_str( &self, algorithm: &str, base_key: &CryptoKey, derived_key_type: &str, extractable: bool, key_usages: &JsValue, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

Source

impl SubtleCrypto

pub fn digest_with_str_and_buffer_source( &self, algorithm: &str, data: &Object, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn digest_with_object_and_u8_array( &self, algorithm: &Object, data: &[u8], ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn digest_with_str_and_u8_array( &self, algorithm: &str, data: &[u8], ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

Source

impl SubtleCrypto

pub fn digest_with_str_and_js_u8_array( &self, algorithm: &str, data: &Uint8Array, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn encrypt_with_object_and_buffer_source( &self, algorithm: &Object, key: &CryptoKey, data: &Object, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn encrypt_with_str_and_buffer_source( &self, algorithm: &str, key: &CryptoKey, data: &Object, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn encrypt_with_object_and_u8_array( &self, algorithm: &Object, key: &CryptoKey, data: &[u8], ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn encrypt_with_str_and_u8_array( &self, algorithm: &str, key: &CryptoKey, data: &[u8], ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

Source

impl SubtleCrypto

pub fn encrypt_with_str_and_js_u8_array( &self, algorithm: &str, key: &CryptoKey, data: &Uint8Array, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn export_key( &self, format: &str, key: &CryptoKey, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn generate_key_with_object( &self, algorithm: &Object, extractable: bool, key_usages: &JsValue, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn generate_key_with_str( &self, algorithm: &str, extractable: bool, key_usages: &JsValue, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn import_key_with_object( &self, format: &str, key_data: &Object, algorithm: &Object, extractable: bool, key_usages: &JsValue, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn import_key_with_str( &self, format: &str, key_data: &Object, algorithm: &str, extractable: bool, key_usages: &JsValue, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn sign_with_object_and_buffer_source( &self, algorithm: &Object, key: &CryptoKey, data: &Object, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn sign_with_str_and_buffer_source( &self, algorithm: &str, key: &CryptoKey, data: &Object, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn sign_with_object_and_u8_array( &self, algorithm: &Object, key: &CryptoKey, data: &[u8], ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn sign_with_str_and_u8_array( &self, algorithm: &str, key: &CryptoKey, data: &[u8], ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn sign_with_object_and_js_u8_array( &self, algorithm: &Object, key: &CryptoKey, data: &Uint8Array, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn sign_with_str_and_js_u8_array( &self, algorithm: &str, key: &CryptoKey, data: &Uint8Array, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn unwrap_key_with_buffer_source_and_object_and_object( &self, format: &str, wrapped_key: &Object, unwrapping_key: &CryptoKey, unwrap_algorithm: &Object, unwrapped_key_algorithm: &Object, extractable: bool, key_usages: &JsValue, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn unwrap_key_with_u8_array_and_object_and_object( &self, format: &str, wrapped_key: &[u8], unwrapping_key: &CryptoKey, unwrap_algorithm: &Object, unwrapped_key_algorithm: &Object, extractable: bool, key_usages: &JsValue, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn unwrap_key_with_js_u8_array_and_object_and_object( &self, format: &str, wrapped_key: &Uint8Array, unwrapping_key: &CryptoKey, unwrap_algorithm: &Object, unwrapped_key_algorithm: &Object, extractable: bool, key_usages: &JsValue, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn unwrap_key_with_buffer_source_and_str_and_object( &self, format: &str, wrapped_key: &Object, unwrapping_key: &CryptoKey, unwrap_algorithm: &str, unwrapped_key_algorithm: &Object, extractable: bool, key_usages: &JsValue, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn unwrap_key_with_u8_array_and_str_and_object( &self, format: &str, wrapped_key: &[u8], unwrapping_key: &CryptoKey, unwrap_algorithm: &str, unwrapped_key_algorithm: &Object, extractable: bool, key_usages: &JsValue, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn unwrap_key_with_js_u8_array_and_str_and_object( &self, format: &str, wrapped_key: &Uint8Array, unwrapping_key: &CryptoKey, unwrap_algorithm: &str, unwrapped_key_algorithm: &Object, extractable: bool, key_usages: &JsValue, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn unwrap_key_with_buffer_source_and_object_and_str( &self, format: &str, wrapped_key: &Object, unwrapping_key: &CryptoKey, unwrap_algorithm: &Object, unwrapped_key_algorithm: &str, extractable: bool, key_usages: &JsValue, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn unwrap_key_with_u8_array_and_object_and_str( &self, format: &str, wrapped_key: &[u8], unwrapping_key: &CryptoKey, unwrap_algorithm: &Object, unwrapped_key_algorithm: &str, extractable: bool, key_usages: &JsValue, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn unwrap_key_with_js_u8_array_and_object_and_str( &self, format: &str, wrapped_key: &Uint8Array, unwrapping_key: &CryptoKey, unwrap_algorithm: &Object, unwrapped_key_algorithm: &str, extractable: bool, key_usages: &JsValue, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn unwrap_key_with_buffer_source_and_str_and_str( &self, format: &str, wrapped_key: &Object, unwrapping_key: &CryptoKey, unwrap_algorithm: &str, unwrapped_key_algorithm: &str, extractable: bool, key_usages: &JsValue, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn unwrap_key_with_u8_array_and_str_and_str( &self, format: &str, wrapped_key: &[u8], unwrapping_key: &CryptoKey, unwrap_algorithm: &str, unwrapped_key_algorithm: &str, extractable: bool, key_usages: &JsValue, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn unwrap_key_with_js_u8_array_and_str_and_str( &self, format: &str, wrapped_key: &Uint8Array, unwrapping_key: &CryptoKey, unwrap_algorithm: &str, unwrapped_key_algorithm: &str, extractable: bool, key_usages: &JsValue, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

Source

impl SubtleCrypto

pub fn verify_with_str_and_buffer_source_and_buffer_source( &self, algorithm: &str, key: &CryptoKey, signature: &Object, data: &Object, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn verify_with_object_and_u8_array_and_buffer_source( &self, algorithm: &Object, key: &CryptoKey, signature: &[u8], data: &Object, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn verify_with_str_and_u8_array_and_buffer_source( &self, algorithm: &str, key: &CryptoKey, signature: &[u8], data: &Object, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

Source

impl SubtleCrypto

pub fn verify_with_str_and_js_u8_array_and_buffer_source( &self, algorithm: &str, key: &CryptoKey, signature: &Uint8Array, data: &Object, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn verify_with_object_and_buffer_source_and_u8_array( &self, algorithm: &Object, key: &CryptoKey, signature: &Object, data: &[u8], ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn verify_with_str_and_buffer_source_and_u8_array( &self, algorithm: &str, key: &CryptoKey, signature: &Object, data: &[u8], ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn verify_with_object_and_u8_array_and_u8_array( &self, algorithm: &Object, key: &CryptoKey, signature: &[u8], data: &[u8], ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn verify_with_str_and_u8_array_and_u8_array( &self, algorithm: &str, key: &CryptoKey, signature: &[u8], data: &[u8], ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn verify_with_object_and_u8_array_and_u8_slice( &self, algorithm: &Object, key: &CryptoKey, signature: &Uint8Array, data: &[u8], ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn verify_with_str_and_u8_array_and_u8_slice( &self, algorithm: &str, key: &CryptoKey, signature: &Uint8Array, data: &[u8], ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

Source

impl SubtleCrypto

pub fn verify_with_str_and_buffer_source_and_js_u8_array( &self, algorithm: &str, key: &CryptoKey, signature: &Object, data: &Uint8Array, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn verify_with_object_and_u8_slice_and_u8_array( &self, algorithm: &Object, key: &CryptoKey, signature: &[u8], data: &Uint8Array, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn verify_with_str_and_u8_slice_and_u8_array( &self, algorithm: &str, key: &CryptoKey, signature: &[u8], data: &Uint8Array, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

Source

impl SubtleCrypto

pub fn verify_with_str_and_js_u8_array_and_js_u8_array( &self, algorithm: &str, key: &CryptoKey, signature: &Uint8Array, data: &Uint8Array, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn wrap_key_with_object( &self, format: &str, key: &CryptoKey, wrapping_key: &CryptoKey, wrap_algorithm: &Object, ) -> Result<Promise, JsValue>

Source

impl SubtleCrypto

pub fn wrap_key_with_str( &self, format: &str, key: &CryptoKey, wrapping_key: &CryptoKey, wrap_algorithm: &str, ) -> Result<Promise, JsValue>

Methods from Deref<Target = Object>

pub fn constructor(&self) -> Function

pub fn has_own_property(&self, property: &JsValue) -> bool

👎Deprecated:

Use Object::hasOwn instead.

pub fn is_prototype_of(&self, value: &JsValue) -> bool

pub fn property_is_enumerable(&self, property: &JsValue) -> bool

pub fn to_locale_string(&self) -> JsString

pub fn to_string(&self) -> JsString

pub fn to_js_string(&self) -> JsString

pub fn value_of(&self) -> Object

Methods from Deref<Target = JsValue>

pub const NULL: JsValue

pub const UNDEFINED: JsValue

pub const TRUE: JsValue

pub const FALSE: JsValue

pub fn unchecked_into_f64(&self) -> f64

Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.

pub fn has_type<T>(&self) -> bool
where T: JsCast,

Check if this value is an instance of a specific JS type.

pub fn checked_div(&self, rhs: &JsValue) -> JsValue

Checked division.

pub fn pow(&self, rhs: &JsValue) -> JsValue

Power operation.

pub fn bit_and(&self, rhs: &JsValue) -> JsValue

Bitwise AND.

pub fn bit_or(&self, rhs: &JsValue) -> JsValue

Bitwise OR.

pub fn bit_xor(&self, rhs: &JsValue) -> JsValue

Bitwise XOR.

pub fn bit_not(&self) -> JsValue

Bitwise NOT.

pub fn shl(&self, rhs: &JsValue) -> JsValue

Left shift.

pub fn shr(&self, rhs: &JsValue) -> JsValue

Signed right shift.

pub fn unsigned_shr(&self, rhs: &JsValue) -> u32

Unsigned right shift.

pub fn add(&self, rhs: &JsValue) -> JsValue

Add.

pub fn sub(&self, rhs: &JsValue) -> JsValue

Subtract.

pub fn mul(&self, rhs: &JsValue) -> JsValue

Multiply.

pub fn div(&self, rhs: &JsValue) -> JsValue

Divide.

pub fn rem(&self, rhs: &JsValue) -> JsValue

Remainder.

pub fn neg(&self) -> JsValue

Negate.

pub fn lt(&self, other: &JsValue) -> bool

Less than comparison.

pub fn le(&self, other: &JsValue) -> bool

Less than or equal comparison.

pub fn gt(&self, other: &JsValue) -> bool

Greater than comparison.

pub fn ge(&self, other: &JsValue) -> bool

Greater than or equal comparison.

pub fn loose_eq(&self, other: &JsValue) -> bool

Loose equality (==).

pub fn is_falsy(&self) -> bool

Check if this value is a falsy value in JavaScript.

pub fn is_truthy(&self) -> bool

Check if this value is a truthy value in JavaScript.

pub fn is_object(&self) -> bool

Check if this value is an object.

pub fn is_function(&self) -> bool

Check if this value is a function.

pub fn is_string(&self) -> bool

Check if this value is a string.

pub fn is_symbol(&self) -> bool

Check if this value is a symbol.

pub fn is_bigint(&self) -> bool

Check if this value is a bigint.

pub fn is_array(&self) -> bool

Check if this value is an Array.

pub fn is_undefined(&self) -> bool

Check if this value is undefined.

pub fn is_null(&self) -> bool

Check if this value is null.

pub fn is_null_or_undefined(&self) -> bool

Check if this value is null or undefined.

pub fn js_typeof(&self) -> JsValue

Get the typeof this value as a string.

pub fn js_in(&self, obj: &JsValue) -> bool

Check if this value has a property with the given name.

pub fn as_bool(&self) -> Option<bool>

Get the value as a bool.

pub fn as_f64(&self) -> Option<f64>

Get the value as an f64.

pub fn as_string(&self) -> Option<String>

Get the value as a string.

pub fn as_debug_string(&self) -> String

Get a debug string representation of the value.