[−][src]Struct web_sys::SvgAnimateElement
The SVGAnimateElement object
This API requires the following crate features to be activated: SvgAnimateElement
Methods from Deref<Target = SvgAnimationElement>
pub fn begin_element(&self) -> Result<(), JsValue> | [src] |
The beginElement() method
This API requires the following crate features to be activated: SvgAnimationElement
pub fn begin_element_at(&self, offset: f32) -> Result<(), JsValue> | [src] |
The beginElementAt() method
This API requires the following crate features to be activated: SvgAnimationElement
pub fn end_element(&self) -> Result<(), JsValue> | [src] |
The endElement() method
This API requires the following crate features to be activated: SvgAnimationElement
pub fn end_element_at(&self, offset: f32) -> Result<(), JsValue> | [src] |
The endElementAt() method
This API requires the following crate features to be activated: SvgAnimationElement
pub fn get_current_time(&self) -> f32 | [src] |
The getCurrentTime() method
This API requires the following crate features to be activated: SvgAnimationElement
pub fn get_simple_duration(&self) -> Result<f32, JsValue> | [src] |
The getSimpleDuration() method
This API requires the following crate features to be activated: SvgAnimationElement
pub fn get_start_time(&self) -> Result<f32, JsValue> | [src] |
The getStartTime() method
This API requires the following crate features to be activated: SvgAnimationElement
pub fn target_element(&self) -> Option<SvgElement> | [src] |
The targetElement getter
This API requires the following crate features to be activated: SvgAnimationElement, SvgElement
pub fn has_extension(&self, extension: &str) -> bool | [src] |
The hasExtension() method
This API requires the following crate features to be activated: SvgAnimationElement
pub fn required_features(&self) -> SvgStringList | [src] |
The requiredFeatures getter
This API requires the following crate features to be activated: SvgAnimationElement, SvgStringList
pub fn required_extensions(&self) -> SvgStringList | [src] |
The requiredExtensions getter
This API requires the following crate features to be activated: SvgAnimationElement, SvgStringList
pub fn system_language(&self) -> SvgStringList | [src] |
The systemLanguage getter
This API requires the following crate features to be activated: SvgAnimationElement, SvgStringList