[−][src]Struct web_sys::SvgAnimatedPreserveAspectRatio
The SVGAnimatedPreserveAspectRatio object
This API requires the following crate features to be activated: SvgAnimatedPreserveAspectRatio
Methods
impl SvgAnimatedPreserveAspectRatio[src]
impl SvgAnimatedPreserveAspectRatiopub fn base_val(&self) -> SvgPreserveAspectRatio | [src] |
The baseVal getter
This API requires the following crate features to be activated: SvgAnimatedPreserveAspectRatio, SvgPreserveAspectRatio
impl SvgAnimatedPreserveAspectRatio[src]
impl SvgAnimatedPreserveAspectRatiopub fn anim_val(&self) -> SvgPreserveAspectRatio | [src] |
The animVal getter
This API requires the following crate features to be activated: SvgAnimatedPreserveAspectRatio, SvgPreserveAspectRatio