[−][src]Struct web_sys::SvgPathElement
The SVGPathElement object
This API requires the following crate features to be activated: SvgPathElement
Methods
impl SvgPathElement[src]
impl SvgPathElementpub fn get_path_seg_at_length(&self, distance: f32) -> u32 | [src] |
The getPathSegAtLength() method
This API requires the following crate features to be activated: SvgPathElement
impl SvgPathElement[src]
impl SvgPathElementpub fn path_seg_list(&self) -> SvgPathSegList | [src] |
The pathSegList getter
This API requires the following crate features to be activated: SvgPathElement, SvgPathSegList
impl SvgPathElement[src]
impl SvgPathElementpub fn animated_path_seg_list(&self) -> SvgPathSegList | [src] |
The animatedPathSegList getter
This API requires the following crate features to be activated: SvgPathElement, SvgPathSegList
Methods from Deref<Target = SvgGeometryElement>
pub fn get_point_at_length(&self, distance: f32) -> Result<SvgPoint, JsValue> | [src] |
The getPointAtLength() method
This API requires the following crate features to be activated: SvgGeometryElement, SvgPoint
pub fn get_total_length(&self) -> f32 | [src] |
The getTotalLength() method
This API requires the following crate features to be activated: SvgGeometryElement
pub fn path_length(&self) -> SvgAnimatedNumber | [src] |
The pathLength getter
This API requires the following crate features to be activated: SvgAnimatedNumber, SvgGeometryElement