pub struct UnderlyingSource { /* private fields */ }Expand description
The UnderlyingSource dictionary.
This API requires the following crate features to be activated: UnderlyingSource
Implementations
Sourceimpl UnderlyingSource
impl UnderlyingSource
pub fn get_auto_allocate_chunk_size(&self) -> Option<f64>
Sourceimpl UnderlyingSource
impl UnderlyingSource
pub fn set_auto_allocate_chunk_size(&self, val: f64)
Sourceimpl UnderlyingSource
impl UnderlyingSource
pub fn set_auto_allocate_chunk_size_u32(&self, val: u32)
Sourceimpl UnderlyingSource
impl UnderlyingSource
pub fn set_auto_allocate_chunk_size_f64(&self, val: f64)
Sourceimpl UnderlyingSource
impl UnderlyingSource
pub fn get_cancel(&self) -> Option<Function>
Sourceimpl UnderlyingSource
impl UnderlyingSource
pub fn set_cancel(&self, val: &Function)
Sourceimpl UnderlyingSource
impl UnderlyingSource
pub fn get_type(&self) -> Option<ReadableStreamType>
Sourceimpl UnderlyingSource
impl UnderlyingSource
pub fn set_type(&self, val: ReadableStreamType)
Sourceimpl UnderlyingSource
impl UnderlyingSource
Sourcepub fn new() -> Self
pub fn new() -> Self
Construct a new UnderlyingSource.
This API requires the following crate features to be activated: UnderlyingSource
pub fn auto_allocate_chunk_size(&mut self, val: f64) -> &mut Self
Use set_auto_allocate_chunk_size() instead.
pub fn cancel(&mut self, val: &Function) -> &mut Self
Use set_cancel() instead.
pub fn pull(&mut self, val: &Function) -> &mut Self
Use set_pull() instead.
pub fn start(&mut self, val: &Function) -> &mut Self
Use set_start() instead.
pub fn type_(&mut self, val: ReadableStreamType) -> &mut Self
Use set_type() instead.
Methods from Deref<Target = Object>
pub fn constructor(&self) -> Function
pub fn has_own_property(&self, property: &JsValue) -> bool
Use Object::hasOwn instead.
pub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn to_locale_string(&self) -> JsString
pub fn to_string(&self) -> JsString
pub fn to_js_string(&self) -> JsString
pub fn value_of(&self) -> Object
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Check if this value is null or undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.