Window

Struct Window 

pub struct Window { /* private fields */ }
The Window class.

MDN Documentation

This API requires the following crate features to be activated: Window

Implementations

Source

impl Window

pub fn window(&self) -> Window

Source

impl Window

pub fn self_(&self) -> Window

Source

impl Window

pub fn document(&self) -> Option<Document>

Source

impl Window

pub fn name(&self) -> Result<String, JsValue>

Source

impl Window

pub fn set_name(&self, value: &str) -> Result<(), JsValue>

Source

impl Window

pub fn location(&self) -> Location

Source

impl Window

pub fn history(&self) -> Result<History, JsValue>

Source

impl Window

pub fn status(&self) -> Result<String, JsValue>

Source

impl Window

pub fn set_status(&self, value: &str) -> Result<(), JsValue>

Source

impl Window

pub fn closed(&self) -> Result<bool, JsValue>

Source

impl Window

pub fn event(&self) -> JsValue

Source

impl Window

pub fn frames(&self) -> Result<Window, JsValue>

Source

impl Window

pub fn length(&self) -> u32

Source

impl Window

pub fn top(&self) -> Result<Option<Window>, JsValue>

Source

impl Window

pub fn opener(&self) -> Result<JsValue, JsValue>

Source

impl Window

pub fn set_opener(&self, value: &JsValue) -> Result<(), JsValue>

Source

impl Window

Source

impl Window

Source

impl Window

pub fn navigator(&self) -> Navigator

Source

impl Window

Source

impl Window

pub fn set_onappinstalled(&self, value: Option<&Function>)

Source

impl Window

pub fn screen(&self) -> Result<Screen, JsValue>

Source

impl Window

Source

impl Window

Source

impl Window

pub fn set_inner_width(&self, value: &JsValue) -> Result<(), JsValue>

Source

impl Window

Source

impl Window

pub fn set_inner_height(&self, value: &JsValue) -> Result<(), JsValue>

Source

impl Window

pub fn scroll_x(&self) -> Result<f64, JsValue>

Source

impl Window

Source

impl Window

pub fn scroll_y(&self) -> Result<f64, JsValue>

Source

impl Window

Source

impl Window

Source

impl Window

pub fn set_screen_x(&self, value: &JsValue) -> Result<(), JsValue>

Source

impl Window

Source

impl Window

pub fn set_screen_y(&self, value: &JsValue) -> Result<(), JsValue>

Source

impl Window

Source

impl Window

pub fn set_outer_width(&self, value: &JsValue) -> Result<(), JsValue>

Source

impl Window

Source

impl Window

pub fn set_outer_height(&self, value: &JsValue) -> Result<(), JsValue>

Source

impl Window

pub fn device_pixel_ratio(&self) -> f64

Source

impl Window

pub fn orientation(&self) -> i16

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

pub fn crypto(&self) -> Result<Crypto, JsValue>

Source

impl Window

pub fn onabort(&self) -> Option<Function>

Source

impl Window

pub fn set_onabort(&self, value: Option<&Function>)

Source

impl Window

pub fn onblur(&self) -> Option<Function>

Source

impl Window

pub fn set_onblur(&self, value: Option<&Function>)

Source

impl Window

pub fn onfocus(&self) -> Option<Function>

Source

impl Window

pub fn set_onfocus(&self, value: Option<&Function>)

Source

impl Window

pub fn oncancel(&self) -> Option<Function>

Source

impl Window

pub fn set_oncancel(&self, value: Option<&Function>)

Source

impl Window

pub fn onauxclick(&self) -> Option<Function>

Source

impl Window

pub fn set_onauxclick(&self, value: Option<&Function>)

Source

impl Window

Source

impl Window

pub fn set_onbeforetoggle(&self, value: Option<&Function>)

Source

impl Window

pub fn oncanplay(&self) -> Option<Function>

Source

impl Window

pub fn set_oncanplay(&self, value: Option<&Function>)

Source

impl Window

Source

impl Window

Source

impl Window

pub fn onchange(&self) -> Option<Function>

Source

impl Window

pub fn set_onchange(&self, value: Option<&Function>)

Source

impl Window

pub fn onclick(&self) -> Option<Function>

Source

impl Window

pub fn set_onclick(&self, value: Option<&Function>)

Source

impl Window

pub fn onclose(&self) -> Option<Function>

Source

impl Window

pub fn set_onclose(&self, value: Option<&Function>)

Source

impl Window

Source

impl Window

pub fn set_oncontextmenu(&self, value: Option<&Function>)

Source

impl Window

pub fn ondblclick(&self) -> Option<Function>

Source

impl Window

pub fn set_ondblclick(&self, value: Option<&Function>)

Source

impl Window

pub fn ondrag(&self) -> Option<Function>

Source

impl Window

pub fn set_ondrag(&self, value: Option<&Function>)

Source

impl Window

pub fn ondragend(&self) -> Option<Function>

Source

impl Window

pub fn set_ondragend(&self, value: Option<&Function>)

Source

impl Window

Source

impl Window

pub fn set_ondragenter(&self, value: Option<&Function>)

Source

impl Window

pub fn ondragexit(&self) -> Option<Function>

Source

impl Window

pub fn set_ondragexit(&self, value: Option<&Function>)

Source

impl Window

Source

impl Window

pub fn set_ondragleave(&self, value: Option<&Function>)

Source

impl Window

pub fn ondragover(&self) -> Option<Function>

Source

impl Window

pub fn set_ondragover(&self, value: Option<&Function>)

Source

impl Window

Source

impl Window

pub fn set_ondragstart(&self, value: Option<&Function>)

Source

impl Window

pub fn ondrop(&self) -> Option<Function>

Source

impl Window

pub fn set_ondrop(&self, value: Option<&Function>)

Source

impl Window

Source

impl Window

Source

impl Window

pub fn onemptied(&self) -> Option<Function>

Source

impl Window

pub fn set_onemptied(&self, value: Option<&Function>)

Source

impl Window

pub fn onended(&self) -> Option<Function>

Source

impl Window

pub fn set_onended(&self, value: Option<&Function>)

Source

impl Window

pub fn oninput(&self) -> Option<Function>

Source

impl Window

pub fn set_oninput(&self, value: Option<&Function>)

Source

impl Window

Source

impl Window

pub fn set_onbeforeinput(&self, value: Option<&Function>)

Source

impl Window

pub fn oninvalid(&self) -> Option<Function>

Source

impl Window

pub fn set_oninvalid(&self, value: Option<&Function>)

Source

impl Window

pub fn onkeydown(&self) -> Option<Function>

Source

impl Window

pub fn set_onkeydown(&self, value: Option<&Function>)

Source

impl Window

pub fn onkeypress(&self) -> Option<Function>

Source

impl Window

pub fn set_onkeypress(&self, value: Option<&Function>)

Source

impl Window

pub fn onkeyup(&self) -> Option<Function>

Source

impl Window

pub fn set_onkeyup(&self, value: Option<&Function>)

Source

impl Window

pub fn onload(&self) -> Option<Function>

Source

impl Window

pub fn set_onload(&self, value: Option<&Function>)

Source

impl Window

Source

impl Window

pub fn set_onloadeddata(&self, value: Option<&Function>)

Source

impl Window

Source

impl Window

Source

impl Window

pub fn onloadend(&self) -> Option<Function>

Source

impl Window

pub fn set_onloadend(&self, value: Option<&Function>)

Source

impl Window

Source

impl Window

pub fn set_onloadstart(&self, value: Option<&Function>)

Source

impl Window

Source

impl Window

pub fn set_onmousedown(&self, value: Option<&Function>)

Source

impl Window

Source

impl Window

pub fn set_onmouseenter(&self, value: Option<&Function>)

Source

impl Window

Source

impl Window

pub fn set_onmouseleave(&self, value: Option<&Function>)

Source

impl Window

Source

impl Window

pub fn set_onmousemove(&self, value: Option<&Function>)

Source

impl Window

pub fn onmouseout(&self) -> Option<Function>

Source

impl Window

pub fn set_onmouseout(&self, value: Option<&Function>)

Source

impl Window

Source

impl Window

pub fn set_onmouseover(&self, value: Option<&Function>)

Source

impl Window

pub fn onmouseup(&self) -> Option<Function>

Source

impl Window

pub fn set_onmouseup(&self, value: Option<&Function>)

Source

impl Window

pub fn onwheel(&self) -> Option<Function>

Source

impl Window

pub fn set_onwheel(&self, value: Option<&Function>)

Source

impl Window

pub fn onpause(&self) -> Option<Function>

Source

impl Window

pub fn set_onpause(&self, value: Option<&Function>)

Source

impl Window

pub fn onplay(&self) -> Option<Function>

Source

impl Window

pub fn set_onplay(&self, value: Option<&Function>)

Source

impl Window

pub fn onplaying(&self) -> Option<Function>

Source

impl Window

pub fn set_onplaying(&self, value: Option<&Function>)

Source

impl Window

pub fn onprogress(&self) -> Option<Function>

Source

impl Window

pub fn set_onprogress(&self, value: Option<&Function>)

Source

impl Window

Source

impl Window

pub fn set_onratechange(&self, value: Option<&Function>)

Source

impl Window

pub fn onreset(&self) -> Option<Function>

Source

impl Window

pub fn set_onreset(&self, value: Option<&Function>)

Source

impl Window

pub fn onresize(&self) -> Option<Function>

Source

impl Window

pub fn set_onresize(&self, value: Option<&Function>)

Source

impl Window

pub fn onscroll(&self) -> Option<Function>

Source

impl Window

pub fn set_onscroll(&self, value: Option<&Function>)

Source

impl Window

pub fn onseeked(&self) -> Option<Function>

Source

impl Window

pub fn set_onseeked(&self, value: Option<&Function>)

Source

impl Window

pub fn onseeking(&self) -> Option<Function>

Source

impl Window

pub fn set_onseeking(&self, value: Option<&Function>)

Source

impl Window

pub fn onselect(&self) -> Option<Function>

Source

impl Window

pub fn set_onselect(&self, value: Option<&Function>)

Source

impl Window

pub fn onshow(&self) -> Option<Function>

Source

impl Window

pub fn set_onshow(&self, value: Option<&Function>)

Source

impl Window

pub fn onstalled(&self) -> Option<Function>

Source

impl Window

pub fn set_onstalled(&self, value: Option<&Function>)

Source

impl Window

pub fn onsubmit(&self) -> Option<Function>

Source

impl Window

pub fn set_onsubmit(&self, value: Option<&Function>)

Source

impl Window

pub fn onsuspend(&self) -> Option<Function>

Source

impl Window

pub fn set_onsuspend(&self, value: Option<&Function>)

Source

impl Window

Source

impl Window

pub fn set_ontimeupdate(&self, value: Option<&Function>)

Source

impl Window

Source

impl Window

pub fn set_onvolumechange(&self, value: Option<&Function>)

Source

impl Window

pub fn onwaiting(&self) -> Option<Function>

Source

impl Window

pub fn set_onwaiting(&self, value: Option<&Function>)

Source

impl Window

Source

impl Window

pub fn set_onselectstart(&self, value: Option<&Function>)

Source

impl Window

pub fn ontoggle(&self) -> Option<Function>

Source

impl Window

pub fn set_ontoggle(&self, value: Option<&Function>)

Source

impl Window

Source

impl Window

pub fn set_onpointercancel(&self, value: Option<&Function>)

Source

impl Window

Source

impl Window

pub fn set_onpointerdown(&self, value: Option<&Function>)

Source

impl Window

Source

impl Window

pub fn set_onpointerup(&self, value: Option<&Function>)

Source

impl Window

Source

impl Window

pub fn set_onpointermove(&self, value: Option<&Function>)

Source

impl Window

Source

impl Window

pub fn set_onpointerout(&self, value: Option<&Function>)

Source

impl Window

Source

impl Window

pub fn set_onpointerover(&self, value: Option<&Function>)

Source

impl Window

Source

impl Window

pub fn set_onpointerenter(&self, value: Option<&Function>)

Source

impl Window

Source

impl Window

pub fn set_onpointerleave(&self, value: Option<&Function>)

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

pub fn set_onanimationend(&self, value: Option<&Function>)

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

pub fn set_ontransitionend(&self, value: Option<&Function>)

Source

impl Window

Source

impl Window

pub fn set_ontransitionrun(&self, value: Option<&Function>)

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

pub fn onerror(&self) -> Option<Function>

Source

impl Window

pub fn set_onerror(&self, value: Option<&Function>)

Source

impl Window

Source

impl Window

pub fn set_ontouchstart(&self, value: Option<&Function>)

Source

impl Window

pub fn ontouchend(&self) -> Option<Function>

Source

impl Window

pub fn set_ontouchend(&self, value: Option<&Function>)

Source

impl Window

Source

impl Window

pub fn set_ontouchmove(&self, value: Option<&Function>)

Source

impl Window

Source

impl Window

pub fn set_ontouchcancel(&self, value: Option<&Function>)

Source

impl Window

Source

impl Window

pub fn set_onafterprint(&self, value: Option<&Function>)

Source

impl Window

Source

impl Window

pub fn set_onbeforeprint(&self, value: Option<&Function>)

Source

impl Window

Source

impl Window

pub fn set_onbeforeunload(&self, value: Option<&Function>)

Source

impl Window

Source

impl Window

pub fn set_onhashchange(&self, value: Option<&Function>)

Source

impl Window

Source

impl Window

Source

impl Window

pub fn onmessage(&self) -> Option<Function>

Source

impl Window

pub fn set_onmessage(&self, value: Option<&Function>)

Source

impl Window

Source

impl Window

pub fn set_onmessageerror(&self, value: Option<&Function>)

Source

impl Window

pub fn onoffline(&self) -> Option<Function>

Source

impl Window

pub fn set_onoffline(&self, value: Option<&Function>)

Source

impl Window

pub fn ononline(&self) -> Option<Function>

Source

impl Window

pub fn set_ononline(&self, value: Option<&Function>)

Source

impl Window

pub fn onpagehide(&self) -> Option<Function>

Source

impl Window

pub fn set_onpagehide(&self, value: Option<&Function>)

Source

impl Window

pub fn onpageshow(&self) -> Option<Function>

Source

impl Window

pub fn set_onpageshow(&self, value: Option<&Function>)

Source

impl Window

pub fn onpopstate(&self) -> Option<Function>

Source

impl Window

pub fn set_onpopstate(&self, value: Option<&Function>)

Source

impl Window

pub fn onstorage(&self) -> Option<Function>

Source

impl Window

pub fn set_onstorage(&self, value: Option<&Function>)

Source

impl Window

pub fn onunload(&self) -> Option<Function>

Source

impl Window

pub fn set_onunload(&self, value: Option<&Function>)

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

pub fn origin(&self) -> String

Source

impl Window

pub fn is_secure_context(&self) -> bool

Source

impl Window

Source

impl Window

Source

impl Window

pub fn alert(&self) -> Result<(), JsValue>

Source

impl Window

pub fn alert_with_message(&self, message: &str) -> Result<(), JsValue>

Source

impl Window

pub fn blur(&self) -> Result<(), JsValue>

Source

impl Window

pub fn cancel_idle_callback(&self, handle: u32)

Source

impl Window

pub fn capture_events(&self)

Source

impl Window

pub fn close(&self) -> Result<(), JsValue>

Source

impl Window

pub fn confirm(&self) -> Result<bool, JsValue>

Source

impl Window

pub fn confirm_with_message(&self, message: &str) -> Result<bool, JsValue>

Source

impl Window

pub fn focus(&self) -> Result<(), JsValue>

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

pub fn match_media( &self, query: &str, ) -> Result<Option<MediaQueryList>, JsValue>

Source

impl Window

pub fn move_by(&self, x: i32, y: i32) -> Result<(), JsValue>

Source

impl Window

pub fn move_to(&self, x: i32, y: i32) -> Result<(), JsValue>

Source

impl Window

pub fn open(&self) -> Result<Option<Window>, JsValue>

Source

impl Window

pub fn open_with_url(&self, url: &str) -> Result<Option<Window>, JsValue>

Source

impl Window

pub fn open_with_url_and_target( &self, url: &str, target: &str, ) -> Result<Option<Window>, JsValue>

Source

impl Window

pub fn open_with_url_and_target_and_features( &self, url: &str, target: &str, features: &str, ) -> Result<Option<Window>, JsValue>

Source

impl Window

pub fn post_message( &self, message: &JsValue, target_origin: &str, ) -> Result<(), JsValue>

Source

impl Window

pub fn post_message_with_transfer( &self, message: &JsValue, target_origin: &str, transfer: &JsValue, ) -> Result<(), JsValue>

Source

impl Window

pub fn print(&self) -> Result<(), JsValue>

Source

impl Window

Source

impl Window

pub fn prompt_with_message( &self, message: &str, ) -> Result<Option<String>, JsValue>

Source

impl Window

pub fn prompt_with_message_and_default( &self, message: &str, _default: &str, ) -> Result<Option<String>, JsValue>

Source

impl Window

pub fn release_events(&self)

Source

impl Window

pub fn request_idle_callback(&self, callback: &Function) -> Result<u32, JsValue>

Source

impl Window

pub fn resize_by(&self, x: i32, y: i32) -> Result<(), JsValue>

Source

impl Window

pub fn resize_to(&self, x: i32, y: i32) -> Result<(), JsValue>

Source

impl Window

pub fn scroll_with_x_and_y(&self, x: f64, y: f64)

Source

impl Window

pub fn scroll(&self)

Source

impl Window

Source

impl Window

pub fn scroll_by_with_x_and_y(&self, x: f64, y: f64)

Source

impl Window

pub fn scroll_by(&self)

Source

impl Window

Source

impl Window

pub fn scroll_to_with_x_and_y(&self, x: f64, y: f64)

Source

impl Window

pub fn scroll_to(&self)

Source

impl Window

Source

impl Window

pub fn stop(&self) -> Result<(), JsValue>

Source

impl Window

pub fn get(&self, name: &str) -> Option<Object>

Source

impl Window

pub fn cancel_animation_frame(&self, handle: i32) -> Result<(), JsValue>

Source

impl Window

pub fn request_animation_frame( &self, callback: &Function, ) -> Result<i32, JsValue>

Source

impl Window

pub fn atob(&self, atob: &str) -> Result<String, JsValue>

Source

impl Window

pub fn btoa(&self, btoa: &str) -> Result<String, JsValue>

Source

impl Window

pub fn clear_interval(&self)

Source

impl Window

pub fn clear_interval_with_handle(&self, handle: i32)

Source

impl Window

pub fn clear_timeout(&self)

Source

impl Window

pub fn clear_timeout_with_handle(&self, handle: i32)

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

Source

impl Window

pub fn fetch_with_request(&self, input: &Request) -> Promise

Source

impl Window

pub fn fetch_with_str(&self, input: &str) -> Promise

Source

impl Window

pub fn fetch_with_request_and_init( &self, input: &Request, init: &RequestInit, ) -> Promise

Source

impl Window

pub fn fetch_with_str_and_init( &self, input: &str, init: &RequestInit, ) -> Promise

Source

impl Window

pub fn queue_microtask(&self, callback: &Function)

Source

impl Window

Source

impl Window

pub fn set_interval_with_callback_and_timeout_and_arguments( &self, handler: &Function, timeout: i32, _arguments: &Array, ) -> Result<i32, JsValue>

Source

impl Window

Source

impl Window

pub fn set_interval_with_callback_and_timeout_and_arguments_1( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, ) -> Result<i32, JsValue>

Source

impl Window

pub fn set_interval_with_callback_and_timeout_and_arguments_2( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, ) -> Result<i32, JsValue>

Source

impl Window

pub fn set_interval_with_callback_and_timeout_and_arguments_3( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, arguments_3: &JsValue, ) -> Result<i32, JsValue>

Source

impl Window

pub fn set_interval_with_callback_and_timeout_and_arguments_4( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, arguments_3: &JsValue, arguments_4: &JsValue, ) -> Result<i32, JsValue>

Source

impl Window

pub fn set_interval_with_callback_and_timeout_and_arguments_5( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, arguments_3: &JsValue, arguments_4: &JsValue, arguments_5: &JsValue, ) -> Result<i32, JsValue>

Source

impl Window

pub fn set_interval_with_callback_and_timeout_and_arguments_6( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, arguments_3: &JsValue, arguments_4: &JsValue, arguments_5: &JsValue, arguments_6: &JsValue, ) -> Result<i32, JsValue>

Source

impl Window

pub fn set_interval_with_callback_and_timeout_and_arguments_7( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, arguments_3: &JsValue, arguments_4: &JsValue, arguments_5: &JsValue, arguments_6: &JsValue, arguments_7: &JsValue, ) -> Result<i32, JsValue>

Source

impl Window

pub fn set_interval_with_str(&self, handler: &str) -> Result<i32, JsValue>

Source

impl Window

pub fn set_interval_with_str_and_timeout_and_unused( &self, handler: &str, timeout: i32, unused: &Array, ) -> Result<i32, JsValue>

Source

impl Window

Source

impl Window

pub fn set_interval_with_str_and_timeout_and_unused_1( &self, handler: &str, timeout: i32, unused_1: &JsValue, ) -> Result<i32, JsValue>

Source

impl Window

pub fn set_interval_with_str_and_timeout_and_unused_2( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, ) -> Result<i32, JsValue>

Source

impl Window

pub fn set_interval_with_str_and_timeout_and_unused_3( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, unused_3: &JsValue, ) -> Result<i32, JsValue>

Source

impl Window

pub fn set_interval_with_str_and_timeout_and_unused_4( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, unused_3: &JsValue, unused_4: &JsValue, ) -> Result<i32, JsValue>

Source

impl Window

pub fn set_interval_with_str_and_timeout_and_unused_5( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, unused_3: &JsValue, unused_4: &JsValue, unused_5: &JsValue, ) -> Result<i32, JsValue>

Source

impl Window

pub fn set_interval_with_str_and_timeout_and_unused_6( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, unused_3: &JsValue, unused_4: &JsValue, unused_5: &JsValue, unused_6: &JsValue, ) -> Result<i32, JsValue>

Source

impl Window

pub fn set_interval_with_str_and_timeout_and_unused_7( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, unused_3: &JsValue, unused_4: &JsValue, unused_5: &JsValue, unused_6: &JsValue, unused_7: &JsValue, ) -> Result<i32, JsValue>

Source

impl Window

pub fn set_timeout_with_callback( &self, handler: &Function, ) -> Result<i32, JsValue>

Source

impl Window

pub fn set_timeout_with_callback_and_timeout_and_arguments( &self, handler: &Function, timeout: i32, _arguments: &Array, ) -> Result<i32, JsValue>

Source

impl Window

Source

impl Window

pub fn set_timeout_with_callback_and_timeout_and_arguments_1( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, ) -> Result<i32, JsValue>

Source

impl Window

pub fn set_timeout_with_callback_and_timeout_and_arguments_2( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, ) -> Result<i32, JsValue>

Source

impl Window

pub fn set_timeout_with_callback_and_timeout_and_arguments_3( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, arguments_3: &JsValue, ) -> Result<i32, JsValue>

Source

impl Window

pub fn set_timeout_with_callback_and_timeout_and_arguments_4( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, arguments_3: &JsValue, arguments_4: &JsValue, ) -> Result<i32, JsValue>

Source

impl Window

pub fn set_timeout_with_callback_and_timeout_and_arguments_5( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, arguments_3: &JsValue, arguments_4: &JsValue, arguments_5: &JsValue, ) -> Result<i32, JsValue>

Source

impl Window

pub fn set_timeout_with_callback_and_timeout_and_arguments_6( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, arguments_3: &JsValue, arguments_4: &JsValue, arguments_5: &JsValue, arguments_6: &JsValue, ) -> Result<i32, JsValue>

Source

impl Window

pub fn set_timeout_with_callback_and_timeout_and_arguments_7( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, arguments_3: &JsValue, arguments_4: &JsValue, arguments_5: &JsValue, arguments_6: &JsValue, arguments_7: &JsValue, ) -> Result<i32, JsValue>

Source

impl Window

pub fn set_timeout_with_str(&self, handler: &str) -> Result<i32, JsValue>

Source

impl Window

pub fn set_timeout_with_str_and_timeout_and_unused( &self, handler: &str, timeout: i32, unused: &Array, ) -> Result<i32, JsValue>

Source

impl Window

Source

impl Window

pub fn set_timeout_with_str_and_timeout_and_unused_1( &self, handler: &str, timeout: i32, unused_1: &JsValue, ) -> Result<i32, JsValue>

Source

impl Window

pub fn set_timeout_with_str_and_timeout_and_unused_2( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, ) -> Result<i32, JsValue>

Source

impl Window

pub fn set_timeout_with_str_and_timeout_and_unused_3( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, unused_3: &JsValue, ) -> Result<i32, JsValue>

Source

impl Window

pub fn set_timeout_with_str_and_timeout_and_unused_4( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, unused_3: &JsValue, unused_4: &JsValue, ) -> Result<i32, JsValue>

Source

impl Window

pub fn set_timeout_with_str_and_timeout_and_unused_5( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, unused_3: &JsValue, unused_4: &JsValue, unused_5: &JsValue, ) -> Result<i32, JsValue>

Source

impl Window

pub fn set_timeout_with_str_and_timeout_and_unused_6( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, unused_3: &JsValue, unused_4: &JsValue, unused_5: &JsValue, unused_6: &JsValue, ) -> Result<i32, JsValue>

Source

impl Window

pub fn set_timeout_with_str_and_timeout_and_unused_7( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, unused_3: &JsValue, unused_4: &JsValue, unused_5: &JsValue, unused_6: &JsValue, unused_7: &JsValue, ) -> Result<i32, JsValue>

Methods from Deref<Target = EventTarget>

pub fn add_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>

pub fn add_event_listener_with_event_listener( &self, type_: &str, listener: &EventListener, ) -> Result<(), JsValue>

pub fn add_event_listener_with_callback_and_add_event_listener_options( &self, type_: &str, listener: &Function, options: &AddEventListenerOptions, ) -> Result<(), JsValue>

pub fn add_event_listener_with_event_listener_and_add_event_listener_options( &self, type_: &str, listener: &EventListener, options: &AddEventListenerOptions, ) -> Result<(), JsValue>

pub fn add_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>

pub fn add_event_listener_with_event_listener_and_bool( &self, type_: &str, listener: &EventListener, options: bool, ) -> Result<(), JsValue>

pub fn add_event_listener_with_callback_and_add_event_listener_options_and_wants_untrusted( &self, type_: &str, listener: &Function, options: &AddEventListenerOptions, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>

pub fn add_event_listener_with_event_listener_and_add_event_listener_options_and_wants_untrusted( &self, type_: &str, listener: &EventListener, options: &AddEventListenerOptions, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>

pub fn add_event_listener_with_callback_and_bool_and_wants_untrusted( &self, type_: &str, listener: &Function, options: bool, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>

pub fn add_event_listener_with_event_listener_and_bool_and_wants_untrusted( &self, type_: &str, listener: &EventListener, options: bool, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>

pub fn dispatch_event(&self, event: &Event) -> Result<bool, JsValue>

pub fn remove_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>

pub fn remove_event_listener_with_event_listener( &self, type_: &str, listener: &EventListener, ) -> Result<(), JsValue>

pub fn remove_event_listener_with_callback_and_event_listener_options( &self, type_: &str, listener: &Function, options: &EventListenerOptions, ) -> Result<(), JsValue>

pub fn remove_event_listener_with_event_listener_and_event_listener_options( &self, type_: &str, listener: &EventListener, options: &EventListenerOptions, ) -> Result<(), JsValue>

pub fn remove_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>

pub fn remove_event_listener_with_event_listener_and_bool( &self, type_: &str, listener: &EventListener, options: bool, ) -> Result<(), JsValue>

Methods from Deref<Target = Object>

pub fn constructor(&self) -> Function

pub fn has_own_property(&self, property: &JsValue) -> bool

👎Deprecated:

Use Object::hasOwn instead.

pub fn is_prototype_of(&self, value: &JsValue) -> bool

pub fn property_is_enumerable(&self, property: &JsValue) -> bool

pub fn to_locale_string(&self) -> JsString

pub fn to_string(&self) -> JsString

pub fn to_js_string(&self) -> JsString

pub fn value_of(&self) -> Object

Methods from Deref<Target = JsValue>

pub const NULL: JsValue

pub const UNDEFINED: JsValue

pub const TRUE: JsValue

pub const FALSE: JsValue

pub fn unchecked_into_f64(&self) -> f64

Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.

pub fn has_type<T>(&self) -> bool
where T: JsCast,

Check if this value is an instance of a specific JS type.

pub fn checked_div(&self, rhs: &JsValue) -> JsValue

Checked division.

pub fn pow(&self, rhs: &JsValue) -> JsValue

Power operation.

pub fn bit_and(&self, rhs: &JsValue) -> JsValue

Bitwise AND.

pub fn bit_or(&self, rhs: &JsValue) -> JsValue

Bitwise OR.

pub fn bit_xor(&self, rhs: &JsValue) -> JsValue

Bitwise XOR.

pub fn bit_not(&self) -> JsValue

Bitwise NOT.

pub fn shl(&self, rhs: &JsValue) -> JsValue

Left shift.

pub fn shr(&self, rhs: &JsValue) -> JsValue

Signed right shift.

pub fn unsigned_shr(&self, rhs: &JsValue) -> u32

Unsigned right shift.

pub fn add(&self, rhs: &JsValue) -> JsValue

Add.

pub fn sub(&self, rhs: &JsValue) -> JsValue

Subtract.

pub fn mul(&self, rhs: &JsValue) -> JsValue

Multiply.

pub fn div(&self, rhs: &JsValue) -> JsValue

Divide.

pub fn rem(&self, rhs: &JsValue) -> JsValue

Remainder.

pub fn neg(&self) -> JsValue

Negate.

pub fn lt(&self, other: &JsValue) -> bool

Less than comparison.

pub fn le(&self, other: &JsValue) -> bool

Less than or equal comparison.

pub fn gt(&self, other: &JsValue) -> bool

Greater than comparison.

pub fn ge(&self, other: &JsValue) -> bool

Greater than or equal comparison.

pub fn loose_eq(&self, other: &JsValue) -> bool

Loose equality (==).

pub fn is_falsy(&self) -> bool

Check if this value is a falsy value in JavaScript.

pub fn is_truthy(&self) -> bool

Check if this value is a truthy value in JavaScript.

pub fn is_object(&self) -> bool

Check if this value is an object.

pub fn is_function(&self) -> bool

Check if this value is a function.

pub fn is_string(&self) -> bool

Check if this value is a string.

pub fn is_symbol(&self) -> bool

Check if this value is a symbol.

pub fn is_bigint(&self) -> bool

Check if this value is a bigint.

pub fn is_array(&self) -> bool

Check if this value is an Array.

pub fn is_undefined(&self) -> bool

Check if this value is undefined.

pub fn is_null(&self) -> bool

Check if this value is null.

pub fn is_null_or_undefined(&self) -> bool

Check if this value is null or undefined.

pub fn js_typeof(&self) -> JsValue

Get the typeof this value as a string.

pub fn js_in(&self, obj: &JsValue) -> bool

Check if this value has a property with the given name.

pub fn as_bool(&self) -> Option<bool>

Get the value as a bool.

pub fn as_f64(&self) -> Option<f64>

Get the value as an f64.

pub fn as_string(&self) -> Option<String>

Get the value as a string.

pub fn as_debug_string(&self) -> String

Get a debug string representation of the value.