WorkerGlobalScope

Struct WorkerGlobalScope 

pub struct WorkerGlobalScope { /* private fields */ }
The WorkerGlobalScope class.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

Implementations

Source

impl WorkerGlobalScope

Source

impl WorkerGlobalScope

Source

impl WorkerGlobalScope

Source

impl WorkerGlobalScope

pub fn onerror(&self) -> Option<Function>

Source

impl WorkerGlobalScope

pub fn set_onerror(&self, value: Option<&Function>)

Source

impl WorkerGlobalScope

pub fn onoffline(&self) -> Option<Function>

Source

impl WorkerGlobalScope

pub fn set_onoffline(&self, value: Option<&Function>)

Source

impl WorkerGlobalScope

pub fn ononline(&self) -> Option<Function>

Source

impl WorkerGlobalScope

pub fn set_ononline(&self, value: Option<&Function>)

Source

impl WorkerGlobalScope

pub fn crypto(&self) -> Result<Crypto, JsValue>

Source

impl WorkerGlobalScope

Source

impl WorkerGlobalScope

Source

impl WorkerGlobalScope

pub fn origin(&self) -> String

Source

impl WorkerGlobalScope

pub fn is_secure_context(&self) -> bool

Source

impl WorkerGlobalScope

Source

impl WorkerGlobalScope

pub fn import_scripts(&self, urls: &Array) -> Result<(), JsValue>

Source

impl WorkerGlobalScope

Source

impl WorkerGlobalScope

pub fn import_scripts_1(&self, urls_1: &str) -> Result<(), JsValue>

Source

impl WorkerGlobalScope

pub fn import_scripts_2( &self, urls_1: &str, urls_2: &str, ) -> Result<(), JsValue>

Source

impl WorkerGlobalScope

pub fn import_scripts_3( &self, urls_1: &str, urls_2: &str, urls_3: &str, ) -> Result<(), JsValue>

Source

impl WorkerGlobalScope

pub fn import_scripts_4( &self, urls_1: &str, urls_2: &str, urls_3: &str, urls_4: &str, ) -> Result<(), JsValue>

Source

impl WorkerGlobalScope

pub fn import_scripts_5( &self, urls_1: &str, urls_2: &str, urls_3: &str, urls_4: &str, urls_5: &str, ) -> Result<(), JsValue>

Source

impl WorkerGlobalScope

pub fn import_scripts_6( &self, urls_1: &str, urls_2: &str, urls_3: &str, urls_4: &str, urls_5: &str, urls_6: &str, ) -> Result<(), JsValue>

Source

impl WorkerGlobalScope

pub fn import_scripts_7( &self, urls_1: &str, urls_2: &str, urls_3: &str, urls_4: &str, urls_5: &str, urls_6: &str, urls_7: &str, ) -> Result<(), JsValue>

Source

impl WorkerGlobalScope

pub fn atob(&self, atob: &str) -> Result<String, JsValue>

Source

impl WorkerGlobalScope

pub fn btoa(&self, btoa: &str) -> Result<String, JsValue>

Source

impl WorkerGlobalScope

pub fn clear_interval(&self)

Source

impl WorkerGlobalScope

pub fn clear_interval_with_handle(&self, handle: i32)

Source

impl WorkerGlobalScope

pub fn clear_timeout(&self)

Source

impl WorkerGlobalScope

pub fn clear_timeout_with_handle(&self, handle: i32)

Source

impl WorkerGlobalScope

Source

impl WorkerGlobalScope

Source

impl WorkerGlobalScope

Source

impl WorkerGlobalScope

Source

impl WorkerGlobalScope

Source

impl WorkerGlobalScope

Source

impl WorkerGlobalScope

Source

impl WorkerGlobalScope

Source

impl WorkerGlobalScope

Source

impl WorkerGlobalScope

Source

impl WorkerGlobalScope

Source

impl WorkerGlobalScope

Source

impl WorkerGlobalScope

Source

impl WorkerGlobalScope

Source

impl WorkerGlobalScope

Source

impl WorkerGlobalScope

Source

impl WorkerGlobalScope

Source

impl WorkerGlobalScope

Source

impl WorkerGlobalScope

Source

impl WorkerGlobalScope

Source

impl WorkerGlobalScope

Source

impl WorkerGlobalScope

Source

impl WorkerGlobalScope

Source

impl WorkerGlobalScope

Source

impl WorkerGlobalScope

Source

impl WorkerGlobalScope

Source

impl WorkerGlobalScope

Source

impl WorkerGlobalScope

Source

impl WorkerGlobalScope

pub fn fetch_with_request(&self, input: &Request) -> Promise

Source

impl WorkerGlobalScope

pub fn fetch_with_str(&self, input: &str) -> Promise

Source

impl WorkerGlobalScope

pub fn fetch_with_request_and_init( &self, input: &Request, init: &RequestInit, ) -> Promise

Source

impl WorkerGlobalScope

pub fn fetch_with_str_and_init( &self, input: &str, init: &RequestInit, ) -> Promise

Source

impl WorkerGlobalScope

pub fn queue_microtask(&self, callback: &Function)

Source

impl WorkerGlobalScope

Source

impl WorkerGlobalScope

pub fn set_interval_with_callback_and_timeout_and_arguments( &self, handler: &Function, timeout: i32, _arguments: &Array, ) -> Result<i32, JsValue>

Source

impl WorkerGlobalScope

Source

impl WorkerGlobalScope

pub fn set_interval_with_callback_and_timeout_and_arguments_1( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, ) -> Result<i32, JsValue>

Source

impl WorkerGlobalScope

pub fn set_interval_with_callback_and_timeout_and_arguments_2( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, ) -> Result<i32, JsValue>

Source

impl WorkerGlobalScope

pub fn set_interval_with_callback_and_timeout_and_arguments_3( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, arguments_3: &JsValue, ) -> Result<i32, JsValue>

Source

impl WorkerGlobalScope

pub fn set_interval_with_callback_and_timeout_and_arguments_4( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, arguments_3: &JsValue, arguments_4: &JsValue, ) -> Result<i32, JsValue>

Source

impl WorkerGlobalScope

pub fn set_interval_with_callback_and_timeout_and_arguments_5( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, arguments_3: &JsValue, arguments_4: &JsValue, arguments_5: &JsValue, ) -> Result<i32, JsValue>

Source

impl WorkerGlobalScope

pub fn set_interval_with_callback_and_timeout_and_arguments_6( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, arguments_3: &JsValue, arguments_4: &JsValue, arguments_5: &JsValue, arguments_6: &JsValue, ) -> Result<i32, JsValue>

Source

impl WorkerGlobalScope

pub fn set_interval_with_callback_and_timeout_and_arguments_7( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, arguments_3: &JsValue, arguments_4: &JsValue, arguments_5: &JsValue, arguments_6: &JsValue, arguments_7: &JsValue, ) -> Result<i32, JsValue>

Source

impl WorkerGlobalScope

pub fn set_interval_with_str(&self, handler: &str) -> Result<i32, JsValue>

Source

impl WorkerGlobalScope

pub fn set_interval_with_str_and_timeout_and_unused( &self, handler: &str, timeout: i32, unused: &Array, ) -> Result<i32, JsValue>

Source

impl WorkerGlobalScope

Source

impl WorkerGlobalScope

pub fn set_interval_with_str_and_timeout_and_unused_1( &self, handler: &str, timeout: i32, unused_1: &JsValue, ) -> Result<i32, JsValue>

Source

impl WorkerGlobalScope

pub fn set_interval_with_str_and_timeout_and_unused_2( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, ) -> Result<i32, JsValue>

Source

impl WorkerGlobalScope

pub fn set_interval_with_str_and_timeout_and_unused_3( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, unused_3: &JsValue, ) -> Result<i32, JsValue>

Source

impl WorkerGlobalScope

pub fn set_interval_with_str_and_timeout_and_unused_4( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, unused_3: &JsValue, unused_4: &JsValue, ) -> Result<i32, JsValue>

Source

impl WorkerGlobalScope

pub fn set_interval_with_str_and_timeout_and_unused_5( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, unused_3: &JsValue, unused_4: &JsValue, unused_5: &JsValue, ) -> Result<i32, JsValue>

Source

impl WorkerGlobalScope

pub fn set_interval_with_str_and_timeout_and_unused_6( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, unused_3: &JsValue, unused_4: &JsValue, unused_5: &JsValue, unused_6: &JsValue, ) -> Result<i32, JsValue>

Source

impl WorkerGlobalScope

pub fn set_interval_with_str_and_timeout_and_unused_7( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, unused_3: &JsValue, unused_4: &JsValue, unused_5: &JsValue, unused_6: &JsValue, unused_7: &JsValue, ) -> Result<i32, JsValue>

Source

impl WorkerGlobalScope

pub fn set_timeout_with_callback( &self, handler: &Function, ) -> Result<i32, JsValue>

Source

impl WorkerGlobalScope

pub fn set_timeout_with_callback_and_timeout_and_arguments( &self, handler: &Function, timeout: i32, _arguments: &Array, ) -> Result<i32, JsValue>

Source

impl WorkerGlobalScope

Source

impl WorkerGlobalScope

pub fn set_timeout_with_callback_and_timeout_and_arguments_1( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, ) -> Result<i32, JsValue>

Source

impl WorkerGlobalScope

pub fn set_timeout_with_callback_and_timeout_and_arguments_2( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, ) -> Result<i32, JsValue>

Source

impl WorkerGlobalScope

pub fn set_timeout_with_callback_and_timeout_and_arguments_3( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, arguments_3: &JsValue, ) -> Result<i32, JsValue>

Source

impl WorkerGlobalScope

pub fn set_timeout_with_callback_and_timeout_and_arguments_4( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, arguments_3: &JsValue, arguments_4: &JsValue, ) -> Result<i32, JsValue>

Source

impl WorkerGlobalScope

pub fn set_timeout_with_callback_and_timeout_and_arguments_5( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, arguments_3: &JsValue, arguments_4: &JsValue, arguments_5: &JsValue, ) -> Result<i32, JsValue>

Source

impl WorkerGlobalScope

pub fn set_timeout_with_callback_and_timeout_and_arguments_6( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, arguments_3: &JsValue, arguments_4: &JsValue, arguments_5: &JsValue, arguments_6: &JsValue, ) -> Result<i32, JsValue>

Source

impl WorkerGlobalScope

pub fn set_timeout_with_callback_and_timeout_and_arguments_7( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, arguments_3: &JsValue, arguments_4: &JsValue, arguments_5: &JsValue, arguments_6: &JsValue, arguments_7: &JsValue, ) -> Result<i32, JsValue>

Source

impl WorkerGlobalScope

pub fn set_timeout_with_str(&self, handler: &str) -> Result<i32, JsValue>

Source

impl WorkerGlobalScope

pub fn set_timeout_with_str_and_timeout_and_unused( &self, handler: &str, timeout: i32, unused: &Array, ) -> Result<i32, JsValue>

Source

impl WorkerGlobalScope

Source

impl WorkerGlobalScope

pub fn set_timeout_with_str_and_timeout_and_unused_1( &self, handler: &str, timeout: i32, unused_1: &JsValue, ) -> Result<i32, JsValue>

Source

impl WorkerGlobalScope

pub fn set_timeout_with_str_and_timeout_and_unused_2( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, ) -> Result<i32, JsValue>

Source

impl WorkerGlobalScope

pub fn set_timeout_with_str_and_timeout_and_unused_3( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, unused_3: &JsValue, ) -> Result<i32, JsValue>

Source

impl WorkerGlobalScope

pub fn set_timeout_with_str_and_timeout_and_unused_4( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, unused_3: &JsValue, unused_4: &JsValue, ) -> Result<i32, JsValue>

Source

impl WorkerGlobalScope

pub fn set_timeout_with_str_and_timeout_and_unused_5( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, unused_3: &JsValue, unused_4: &JsValue, unused_5: &JsValue, ) -> Result<i32, JsValue>

Source

impl WorkerGlobalScope

pub fn set_timeout_with_str_and_timeout_and_unused_6( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, unused_3: &JsValue, unused_4: &JsValue, unused_5: &JsValue, unused_6: &JsValue, ) -> Result<i32, JsValue>

Source

impl WorkerGlobalScope

pub fn set_timeout_with_str_and_timeout_and_unused_7( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, unused_3: &JsValue, unused_4: &JsValue, unused_5: &JsValue, unused_6: &JsValue, unused_7: &JsValue, ) -> Result<i32, JsValue>

Methods from Deref<Target = EventTarget>

pub fn add_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>

pub fn add_event_listener_with_event_listener( &self, type_: &str, listener: &EventListener, ) -> Result<(), JsValue>

pub fn add_event_listener_with_callback_and_add_event_listener_options( &self, type_: &str, listener: &Function, options: &AddEventListenerOptions, ) -> Result<(), JsValue>

pub fn add_event_listener_with_event_listener_and_add_event_listener_options( &self, type_: &str, listener: &EventListener, options: &AddEventListenerOptions, ) -> Result<(), JsValue>

pub fn add_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>

pub fn add_event_listener_with_event_listener_and_bool( &self, type_: &str, listener: &EventListener, options: bool, ) -> Result<(), JsValue>

pub fn add_event_listener_with_callback_and_add_event_listener_options_and_wants_untrusted( &self, type_: &str, listener: &Function, options: &AddEventListenerOptions, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>

pub fn add_event_listener_with_event_listener_and_add_event_listener_options_and_wants_untrusted( &self, type_: &str, listener: &EventListener, options: &AddEventListenerOptions, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>

pub fn add_event_listener_with_callback_and_bool_and_wants_untrusted( &self, type_: &str, listener: &Function, options: bool, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>

pub fn add_event_listener_with_event_listener_and_bool_and_wants_untrusted( &self, type_: &str, listener: &EventListener, options: bool, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>

pub fn dispatch_event(&self, event: &Event) -> Result<bool, JsValue>

pub fn remove_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>

pub fn remove_event_listener_with_event_listener( &self, type_: &str, listener: &EventListener, ) -> Result<(), JsValue>

pub fn remove_event_listener_with_callback_and_event_listener_options( &self, type_: &str, listener: &Function, options: &EventListenerOptions, ) -> Result<(), JsValue>

pub fn remove_event_listener_with_event_listener_and_event_listener_options( &self, type_: &str, listener: &EventListener, options: &EventListenerOptions, ) -> Result<(), JsValue>

pub fn remove_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>

pub fn remove_event_listener_with_event_listener_and_bool( &self, type_: &str, listener: &EventListener, options: bool, ) -> Result<(), JsValue>

Methods from Deref<Target = Object>

pub fn constructor(&self) -> Function

pub fn has_own_property(&self, property: &JsValue) -> bool

👎Deprecated:

Use Object::hasOwn instead.

pub fn is_prototype_of(&self, value: &JsValue) -> bool

pub fn property_is_enumerable(&self, property: &JsValue) -> bool

pub fn to_locale_string(&self) -> JsString

pub fn to_string(&self) -> JsString

pub fn to_js_string(&self) -> JsString

pub fn value_of(&self) -> Object

Methods from Deref<Target = JsValue>

pub const NULL: JsValue

pub const UNDEFINED: JsValue

pub const TRUE: JsValue

pub const FALSE: JsValue

pub fn unchecked_into_f64(&self) -> f64

Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.

pub fn has_type<T>(&self) -> bool
where T: JsCast,

Check if this value is an instance of a specific JS type.

pub fn checked_div(&self, rhs: &JsValue) -> JsValue

Checked division.

pub fn pow(&self, rhs: &JsValue) -> JsValue

Power operation.

pub fn bit_and(&self, rhs: &JsValue) -> JsValue

Bitwise AND.

pub fn bit_or(&self, rhs: &JsValue) -> JsValue

Bitwise OR.

pub fn bit_xor(&self, rhs: &JsValue) -> JsValue

Bitwise XOR.

pub fn bit_not(&self) -> JsValue

Bitwise NOT.

pub fn shl(&self, rhs: &JsValue) -> JsValue

Left shift.

pub fn shr(&self, rhs: &JsValue) -> JsValue

Signed right shift.

pub fn unsigned_shr(&self, rhs: &JsValue) -> u32

Unsigned right shift.

pub fn add(&self, rhs: &JsValue) -> JsValue

Add.

pub fn sub(&self, rhs: &JsValue) -> JsValue

Subtract.

pub fn mul(&self, rhs: &JsValue) -> JsValue

Multiply.

pub fn div(&self, rhs: &JsValue) -> JsValue

Divide.

pub fn rem(&self, rhs: &JsValue) -> JsValue

Remainder.

pub fn neg(&self) -> JsValue

Negate.

pub fn lt(&self, other: &JsValue) -> bool

Less than comparison.

pub fn le(&self, other: &JsValue) -> bool

Less than or equal comparison.

pub fn gt(&self, other: &JsValue) -> bool

Greater than comparison.

pub fn ge(&self, other: &JsValue) -> bool

Greater than or equal comparison.

pub fn loose_eq(&self, other: &JsValue) -> bool

Loose equality (==).

pub fn is_falsy(&self) -> bool

Check if this value is a falsy value in JavaScript.

pub fn is_truthy(&self) -> bool

Check if this value is a truthy value in JavaScript.

pub fn is_object(&self) -> bool

Check if this value is an object.

pub fn is_function(&self) -> bool

Check if this value is a function.

pub fn is_string(&self) -> bool

Check if this value is a string.

pub fn is_symbol(&self) -> bool

Check if this value is a symbol.

pub fn is_bigint(&self) -> bool

Check if this value is a bigint.

pub fn is_array(&self) -> bool

Check if this value is an Array.

pub fn is_undefined(&self) -> bool

Check if this value is undefined.

pub fn is_null(&self) -> bool

Check if this value is null.

pub fn is_null_or_undefined(&self) -> bool

Check if this value is null or undefined.

pub fn js_typeof(&self) -> JsValue

Get the typeof this value as a string.

pub fn js_in(&self, obj: &JsValue) -> bool

Check if this value has a property with the given name.

pub fn as_bool(&self) -> Option<bool>

Get the value as a bool.

pub fn as_f64(&self) -> Option<f64>

Get the value as an f64.

pub fn as_string(&self) -> Option<String>

Get the value as a string.

pub fn as_debug_string(&self) -> String

Get a debug string representation of the value.