pub struct XmlHttpRequest { /* private fields */ }Expand description
The XmlHttpRequest class.
This API requires the following crate features to be activated: XmlHttpRequest
Implementations
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
pub fn onreadystatechange(&self) -> Option<Function>
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
pub fn set_onreadystatechange(&self, value: Option<&Function>)
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
pub fn ready_state(&self) -> u16
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
pub fn set_timeout(&self, value: u32)
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
pub fn with_credentials(&self) -> bool
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
pub fn set_with_credentials(&self, value: bool)
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
pub fn response_url(&self) -> String
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
pub fn status_text(&self) -> Result<String, JsValue>
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
pub fn response_type(&self) -> XmlHttpRequestResponseType
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
pub fn set_response_type(&self, value: XmlHttpRequestResponseType)
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
pub fn new() -> Result<XmlHttpRequest, JsValue>
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
pub fn new_with_ignored(ignored: &str) -> Result<XmlHttpRequest, JsValue>
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
pub fn get_all_response_headers(&self) -> Result<String, JsValue>
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
pub fn send_with_opt_js_u8_array( &self, body: Option<&Uint8Array>, ) -> Result<(), JsValue>
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
pub fn send_with_opt_url_search_params( &self, body: Option<&UrlSearchParams>, ) -> Result<(), JsValue>
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
pub fn send_with_opt_readable_stream( &self, body: Option<&ReadableStream>, ) -> Result<(), JsValue>
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
Sourcepub const UNSENT: u16
pub const UNSENT: u16
The XMLHttpRequest.UNSENT const.
This API requires the following crate features to be activated: XmlHttpRequest
Sourcepub const OPENED: u16
pub const OPENED: u16
The XMLHttpRequest.OPENED const.
This API requires the following crate features to be activated: XmlHttpRequest
Sourcepub const HEADERS_RECEIVED: u16
pub const HEADERS_RECEIVED: u16
The XMLHttpRequest.HEADERS_RECEIVED const.
This API requires the following crate features to be activated: XmlHttpRequest
Methods from Deref<Target = XmlHttpRequestEventTarget>
pub fn onloadstart(&self) -> Option<Function>
pub fn set_onloadstart(&self, value: Option<&Function>)
pub fn onprogress(&self) -> Option<Function>
pub fn set_onprogress(&self, value: Option<&Function>)
pub fn onabort(&self) -> Option<Function>
pub fn set_onabort(&self, value: Option<&Function>)
pub fn onerror(&self) -> Option<Function>
pub fn set_onerror(&self, value: Option<&Function>)
pub fn onload(&self) -> Option<Function>
pub fn set_onload(&self, value: Option<&Function>)
pub fn ontimeout(&self) -> Option<Function>
pub fn set_ontimeout(&self, value: Option<&Function>)
pub fn onloadend(&self) -> Option<Function>
pub fn set_onloadend(&self, value: Option<&Function>)
Methods from Deref<Target = EventTarget>
pub fn add_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener( &self, type_: &str, listener: &EventListener, ) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_add_event_listener_options( &self, type_: &str, listener: &Function, options: &AddEventListenerOptions, ) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_add_event_listener_options( &self, type_: &str, listener: &EventListener, options: &AddEventListenerOptions, ) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_bool( &self, type_: &str, listener: &EventListener, options: bool, ) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_add_event_listener_options_and_wants_untrusted( &self, type_: &str, listener: &Function, options: &AddEventListenerOptions, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_add_event_listener_options_and_wants_untrusted( &self, type_: &str, listener: &EventListener, options: &AddEventListenerOptions, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_bool_and_wants_untrusted( &self, type_: &str, listener: &Function, options: bool, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_bool_and_wants_untrusted( &self, type_: &str, listener: &EventListener, options: bool, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>
pub fn dispatch_event(&self, event: &Event) -> Result<bool, JsValue>
pub fn remove_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>
pub fn remove_event_listener_with_event_listener( &self, type_: &str, listener: &EventListener, ) -> Result<(), JsValue>
pub fn remove_event_listener_with_callback_and_event_listener_options( &self, type_: &str, listener: &Function, options: &EventListenerOptions, ) -> Result<(), JsValue>
pub fn remove_event_listener_with_event_listener_and_event_listener_options( &self, type_: &str, listener: &EventListener, options: &EventListenerOptions, ) -> Result<(), JsValue>
pub fn remove_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>
pub fn remove_event_listener_with_event_listener_and_bool( &self, type_: &str, listener: &EventListener, options: bool, ) -> Result<(), JsValue>
Methods from Deref<Target = Object>
pub fn constructor(&self) -> Function
pub fn has_own_property(&self, property: &JsValue) -> bool
Use Object::hasOwn instead.
pub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn to_locale_string(&self) -> JsString
pub fn to_string(&self) -> JsString
pub fn to_js_string(&self) -> JsString
pub fn value_of(&self) -> Object
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Check if this value is null or undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.