GpuTextureFormat

Enum GpuTextureFormat 

#[non_exhaustive]
pub enum GpuTextureFormat {
Show 101 variants R8unorm = 0, R8snorm = 1, R8uint = 2, R8sint = 3, R16unorm = 4, R16snorm = 5, R16uint = 6, R16sint = 7, R16float = 8, Rg8unorm = 9, Rg8snorm = 10, Rg8uint = 11, Rg8sint = 12, R32uint = 13, R32sint = 14, R32float = 15, Rg16unorm = 16, Rg16snorm = 17, Rg16uint = 18, Rg16sint = 19, Rg16float = 20, Rgba8unorm = 21, Rgba8unormSrgb = 22, Rgba8snorm = 23, Rgba8uint = 24, Rgba8sint = 25, Bgra8unorm = 26, Bgra8unormSrgb = 27, Rgb9e5ufloat = 28, Rgb10a2uint = 29, Rgb10a2unorm = 30, Rg11b10ufloat = 31, Rg32uint = 32, Rg32sint = 33, Rg32float = 34, Rgba16unorm = 35, Rgba16snorm = 36, Rgba16uint = 37, Rgba16sint = 38, Rgba16float = 39, Rgba32uint = 40, Rgba32sint = 41, Rgba32float = 42, Stencil8 = 43, Depth16unorm = 44, Depth24plus = 45, Depth24plusStencil8 = 46, Depth32float = 47, Depth32floatStencil8 = 48, Bc1RgbaUnorm = 49, Bc1RgbaUnormSrgb = 50, Bc2RgbaUnorm = 51, Bc2RgbaUnormSrgb = 52, Bc3RgbaUnorm = 53, Bc3RgbaUnormSrgb = 54, Bc4RUnorm = 55, Bc4RSnorm = 56, Bc5RgUnorm = 57, Bc5RgSnorm = 58, Bc6hRgbUfloat = 59, Bc6hRgbFloat = 60, Bc7RgbaUnorm = 61, Bc7RgbaUnormSrgb = 62, Etc2Rgb8unorm = 63, Etc2Rgb8unormSrgb = 64, Etc2Rgb8a1unorm = 65, Etc2Rgb8a1unormSrgb = 66, Etc2Rgba8unorm = 67, Etc2Rgba8unormSrgb = 68, EacR11unorm = 69, EacR11snorm = 70, EacRg11unorm = 71, EacRg11snorm = 72, Astc4x4Unorm = 73, Astc4x4UnormSrgb = 74, Astc5x4Unorm = 75, Astc5x4UnormSrgb = 76, Astc5x5Unorm = 77, Astc5x5UnormSrgb = 78, Astc6x5Unorm = 79, Astc6x5UnormSrgb = 80, Astc6x6Unorm = 81, Astc6x6UnormSrgb = 82, Astc8x5Unorm = 83, Astc8x5UnormSrgb = 84, Astc8x6Unorm = 85, Astc8x6UnormSrgb = 86, Astc8x8Unorm = 87, Astc8x8UnormSrgb = 88, Astc10x5Unorm = 89, Astc10x5UnormSrgb = 90, Astc10x6Unorm = 91, Astc10x6UnormSrgb = 92, Astc10x8Unorm = 93, Astc10x8UnormSrgb = 94, Astc10x10Unorm = 95, Astc10x10UnormSrgb = 96, Astc12x10Unorm = 97, Astc12x10UnormSrgb = 98, Astc12x12Unorm = 99, Astc12x12UnormSrgb = 100,
}
The GpuTextureFormat enum.

This API requires the following crate features to be activated: GpuTextureFormat

This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as described in the wasm-bindgen guide

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


R8unorm = 0



R8snorm = 1



R8uint = 2



R8sint = 3



R16unorm = 4



R16snorm = 5



R16uint = 6



R16sint = 7



R16float = 8



Rg8unorm = 9



Rg8snorm = 10



Rg8uint = 11



Rg8sint = 12



R32uint = 13



R32sint = 14



R32float = 15



Rg16unorm = 16



Rg16snorm = 17



Rg16uint = 18



Rg16sint = 19



Rg16float = 20



Rgba8unorm = 21



Rgba8unormSrgb = 22



Rgba8snorm = 23



Rgba8uint = 24



Rgba8sint = 25



Bgra8unorm = 26



Bgra8unormSrgb = 27



Rgb9e5ufloat = 28



Rgb10a2uint = 29



Rgb10a2unorm = 30



Rg11b10ufloat = 31



Rg32uint = 32



Rg32sint = 33



Rg32float = 34



Rgba16unorm = 35



Rgba16snorm = 36



Rgba16uint = 37



Rgba16sint = 38



Rgba16float = 39



Rgba32uint = 40



Rgba32sint = 41



Rgba32float = 42



Stencil8 = 43



Depth16unorm = 44



Depth24plus = 45



Depth24plusStencil8 = 46



Depth32float = 47



Depth32floatStencil8 = 48



Bc1RgbaUnorm = 49



Bc1RgbaUnormSrgb = 50



Bc2RgbaUnorm = 51



Bc2RgbaUnormSrgb = 52



Bc3RgbaUnorm = 53



Bc3RgbaUnormSrgb = 54



Bc4RUnorm = 55



Bc4RSnorm = 56



Bc5RgUnorm = 57



Bc5RgSnorm = 58



Bc6hRgbUfloat = 59



Bc6hRgbFloat = 60



Bc7RgbaUnorm = 61



Bc7RgbaUnormSrgb = 62



Etc2Rgb8unorm = 63



Etc2Rgb8unormSrgb = 64



Etc2Rgb8a1unorm = 65



Etc2Rgb8a1unormSrgb = 66



Etc2Rgba8unorm = 67



Etc2Rgba8unormSrgb = 68



EacR11unorm = 69



EacR11snorm = 70



EacRg11unorm = 71



EacRg11snorm = 72



Astc4x4Unorm = 73



Astc4x4UnormSrgb = 74



Astc5x4Unorm = 75



Astc5x4UnormSrgb = 76



Astc5x5Unorm = 77



Astc5x5UnormSrgb = 78



Astc6x5Unorm = 79



Astc6x5UnormSrgb = 80



Astc6x6Unorm = 81



Astc6x6UnormSrgb = 82



Astc8x5Unorm = 83



Astc8x5UnormSrgb = 84



Astc8x6Unorm = 85



Astc8x6UnormSrgb = 86



Astc8x8Unorm = 87



Astc8x8UnormSrgb = 88



Astc10x5Unorm = 89



Astc10x5UnormSrgb = 90



Astc10x6Unorm = 91



Astc10x6UnormSrgb = 92



Astc10x8Unorm = 93



Astc10x8UnormSrgb = 94



Astc10x10Unorm = 95



Astc10x10UnormSrgb = 96



Astc12x10Unorm = 97



Astc12x10UnormSrgb = 98



Astc12x12Unorm = 99



Astc12x12UnormSrgb = 100

Implementations