pub struct Element { /* private fields */ }Expand description
The Element class.
This API requires the following crate features to be activated: Element
Implementations
Sourceimpl Element
impl Element
pub fn class_list(&self) -> DomTokenList
Sourceimpl Element
impl Element
pub fn attributes(&self) -> NamedNodeMap
Sourceimpl Element
impl Element
pub fn shadow_root(&self) -> Option<ShadowRoot>
Sourceimpl Element
impl Element
pub fn attach_shadow( &self, shadow_root_init_dict: &ShadowRootInit, ) -> Result<ShadowRoot, JsValue>
Sourceimpl Element
impl Element
pub fn get_elements_by_class_name(&self, class_names: &str) -> HtmlCollection
Sourceimpl Element
impl Element
pub fn get_elements_by_tag_name(&self, local_name: &str) -> HtmlCollection
Sourceimpl Element
impl Element
pub fn get_elements_by_tag_name_ns( &self, namespace: Option<&str>, local_name: &str, ) -> Result<HtmlCollection, JsValue>
Sourceimpl Element
impl Element
pub fn release_capture(&self)
Sourceimpl Element
impl Element
pub fn request_pointer_lock(&self)
Sourceimpl Element
impl Element
pub fn scroll_with_scroll_to_options(&self, options: &ScrollToOptions)
Sourceimpl Element
impl Element
pub fn scroll_by_with_scroll_to_options(&self, options: &ScrollToOptions)
Sourceimpl Element
impl Element
pub fn scroll_into_view(&self)
Sourceimpl Element
impl Element
pub fn scroll_into_view_with_scroll_into_view_options( &self, arg: &ScrollIntoViewOptions, )
Sourceimpl Element
impl Element
pub fn scroll_to_with_scroll_to_options(&self, options: &ScrollToOptions)
Sourceimpl Element
impl Element
pub fn set_capture(&self)
Sourceimpl Element
impl Element
pub fn set_capture_with_retarget_to_element(&self, retarget_to_element: bool)
Sourceimpl Element
impl Element
pub fn replace_children_with_node_0(&self)
Sourceimpl Element
impl Element
pub fn replace_children_with_node_3( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, )
Sourceimpl Element
impl Element
pub fn replace_children_with_str_0(&self)
Sourceimpl Element
impl Element
pub fn replace_children_with_str_3( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, )
Methods from Deref<Target = Node>
pub fn node_type(&self) -> u16
pub fn node_name(&self) -> String
pub fn base_uri(&self) -> Result<Option<String>, JsValue>
pub fn is_connected(&self) -> bool
pub fn owner_document(&self) -> Option<Document>
pub fn parent_node(&self) -> Option<Node>
pub fn parent_element(&self) -> Option<Element>
pub fn child_nodes(&self) -> NodeList
pub fn first_child(&self) -> Option<Node>
pub fn last_child(&self) -> Option<Node>
pub fn previous_sibling(&self) -> Option<Node>
pub fn next_sibling(&self) -> Option<Node>
pub fn node_value(&self) -> Option<String>
pub fn set_node_value(&self, value: Option<&str>)
pub fn text_content(&self) -> Option<String>
pub fn set_text_content(&self, value: Option<&str>)
pub fn append_child(&self, node: &Node) -> Result<Node, JsValue>
pub fn clone_node(&self) -> Result<Node, JsValue>
pub fn clone_node_with_deep(&self, deep: bool) -> Result<Node, JsValue>
pub fn compare_document_position(&self, other: &Node) -> u16
pub fn contains(&self, other: Option<&Node>) -> bool
pub fn get_root_node(&self) -> Node
pub fn has_child_nodes(&self) -> bool
pub fn insert_before( &self, node: &Node, child: Option<&Node>, ) -> Result<Node, JsValue>
pub fn is_default_namespace(&self, namespace: Option<&str>) -> bool
pub fn is_equal_node(&self, node: Option<&Node>) -> bool
pub fn is_same_node(&self, node: Option<&Node>) -> bool
pub fn lookup_namespace_uri(&self, prefix: Option<&str>) -> Option<String>
pub fn lookup_prefix(&self, namespace: Option<&str>) -> Option<String>
pub fn normalize(&self)
pub fn remove_child(&self, child: &Node) -> Result<Node, JsValue>
pub fn replace_child(&self, node: &Node, child: &Node) -> Result<Node, JsValue>
pub const ELEMENT_NODE: u16
pub const ATTRIBUTE_NODE: u16
pub const TEXT_NODE: u16
pub const CDATA_SECTION_NODE: u16
pub const ENTITY_REFERENCE_NODE: u16
pub const ENTITY_NODE: u16
pub const PROCESSING_INSTRUCTION_NODE: u16
pub const COMMENT_NODE: u16
pub const DOCUMENT_NODE: u16
pub const DOCUMENT_TYPE_NODE: u16
pub const DOCUMENT_FRAGMENT_NODE: u16
pub const NOTATION_NODE: u16
pub const DOCUMENT_POSITION_DISCONNECTED: u16
pub const DOCUMENT_POSITION_PRECEDING: u16
pub const DOCUMENT_POSITION_FOLLOWING: u16
pub const DOCUMENT_POSITION_CONTAINS: u16
pub const DOCUMENT_POSITION_CONTAINED_BY: u16
pub const DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC: u16
Methods from Deref<Target = EventTarget>
pub fn add_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener( &self, type_: &str, listener: &EventListener, ) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_add_event_listener_options( &self, type_: &str, listener: &Function, options: &AddEventListenerOptions, ) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_add_event_listener_options( &self, type_: &str, listener: &EventListener, options: &AddEventListenerOptions, ) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_bool( &self, type_: &str, listener: &EventListener, options: bool, ) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_add_event_listener_options_and_wants_untrusted( &self, type_: &str, listener: &Function, options: &AddEventListenerOptions, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_add_event_listener_options_and_wants_untrusted( &self, type_: &str, listener: &EventListener, options: &AddEventListenerOptions, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_bool_and_wants_untrusted( &self, type_: &str, listener: &Function, options: bool, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_bool_and_wants_untrusted( &self, type_: &str, listener: &EventListener, options: bool, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>
pub fn dispatch_event(&self, event: &Event) -> Result<bool, JsValue>
pub fn remove_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>
pub fn remove_event_listener_with_event_listener( &self, type_: &str, listener: &EventListener, ) -> Result<(), JsValue>
pub fn remove_event_listener_with_callback_and_event_listener_options( &self, type_: &str, listener: &Function, options: &EventListenerOptions, ) -> Result<(), JsValue>
pub fn remove_event_listener_with_event_listener_and_event_listener_options( &self, type_: &str, listener: &EventListener, options: &EventListenerOptions, ) -> Result<(), JsValue>
pub fn remove_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>
pub fn remove_event_listener_with_event_listener_and_bool( &self, type_: &str, listener: &EventListener, options: bool, ) -> Result<(), JsValue>
Methods from Deref<Target = Object>
pub fn constructor(&self) -> Function
pub fn has_own_property(&self, property: &JsValue) -> bool
👎Deprecated:
Use Object::hasOwn instead.
pub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn to_locale_string(&self) -> JsString
pub fn to_string(&self) -> JsString
pub fn to_js_string(&self) -> JsString
pub fn value_of(&self) -> Object
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Check if this value is null or undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.