Element

Struct Element 

pub struct Element { /* private fields */ }
The Element class.

MDN Documentation

This API requires the following crate features to be activated: Element

Implementations

Source

impl Element

Source

impl Element

pub fn prefix(&self) -> Option<String>

Source

impl Element

pub fn local_name(&self) -> String

Source

impl Element

pub fn tag_name(&self) -> String

Source

impl Element

pub fn id(&self) -> String

Source

impl Element

pub fn set_id(&self, value: &str)

Source

impl Element

pub fn class_name(&self) -> String

Source

impl Element

pub fn set_class_name(&self, value: &str)

Source

impl Element

Source

impl Element

Source

impl Element

pub fn scroll_width(&self) -> i32

Source

impl Element

pub fn scroll_height(&self) -> i32

Source

impl Element

pub fn client_top(&self) -> i32

Source

impl Element

pub fn client_left(&self) -> i32

Source

impl Element

pub fn client_width(&self) -> i32

Source

impl Element

pub fn client_height(&self) -> i32

Source

impl Element

pub fn inner_html(&self) -> String

Source

impl Element

pub fn set_inner_html(&self, value: &str)

Source

impl Element

pub fn outer_html(&self) -> String

Source

impl Element

pub fn set_outer_html(&self, value: &str)

Source

impl Element

Source

impl Element

pub fn slot(&self) -> String

Source

impl Element

pub fn set_slot(&self, value: &str)

Source

impl Element

pub fn scroll_top(&self) -> f64

Source

impl Element

pub fn set_scroll_top(&self, value: f64)

Source

impl Element

pub fn scroll_left(&self) -> f64

Source

impl Element

pub fn set_scroll_left(&self, value: f64)

Source

impl Element

Source

impl Element

Source

impl Element

Source

impl Element

Source

impl Element

Source

impl Element

Source

impl Element

pub fn attach_shadow( &self, shadow_root_init_dict: &ShadowRootInit, ) -> Result<ShadowRoot, JsValue>

Source

impl Element

pub fn closest(&self, selector: &str) -> Result<Option<Element>, JsValue>

Source

impl Element

pub fn get_attribute(&self, name: &str) -> Option<String>

Source

impl Element

pub fn get_attribute_ns( &self, namespace: Option<&str>, local_name: &str, ) -> Option<String>

Source

impl Element

Source

impl Element

pub fn get_attribute_node(&self, name: &str) -> Option<Attr>

Source

impl Element

pub fn get_attribute_node_ns( &self, namespace_uri: Option<&str>, local_name: &str, ) -> Option<Attr>

Source

impl Element

Source

impl Element

pub fn get_elements_by_class_name(&self, class_names: &str) -> HtmlCollection

Source

impl Element

pub fn get_elements_by_tag_name(&self, local_name: &str) -> HtmlCollection

Source

impl Element

pub fn get_elements_by_tag_name_ns( &self, namespace: Option<&str>, local_name: &str, ) -> Result<HtmlCollection, JsValue>

Source

impl Element

pub fn has_attribute(&self, name: &str) -> bool

Source

impl Element

pub fn has_attribute_ns( &self, namespace: Option<&str>, local_name: &str, ) -> bool

Source

impl Element

pub fn has_attributes(&self) -> bool

Source

impl Element

pub fn has_pointer_capture(&self, pointer_id: i32) -> bool

Source

impl Element

pub fn insert_adjacent_element( &self, where_: &str, element: &Element, ) -> Result<Option<Element>, JsValue>

Source

impl Element

pub fn insert_adjacent_html( &self, position: &str, text: &str, ) -> Result<(), JsValue>

Source

impl Element

pub fn insert_adjacent_text( &self, where_: &str, data: &str, ) -> Result<(), JsValue>

Source

impl Element

pub fn matches(&self, selector: &str) -> Result<bool, JsValue>

Source

impl Element

pub fn query_selector( &self, selectors: &str, ) -> Result<Option<Element>, JsValue>

Source

impl Element

pub fn query_selector_all(&self, selectors: &str) -> Result<NodeList, JsValue>

Source

impl Element

pub fn release_capture(&self)

Source

impl Element

pub fn release_pointer_capture(&self, pointer_id: i32) -> Result<(), JsValue>

Source

impl Element

pub fn remove_attribute(&self, name: &str) -> Result<(), JsValue>

Source

impl Element

pub fn remove_attribute_ns( &self, namespace: Option<&str>, local_name: &str, ) -> Result<(), JsValue>

Source

impl Element

pub fn remove_attribute_node( &self, old_attr: &Attr, ) -> Result<Option<Attr>, JsValue>

Source

impl Element

Source

impl Element

Source

impl Element

pub fn scroll_with_x_and_y(&self, x: f64, y: f64)

Source

impl Element

pub fn scroll(&self)

Source

impl Element

Source

impl Element

pub fn scroll_by_with_x_and_y(&self, x: f64, y: f64)

Source

impl Element

pub fn scroll_by(&self)

Source

impl Element

Source

impl Element

Source

impl Element

Source

impl Element

Source

impl Element

pub fn scroll_to_with_x_and_y(&self, x: f64, y: f64)

Source

impl Element

pub fn scroll_to(&self)

Source

impl Element

Source

impl Element

pub fn set_attribute(&self, name: &str, value: &str) -> Result<(), JsValue>

Source

impl Element

pub fn set_attribute_ns( &self, namespace: Option<&str>, name: &str, value: &str, ) -> Result<(), JsValue>

Source

impl Element

pub fn set_attribute_node( &self, new_attr: &Attr, ) -> Result<Option<Attr>, JsValue>

Source

impl Element

pub fn set_attribute_node_ns( &self, new_attr: &Attr, ) -> Result<Option<Attr>, JsValue>

Source

impl Element

pub fn set_capture(&self)

Source

impl Element

pub fn set_capture_with_retarget_to_element(&self, retarget_to_element: bool)

Source

impl Element

pub fn set_pointer_capture(&self, pointer_id: i32) -> Result<(), JsValue>

Source

impl Element

pub fn toggle_attribute(&self, name: &str) -> Result<bool, JsValue>

Source

impl Element

pub fn toggle_attribute_with_force( &self, name: &str, force: bool, ) -> Result<bool, JsValue>

Source

impl Element

pub fn webkit_matches_selector(&self, selector: &str) -> Result<bool, JsValue>

Source

impl Element

pub fn animate(&self, keyframes: Option<&Object>) -> Animation

Source

impl Element

pub fn animate_with_f64( &self, keyframes: Option<&Object>, options: f64, ) -> Animation

Source

impl Element

Source

impl Element

pub fn after_with_node(&self, nodes: &Array) -> Result<(), JsValue>

Source

impl Element

Source

impl Element

pub fn after_with_node_1(&self, nodes_1: &Node) -> Result<(), JsValue>

Source

impl Element

pub fn after_with_node_2( &self, nodes_1: &Node, nodes_2: &Node, ) -> Result<(), JsValue>

Source

impl Element

pub fn after_with_node_3( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, ) -> Result<(), JsValue>

Source

impl Element

pub fn after_with_node_4( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, ) -> Result<(), JsValue>

Source

impl Element

pub fn after_with_node_5( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, ) -> Result<(), JsValue>

Source

impl Element

pub fn after_with_node_6( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, nodes_6: &Node, ) -> Result<(), JsValue>

Source

impl Element

pub fn after_with_node_7( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, nodes_6: &Node, nodes_7: &Node, ) -> Result<(), JsValue>

Source

impl Element

pub fn after_with_str(&self, nodes: &Array) -> Result<(), JsValue>

Source

impl Element

Source

impl Element

pub fn after_with_str_1(&self, nodes_1: &str) -> Result<(), JsValue>

Source

impl Element

pub fn after_with_str_2( &self, nodes_1: &str, nodes_2: &str, ) -> Result<(), JsValue>

Source

impl Element

pub fn after_with_str_3( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, ) -> Result<(), JsValue>

Source

impl Element

pub fn after_with_str_4( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, ) -> Result<(), JsValue>

Source

impl Element

pub fn after_with_str_5( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, ) -> Result<(), JsValue>

Source

impl Element

pub fn after_with_str_6( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, nodes_6: &str, ) -> Result<(), JsValue>

Source

impl Element

pub fn after_with_str_7( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, nodes_6: &str, nodes_7: &str, ) -> Result<(), JsValue>

Source

impl Element

pub fn before_with_node(&self, nodes: &Array) -> Result<(), JsValue>

Source

impl Element

Source

impl Element

pub fn before_with_node_1(&self, nodes_1: &Node) -> Result<(), JsValue>

Source

impl Element

pub fn before_with_node_2( &self, nodes_1: &Node, nodes_2: &Node, ) -> Result<(), JsValue>

Source

impl Element

pub fn before_with_node_3( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, ) -> Result<(), JsValue>

Source

impl Element

pub fn before_with_node_4( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, ) -> Result<(), JsValue>

Source

impl Element

pub fn before_with_node_5( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, ) -> Result<(), JsValue>

Source

impl Element

pub fn before_with_node_6( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, nodes_6: &Node, ) -> Result<(), JsValue>

Source

impl Element

pub fn before_with_node_7( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, nodes_6: &Node, nodes_7: &Node, ) -> Result<(), JsValue>

Source

impl Element

pub fn before_with_str(&self, nodes: &Array) -> Result<(), JsValue>

Source

impl Element

Source

impl Element

pub fn before_with_str_1(&self, nodes_1: &str) -> Result<(), JsValue>

Source

impl Element

pub fn before_with_str_2( &self, nodes_1: &str, nodes_2: &str, ) -> Result<(), JsValue>

Source

impl Element

pub fn before_with_str_3( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, ) -> Result<(), JsValue>

Source

impl Element

pub fn before_with_str_4( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, ) -> Result<(), JsValue>

Source

impl Element

pub fn before_with_str_5( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, ) -> Result<(), JsValue>

Source

impl Element

pub fn before_with_str_6( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, nodes_6: &str, ) -> Result<(), JsValue>

Source

impl Element

pub fn before_with_str_7( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, nodes_6: &str, nodes_7: &str, ) -> Result<(), JsValue>

Source

impl Element

pub fn remove(&self)

Source

impl Element

pub fn replace_with_with_node(&self, nodes: &Array) -> Result<(), JsValue>

Source

impl Element

Source

impl Element

pub fn replace_with_with_node_1(&self, nodes_1: &Node) -> Result<(), JsValue>

Source

impl Element

pub fn replace_with_with_node_2( &self, nodes_1: &Node, nodes_2: &Node, ) -> Result<(), JsValue>

Source

impl Element

pub fn replace_with_with_node_3( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, ) -> Result<(), JsValue>

Source

impl Element

pub fn replace_with_with_node_4( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, ) -> Result<(), JsValue>

Source

impl Element

pub fn replace_with_with_node_5( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, ) -> Result<(), JsValue>

Source

impl Element

pub fn replace_with_with_node_6( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, nodes_6: &Node, ) -> Result<(), JsValue>

Source

impl Element

pub fn replace_with_with_node_7( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, nodes_6: &Node, nodes_7: &Node, ) -> Result<(), JsValue>

Source

impl Element

pub fn replace_with_with_str(&self, nodes: &Array) -> Result<(), JsValue>

Source

impl Element

Source

impl Element

pub fn replace_with_with_str_1(&self, nodes_1: &str) -> Result<(), JsValue>

Source

impl Element

pub fn replace_with_with_str_2( &self, nodes_1: &str, nodes_2: &str, ) -> Result<(), JsValue>

Source

impl Element

pub fn replace_with_with_str_3( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, ) -> Result<(), JsValue>

Source

impl Element

pub fn replace_with_with_str_4( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, ) -> Result<(), JsValue>

Source

impl Element

pub fn replace_with_with_str_5( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, ) -> Result<(), JsValue>

Source

impl Element

pub fn replace_with_with_str_6( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, nodes_6: &str, ) -> Result<(), JsValue>

Source

impl Element

pub fn replace_with_with_str_7( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, nodes_6: &str, nodes_7: &str, ) -> Result<(), JsValue>

Source

impl Element

Source

impl Element

pub fn append_with_node(&self, nodes: &Array) -> Result<(), JsValue>

Source

impl Element

Source

impl Element

pub fn append_with_node_1(&self, nodes_1: &Node) -> Result<(), JsValue>

Source

impl Element

pub fn append_with_node_2( &self, nodes_1: &Node, nodes_2: &Node, ) -> Result<(), JsValue>

Source

impl Element

pub fn append_with_node_3( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, ) -> Result<(), JsValue>

Source

impl Element

pub fn append_with_node_4( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, ) -> Result<(), JsValue>

Source

impl Element

pub fn append_with_node_5( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, ) -> Result<(), JsValue>

Source

impl Element

pub fn append_with_node_6( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, nodes_6: &Node, ) -> Result<(), JsValue>

Source

impl Element

pub fn append_with_node_7( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, nodes_6: &Node, nodes_7: &Node, ) -> Result<(), JsValue>

Source

impl Element

pub fn append_with_str(&self, nodes: &Array) -> Result<(), JsValue>

Source

impl Element

Source

impl Element

pub fn append_with_str_1(&self, nodes_1: &str) -> Result<(), JsValue>

Source

impl Element

pub fn append_with_str_2( &self, nodes_1: &str, nodes_2: &str, ) -> Result<(), JsValue>

Source

impl Element

pub fn append_with_str_3( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, ) -> Result<(), JsValue>

Source

impl Element

pub fn append_with_str_4( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, ) -> Result<(), JsValue>

Source

impl Element

pub fn append_with_str_5( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, ) -> Result<(), JsValue>

Source

impl Element

pub fn append_with_str_6( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, nodes_6: &str, ) -> Result<(), JsValue>

Source

impl Element

pub fn append_with_str_7( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, nodes_6: &str, nodes_7: &str, ) -> Result<(), JsValue>

Source

impl Element

pub fn prepend_with_node(&self, nodes: &Array) -> Result<(), JsValue>

Source

impl Element

Source

impl Element

pub fn prepend_with_node_1(&self, nodes_1: &Node) -> Result<(), JsValue>

Source

impl Element

pub fn prepend_with_node_2( &self, nodes_1: &Node, nodes_2: &Node, ) -> Result<(), JsValue>

Source

impl Element

pub fn prepend_with_node_3( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, ) -> Result<(), JsValue>

Source

impl Element

pub fn prepend_with_node_4( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, ) -> Result<(), JsValue>

Source

impl Element

pub fn prepend_with_node_5( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, ) -> Result<(), JsValue>

Source

impl Element

pub fn prepend_with_node_6( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, nodes_6: &Node, ) -> Result<(), JsValue>

Source

impl Element

pub fn prepend_with_node_7( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, nodes_6: &Node, nodes_7: &Node, ) -> Result<(), JsValue>

Source

impl Element

pub fn prepend_with_str(&self, nodes: &Array) -> Result<(), JsValue>

Source

impl Element

Source

impl Element

pub fn prepend_with_str_1(&self, nodes_1: &str) -> Result<(), JsValue>

Source

impl Element

pub fn prepend_with_str_2( &self, nodes_1: &str, nodes_2: &str, ) -> Result<(), JsValue>

Source

impl Element

pub fn prepend_with_str_3( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, ) -> Result<(), JsValue>

Source

impl Element

pub fn prepend_with_str_4( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, ) -> Result<(), JsValue>

Source

impl Element

pub fn prepend_with_str_5( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, ) -> Result<(), JsValue>

Source

impl Element

pub fn prepend_with_str_6( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, nodes_6: &str, ) -> Result<(), JsValue>

Source

impl Element

pub fn prepend_with_str_7( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, nodes_6: &str, nodes_7: &str, ) -> Result<(), JsValue>

Source

impl Element

Source

impl Element

Source

impl Element

pub fn replace_children_with_node_1(&self, nodes_1: &Node)

Source

impl Element

pub fn replace_children_with_node_2(&self, nodes_1: &Node, nodes_2: &Node)

Source

impl Element

pub fn replace_children_with_node_3( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, )

Source

impl Element

pub fn replace_children_with_node_4( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, )

Source

impl Element

pub fn replace_children_with_node_5( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, )

Source

impl Element

pub fn replace_children_with_node_6( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, nodes_6: &Node, )

Source

impl Element

pub fn replace_children_with_node_7( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, nodes_6: &Node, nodes_7: &Node, )

Source

impl Element

pub fn replace_children_with_str(&self, nodes: &Array)

Source

impl Element

Source

impl Element

pub fn replace_children_with_str_1(&self, nodes_1: &str)

Source

impl Element

pub fn replace_children_with_str_2(&self, nodes_1: &str, nodes_2: &str)

Source

impl Element

pub fn replace_children_with_str_3( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, )

Source

impl Element

pub fn replace_children_with_str_4( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, )

Source

impl Element

pub fn replace_children_with_str_5( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, )

Source

impl Element

pub fn replace_children_with_str_6( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, nodes_6: &str, )

Source

impl Element

pub fn replace_children_with_str_7( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, nodes_6: &str, nodes_7: &str, )

Methods from Deref<Target = Node>

pub fn node_type(&self) -> u16

pub fn node_name(&self) -> String

pub fn base_uri(&self) -> Result<Option<String>, JsValue>

pub fn is_connected(&self) -> bool

pub fn owner_document(&self) -> Option<Document>

pub fn parent_node(&self) -> Option<Node>

pub fn parent_element(&self) -> Option<Element>

pub fn child_nodes(&self) -> NodeList

pub fn first_child(&self) -> Option<Node>

pub fn last_child(&self) -> Option<Node>

pub fn previous_sibling(&self) -> Option<Node>

pub fn next_sibling(&self) -> Option<Node>

pub fn node_value(&self) -> Option<String>

pub fn set_node_value(&self, value: Option<&str>)

pub fn text_content(&self) -> Option<String>

pub fn set_text_content(&self, value: Option<&str>)

pub fn append_child(&self, node: &Node) -> Result<Node, JsValue>

pub fn clone_node(&self) -> Result<Node, JsValue>

pub fn clone_node_with_deep(&self, deep: bool) -> Result<Node, JsValue>

pub fn compare_document_position(&self, other: &Node) -> u16

pub fn contains(&self, other: Option<&Node>) -> bool

pub fn get_root_node(&self) -> Node

pub fn has_child_nodes(&self) -> bool

pub fn insert_before( &self, node: &Node, child: Option<&Node>, ) -> Result<Node, JsValue>

pub fn is_default_namespace(&self, namespace: Option<&str>) -> bool

pub fn is_equal_node(&self, node: Option<&Node>) -> bool

pub fn is_same_node(&self, node: Option<&Node>) -> bool

pub fn lookup_namespace_uri(&self, prefix: Option<&str>) -> Option<String>

pub fn lookup_prefix(&self, namespace: Option<&str>) -> Option<String>

pub fn normalize(&self)

pub fn remove_child(&self, child: &Node) -> Result<Node, JsValue>

pub fn replace_child(&self, node: &Node, child: &Node) -> Result<Node, JsValue>

pub const ELEMENT_NODE: u16

pub const ATTRIBUTE_NODE: u16

pub const TEXT_NODE: u16

pub const CDATA_SECTION_NODE: u16

pub const ENTITY_REFERENCE_NODE: u16

pub const ENTITY_NODE: u16

pub const PROCESSING_INSTRUCTION_NODE: u16

pub const COMMENT_NODE: u16

pub const DOCUMENT_NODE: u16

pub const DOCUMENT_TYPE_NODE: u16

pub const DOCUMENT_FRAGMENT_NODE: u16

pub const NOTATION_NODE: u16

pub const DOCUMENT_POSITION_DISCONNECTED: u16

pub const DOCUMENT_POSITION_PRECEDING: u16

pub const DOCUMENT_POSITION_FOLLOWING: u16

pub const DOCUMENT_POSITION_CONTAINS: u16

pub const DOCUMENT_POSITION_CONTAINED_BY: u16

pub const DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC: u16

Methods from Deref<Target = EventTarget>

pub fn add_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>

pub fn add_event_listener_with_event_listener( &self, type_: &str, listener: &EventListener, ) -> Result<(), JsValue>

pub fn add_event_listener_with_callback_and_add_event_listener_options( &self, type_: &str, listener: &Function, options: &AddEventListenerOptions, ) -> Result<(), JsValue>

pub fn add_event_listener_with_event_listener_and_add_event_listener_options( &self, type_: &str, listener: &EventListener, options: &AddEventListenerOptions, ) -> Result<(), JsValue>

pub fn add_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>

pub fn add_event_listener_with_event_listener_and_bool( &self, type_: &str, listener: &EventListener, options: bool, ) -> Result<(), JsValue>

pub fn add_event_listener_with_callback_and_add_event_listener_options_and_wants_untrusted( &self, type_: &str, listener: &Function, options: &AddEventListenerOptions, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>

pub fn add_event_listener_with_event_listener_and_add_event_listener_options_and_wants_untrusted( &self, type_: &str, listener: &EventListener, options: &AddEventListenerOptions, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>

pub fn add_event_listener_with_callback_and_bool_and_wants_untrusted( &self, type_: &str, listener: &Function, options: bool, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>

pub fn add_event_listener_with_event_listener_and_bool_and_wants_untrusted( &self, type_: &str, listener: &EventListener, options: bool, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>

pub fn dispatch_event(&self, event: &Event) -> Result<bool, JsValue>

pub fn remove_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>

pub fn remove_event_listener_with_event_listener( &self, type_: &str, listener: &EventListener, ) -> Result<(), JsValue>

pub fn remove_event_listener_with_callback_and_event_listener_options( &self, type_: &str, listener: &Function, options: &EventListenerOptions, ) -> Result<(), JsValue>

pub fn remove_event_listener_with_event_listener_and_event_listener_options( &self, type_: &str, listener: &EventListener, options: &EventListenerOptions, ) -> Result<(), JsValue>

pub fn remove_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>

pub fn remove_event_listener_with_event_listener_and_bool( &self, type_: &str, listener: &EventListener, options: bool, ) -> Result<(), JsValue>

Methods from Deref<Target = Object>

pub fn constructor(&self) -> Function

pub fn has_own_property(&self, property: &JsValue) -> bool

👎Deprecated:

Use Object::hasOwn instead.

pub fn is_prototype_of(&self, value: &JsValue) -> bool

pub fn property_is_enumerable(&self, property: &JsValue) -> bool

pub fn to_locale_string(&self) -> JsString

pub fn to_string(&self) -> JsString

pub fn to_js_string(&self) -> JsString

pub fn value_of(&self) -> Object

Methods from Deref<Target = JsValue>

pub const NULL: JsValue

pub const UNDEFINED: JsValue

pub const TRUE: JsValue

pub const FALSE: JsValue

pub fn unchecked_into_f64(&self) -> f64

Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.

pub fn has_type<T>(&self) -> bool
where T: JsCast,

Check if this value is an instance of a specific JS type.

pub fn checked_div(&self, rhs: &JsValue) -> JsValue

Checked division.

pub fn pow(&self, rhs: &JsValue) -> JsValue

Power operation.

pub fn bit_and(&self, rhs: &JsValue) -> JsValue

Bitwise AND.

pub fn bit_or(&self, rhs: &JsValue) -> JsValue

Bitwise OR.

pub fn bit_xor(&self, rhs: &JsValue) -> JsValue

Bitwise XOR.

pub fn bit_not(&self) -> JsValue

Bitwise NOT.

pub fn shl(&self, rhs: &JsValue) -> JsValue

Left shift.

pub fn shr(&self, rhs: &JsValue) -> JsValue

Signed right shift.

pub fn unsigned_shr(&self, rhs: &JsValue) -> u32

Unsigned right shift.

pub fn add(&self, rhs: &JsValue) -> JsValue

Add.

pub fn sub(&self, rhs: &JsValue) -> JsValue

Subtract.

pub fn mul(&self, rhs: &JsValue) -> JsValue

Multiply.

pub fn div(&self, rhs: &JsValue) -> JsValue

Divide.

pub fn rem(&self, rhs: &JsValue) -> JsValue

Remainder.

pub fn neg(&self) -> JsValue

Negate.

pub fn lt(&self, other: &JsValue) -> bool

Less than comparison.

pub fn le(&self, other: &JsValue) -> bool

Less than or equal comparison.

pub fn gt(&self, other: &JsValue) -> bool

Greater than comparison.

pub fn ge(&self, other: &JsValue) -> bool

Greater than or equal comparison.

pub fn loose_eq(&self, other: &JsValue) -> bool

Loose equality (==).

pub fn is_falsy(&self) -> bool

Check if this value is a falsy value in JavaScript.

pub fn is_truthy(&self) -> bool

Check if this value is a truthy value in JavaScript.

pub fn is_object(&self) -> bool

Check if this value is an object.

pub fn is_function(&self) -> bool

Check if this value is a function.

pub fn is_string(&self) -> bool

Check if this value is a string.

pub fn is_symbol(&self) -> bool

Check if this value is a symbol.

pub fn is_bigint(&self) -> bool

Check if this value is a bigint.

pub fn is_array(&self) -> bool

Check if this value is an Array.

pub fn is_undefined(&self) -> bool

Check if this value is undefined.

pub fn is_null(&self) -> bool

Check if this value is null.

pub fn is_null_or_undefined(&self) -> bool

Check if this value is null or undefined.

pub fn js_typeof(&self) -> JsValue

Get the typeof this value as a string.

pub fn js_in(&self, obj: &JsValue) -> bool

Check if this value has a property with the given name.

pub fn as_bool(&self) -> Option<bool>

Get the value as a bool.

pub fn as_f64(&self) -> Option<f64>

Get the value as an f64.

pub fn as_string(&self) -> Option<String>

Get the value as a string.

pub fn as_debug_string(&self) -> String

Get a debug string representation of the value.