HtmlDocument

Struct HtmlDocument 

pub struct HtmlDocument { /* private fields */ }
The HtmlDocument class.

MDN Documentation

This API requires the following crate features to be activated: HtmlDocument

Implementations

Source

impl HtmlDocument

pub fn domain(&self) -> String

Source

impl HtmlDocument

pub fn set_domain(&self, value: &str)

Source

impl HtmlDocument

pub fn cookie(&self) -> Result<String, JsValue>

Source

impl HtmlDocument

Source

impl HtmlDocument

pub fn design_mode(&self) -> String

Source

impl HtmlDocument

pub fn set_design_mode(&self, value: &str)

Source

impl HtmlDocument

pub fn fg_color(&self) -> String

Source

impl HtmlDocument

pub fn set_fg_color(&self, value: &str)

Source

impl HtmlDocument

Source

impl HtmlDocument

Source

impl HtmlDocument

Source

impl HtmlDocument

Source

impl HtmlDocument

Source

impl HtmlDocument

Source

impl HtmlDocument

pub fn bg_color(&self) -> String

Source

impl HtmlDocument

pub fn set_bg_color(&self, value: &str)

Source

impl HtmlDocument

pub fn capture_events(&self)

Source

impl HtmlDocument

pub fn clear(&self)

Source

impl HtmlDocument

pub fn close(&self) -> Result<(), JsValue>

Source

impl HtmlDocument

pub fn exec_command(&self, command_id: &str) -> Result<bool, JsValue>

Source

impl HtmlDocument

pub fn exec_command_with_show_ui( &self, command_id: &str, show_ui: bool, ) -> Result<bool, JsValue>

Source

impl HtmlDocument

pub fn exec_command_with_show_ui_and_value( &self, command_id: &str, show_ui: bool, value: &str, ) -> Result<bool, JsValue>

Source

impl HtmlDocument

pub fn open(&self) -> Result<Document, JsValue>

Source

impl HtmlDocument

pub fn open_with_type(&self, type_: &str) -> Result<Document, JsValue>

Source

impl HtmlDocument

pub fn open_with_type_and_replace( &self, type_: &str, replace: &str, ) -> Result<Document, JsValue>

Source

impl HtmlDocument

pub fn open_with_url_and_name_and_features( &self, url: &str, name: &str, features: &str, ) -> Result<Option<Window>, JsValue>

Source

impl HtmlDocument

pub fn open_with_url_and_name_and_features_and_replace( &self, url: &str, name: &str, features: &str, replace: bool, ) -> Result<Option<Window>, JsValue>

Source

impl HtmlDocument

pub fn query_command_enabled(&self, command_id: &str) -> Result<bool, JsValue>

Source

impl HtmlDocument

pub fn query_command_indeterm(&self, command_id: &str) -> Result<bool, JsValue>

Source

impl HtmlDocument

pub fn query_command_state(&self, command_id: &str) -> Result<bool, JsValue>

Source

impl HtmlDocument

pub fn query_command_supported(&self, command_id: &str) -> bool

Source

impl HtmlDocument

pub fn query_command_value(&self, command_id: &str) -> Result<String, JsValue>

Source

impl HtmlDocument

pub fn release_events(&self)

Source

impl HtmlDocument

pub fn write(&self, text: &Array) -> Result<(), JsValue>

Source

impl HtmlDocument

pub fn write_0(&self) -> Result<(), JsValue>

Source

impl HtmlDocument

pub fn write_1(&self, text_1: &str) -> Result<(), JsValue>

Source

impl HtmlDocument

pub fn write_2(&self, text_1: &str, text_2: &str) -> Result<(), JsValue>

Source

impl HtmlDocument

pub fn write_3( &self, text_1: &str, text_2: &str, text_3: &str, ) -> Result<(), JsValue>

Source

impl HtmlDocument

pub fn write_4( &self, text_1: &str, text_2: &str, text_3: &str, text_4: &str, ) -> Result<(), JsValue>

Source

impl HtmlDocument

pub fn write_5( &self, text_1: &str, text_2: &str, text_3: &str, text_4: &str, text_5: &str, ) -> Result<(), JsValue>

Source

impl HtmlDocument

pub fn write_6( &self, text_1: &str, text_2: &str, text_3: &str, text_4: &str, text_5: &str, text_6: &str, ) -> Result<(), JsValue>

Source

impl HtmlDocument

pub fn write_7( &self, text_1: &str, text_2: &str, text_3: &str, text_4: &str, text_5: &str, text_6: &str, text_7: &str, ) -> Result<(), JsValue>

Source

impl HtmlDocument

pub fn writeln(&self, text: &Array) -> Result<(), JsValue>

Source

impl HtmlDocument

pub fn writeln_0(&self) -> Result<(), JsValue>

Source

impl HtmlDocument

pub fn writeln_1(&self, text_1: &str) -> Result<(), JsValue>

Source

impl HtmlDocument

pub fn writeln_2(&self, text_1: &str, text_2: &str) -> Result<(), JsValue>

Source

impl HtmlDocument

pub fn writeln_3( &self, text_1: &str, text_2: &str, text_3: &str, ) -> Result<(), JsValue>

Source

impl HtmlDocument

pub fn writeln_4( &self, text_1: &str, text_2: &str, text_3: &str, text_4: &str, ) -> Result<(), JsValue>

Source

impl HtmlDocument

pub fn writeln_5( &self, text_1: &str, text_2: &str, text_3: &str, text_4: &str, text_5: &str, ) -> Result<(), JsValue>

Source

impl HtmlDocument

pub fn writeln_6( &self, text_1: &str, text_2: &str, text_3: &str, text_4: &str, text_5: &str, text_6: &str, ) -> Result<(), JsValue>

Source

impl HtmlDocument

pub fn writeln_7( &self, text_1: &str, text_2: &str, text_3: &str, text_4: &str, text_5: &str, text_6: &str, text_7: &str, ) -> Result<(), JsValue>

Source

impl HtmlDocument

pub fn get(&self, name: &str) -> Result<Object, JsValue>

Methods from Deref<Target = Document>

pub fn implementation(&self) -> Result<DomImplementation, JsValue>

pub fn url(&self) -> Result<String, JsValue>

pub fn document_uri(&self) -> Result<String, JsValue>

pub fn compat_mode(&self) -> String

pub fn character_set(&self) -> String

pub fn charset(&self) -> String

pub fn input_encoding(&self) -> String

pub fn content_type(&self) -> String

pub fn doctype(&self) -> Option<DocumentType>

pub fn document_element(&self) -> Option<Element>

pub fn location(&self) -> Option<Location>

pub fn referrer(&self) -> String

pub fn last_modified(&self) -> String

pub fn ready_state(&self) -> String

pub fn title(&self) -> String

pub fn set_title(&self, value: &str)

pub fn dir(&self) -> String

pub fn set_dir(&self, value: &str)

pub fn body(&self) -> Option<HtmlElement>

pub fn set_body(&self, value: Option<&HtmlElement>)

pub fn head(&self) -> Option<HtmlHeadElement>

pub fn images(&self) -> HtmlCollection

pub fn embeds(&self) -> HtmlCollection

pub fn plugins(&self) -> HtmlCollection

pub fn forms(&self) -> HtmlCollection

pub fn scripts(&self) -> HtmlCollection

pub fn default_view(&self) -> Option<Window>

pub fn onreadystatechange(&self) -> Option<Function>

pub fn set_onreadystatechange(&self, value: Option<&Function>)

pub fn onbeforescriptexecute(&self) -> Option<Function>

pub fn set_onbeforescriptexecute(&self, value: Option<&Function>)

pub fn onafterscriptexecute(&self) -> Option<Function>

pub fn set_onafterscriptexecute(&self, value: Option<&Function>)

pub fn onselectionchange(&self) -> Option<Function>

pub fn set_onselectionchange(&self, value: Option<&Function>)

pub fn current_script(&self) -> Option<Element>

pub fn anchors(&self) -> HtmlCollection

pub fn applets(&self) -> HtmlCollection

pub fn fullscreen(&self) -> bool

pub fn fullscreen_enabled(&self) -> bool

pub fn onfullscreenchange(&self) -> Option<Function>

pub fn set_onfullscreenchange(&self, value: Option<&Function>)

pub fn onfullscreenerror(&self) -> Option<Function>

pub fn set_onfullscreenerror(&self, value: Option<&Function>)

pub fn onpointerlockchange(&self) -> Option<Function>

pub fn set_onpointerlockchange(&self, value: Option<&Function>)

pub fn onpointerlockerror(&self) -> Option<Function>

pub fn set_onpointerlockerror(&self, value: Option<&Function>)

pub fn hidden(&self) -> bool

pub fn visibility_state(&self) -> VisibilityState

pub fn onvisibilitychange(&self) -> Option<Function>

pub fn set_onvisibilitychange(&self, value: Option<&Function>)

pub fn selected_style_sheet_set(&self) -> Option<String>

pub fn set_selected_style_sheet_set(&self, value: Option<&str>)

pub fn last_style_sheet_set(&self) -> Option<String>

pub fn preferred_style_sheet_set(&self) -> Option<String>

pub fn style_sheet_sets(&self) -> DomStringList

pub fn scrolling_element(&self) -> Option<Element>

pub fn root_element(&self) -> Option<SvgsvgElement>

pub fn picture_in_picture_enabled(&self) -> bool

pub fn oncopy(&self) -> Option<Function>

pub fn set_oncopy(&self, value: Option<&Function>)

pub fn oncut(&self) -> Option<Function>

pub fn set_oncut(&self, value: Option<&Function>)

pub fn onpaste(&self) -> Option<Function>

pub fn set_onpaste(&self, value: Option<&Function>)

pub fn active_element(&self) -> Option<Element>

pub fn pointer_lock_element(&self) -> Option<Element>

pub fn fullscreen_element(&self) -> Option<Element>

pub fn style_sheets(&self) -> StyleSheetList

pub fn adopted_style_sheets(&self) -> Array

pub fn set_adopted_style_sheets(&self, value: &JsValue)

pub fn picture_in_picture_element(&self) -> Option<Element>

pub fn onabort(&self) -> Option<Function>

pub fn set_onabort(&self, value: Option<&Function>)

pub fn onblur(&self) -> Option<Function>

pub fn set_onblur(&self, value: Option<&Function>)

pub fn onfocus(&self) -> Option<Function>

pub fn set_onfocus(&self, value: Option<&Function>)

pub fn oncancel(&self) -> Option<Function>

pub fn set_oncancel(&self, value: Option<&Function>)

pub fn onauxclick(&self) -> Option<Function>

pub fn set_onauxclick(&self, value: Option<&Function>)

pub fn onbeforetoggle(&self) -> Option<Function>

pub fn set_onbeforetoggle(&self, value: Option<&Function>)

pub fn oncanplay(&self) -> Option<Function>

pub fn set_oncanplay(&self, value: Option<&Function>)

pub fn oncanplaythrough(&self) -> Option<Function>

pub fn set_oncanplaythrough(&self, value: Option<&Function>)

pub fn onchange(&self) -> Option<Function>

pub fn set_onchange(&self, value: Option<&Function>)

pub fn onclick(&self) -> Option<Function>

pub fn set_onclick(&self, value: Option<&Function>)

pub fn onclose(&self) -> Option<Function>

pub fn set_onclose(&self, value: Option<&Function>)

pub fn oncontextmenu(&self) -> Option<Function>

pub fn set_oncontextmenu(&self, value: Option<&Function>)

pub fn ondblclick(&self) -> Option<Function>

pub fn set_ondblclick(&self, value: Option<&Function>)

pub fn ondrag(&self) -> Option<Function>

pub fn set_ondrag(&self, value: Option<&Function>)

pub fn ondragend(&self) -> Option<Function>

pub fn set_ondragend(&self, value: Option<&Function>)

pub fn ondragenter(&self) -> Option<Function>

pub fn set_ondragenter(&self, value: Option<&Function>)

pub fn ondragexit(&self) -> Option<Function>

pub fn set_ondragexit(&self, value: Option<&Function>)

pub fn ondragleave(&self) -> Option<Function>

pub fn set_ondragleave(&self, value: Option<&Function>)

pub fn ondragover(&self) -> Option<Function>

pub fn set_ondragover(&self, value: Option<&Function>)

pub fn ondragstart(&self) -> Option<Function>

pub fn set_ondragstart(&self, value: Option<&Function>)

pub fn ondrop(&self) -> Option<Function>

pub fn set_ondrop(&self, value: Option<&Function>)

pub fn ondurationchange(&self) -> Option<Function>

pub fn set_ondurationchange(&self, value: Option<&Function>)

pub fn onemptied(&self) -> Option<Function>

pub fn set_onemptied(&self, value: Option<&Function>)

pub fn onended(&self) -> Option<Function>

pub fn set_onended(&self, value: Option<&Function>)

pub fn oninput(&self) -> Option<Function>

pub fn set_oninput(&self, value: Option<&Function>)

pub fn onbeforeinput(&self) -> Option<Function>

pub fn set_onbeforeinput(&self, value: Option<&Function>)

pub fn oninvalid(&self) -> Option<Function>

pub fn set_oninvalid(&self, value: Option<&Function>)

pub fn onkeydown(&self) -> Option<Function>

pub fn set_onkeydown(&self, value: Option<&Function>)

pub fn onkeypress(&self) -> Option<Function>

pub fn set_onkeypress(&self, value: Option<&Function>)

pub fn onkeyup(&self) -> Option<Function>

pub fn set_onkeyup(&self, value: Option<&Function>)

pub fn onload(&self) -> Option<Function>

pub fn set_onload(&self, value: Option<&Function>)

pub fn onloadeddata(&self) -> Option<Function>

pub fn set_onloadeddata(&self, value: Option<&Function>)

pub fn onloadedmetadata(&self) -> Option<Function>

pub fn set_onloadedmetadata(&self, value: Option<&Function>)

pub fn onloadend(&self) -> Option<Function>

pub fn set_onloadend(&self, value: Option<&Function>)

pub fn onloadstart(&self) -> Option<Function>

pub fn set_onloadstart(&self, value: Option<&Function>)

pub fn onmousedown(&self) -> Option<Function>

pub fn set_onmousedown(&self, value: Option<&Function>)

pub fn onmouseenter(&self) -> Option<Function>

pub fn set_onmouseenter(&self, value: Option<&Function>)

pub fn onmouseleave(&self) -> Option<Function>

pub fn set_onmouseleave(&self, value: Option<&Function>)

pub fn onmousemove(&self) -> Option<Function>

pub fn set_onmousemove(&self, value: Option<&Function>)

pub fn onmouseout(&self) -> Option<Function>

pub fn set_onmouseout(&self, value: Option<&Function>)

pub fn onmouseover(&self) -> Option<Function>

pub fn set_onmouseover(&self, value: Option<&Function>)

pub fn onmouseup(&self) -> Option<Function>

pub fn set_onmouseup(&self, value: Option<&Function>)

pub fn onwheel(&self) -> Option<Function>

pub fn set_onwheel(&self, value: Option<&Function>)

pub fn onpause(&self) -> Option<Function>

pub fn set_onpause(&self, value: Option<&Function>)

pub fn onplay(&self) -> Option<Function>

pub fn set_onplay(&self, value: Option<&Function>)

pub fn onplaying(&self) -> Option<Function>

pub fn set_onplaying(&self, value: Option<&Function>)

pub fn onprogress(&self) -> Option<Function>

pub fn set_onprogress(&self, value: Option<&Function>)

pub fn onratechange(&self) -> Option<Function>

pub fn set_onratechange(&self, value: Option<&Function>)

pub fn onreset(&self) -> Option<Function>

pub fn set_onreset(&self, value: Option<&Function>)

pub fn onresize(&self) -> Option<Function>

pub fn set_onresize(&self, value: Option<&Function>)

pub fn onscroll(&self) -> Option<Function>

pub fn set_onscroll(&self, value: Option<&Function>)

pub fn onseeked(&self) -> Option<Function>

pub fn set_onseeked(&self, value: Option<&Function>)

pub fn onseeking(&self) -> Option<Function>

pub fn set_onseeking(&self, value: Option<&Function>)

pub fn onselect(&self) -> Option<Function>

pub fn set_onselect(&self, value: Option<&Function>)

pub fn onshow(&self) -> Option<Function>

pub fn set_onshow(&self, value: Option<&Function>)

pub fn onstalled(&self) -> Option<Function>

pub fn set_onstalled(&self, value: Option<&Function>)

pub fn onsubmit(&self) -> Option<Function>

pub fn set_onsubmit(&self, value: Option<&Function>)

pub fn onsuspend(&self) -> Option<Function>

pub fn set_onsuspend(&self, value: Option<&Function>)

pub fn ontimeupdate(&self) -> Option<Function>

pub fn set_ontimeupdate(&self, value: Option<&Function>)

pub fn onvolumechange(&self) -> Option<Function>

pub fn set_onvolumechange(&self, value: Option<&Function>)

pub fn onwaiting(&self) -> Option<Function>

pub fn set_onwaiting(&self, value: Option<&Function>)

pub fn onselectstart(&self) -> Option<Function>

pub fn set_onselectstart(&self, value: Option<&Function>)

pub fn ontoggle(&self) -> Option<Function>

pub fn set_ontoggle(&self, value: Option<&Function>)

pub fn onpointercancel(&self) -> Option<Function>

pub fn set_onpointercancel(&self, value: Option<&Function>)

pub fn onpointerdown(&self) -> Option<Function>

pub fn set_onpointerdown(&self, value: Option<&Function>)

pub fn onpointerup(&self) -> Option<Function>

pub fn set_onpointerup(&self, value: Option<&Function>)

pub fn onpointermove(&self) -> Option<Function>

pub fn set_onpointermove(&self, value: Option<&Function>)

pub fn onpointerout(&self) -> Option<Function>

pub fn set_onpointerout(&self, value: Option<&Function>)

pub fn onpointerover(&self) -> Option<Function>

pub fn set_onpointerover(&self, value: Option<&Function>)

pub fn onpointerenter(&self) -> Option<Function>

pub fn set_onpointerenter(&self, value: Option<&Function>)

pub fn onpointerleave(&self) -> Option<Function>

pub fn set_onpointerleave(&self, value: Option<&Function>)

pub fn ongotpointercapture(&self) -> Option<Function>

pub fn set_ongotpointercapture(&self, value: Option<&Function>)

pub fn onlostpointercapture(&self) -> Option<Function>

pub fn set_onlostpointercapture(&self, value: Option<&Function>)

pub fn onanimationcancel(&self) -> Option<Function>

pub fn set_onanimationcancel(&self, value: Option<&Function>)

pub fn onanimationend(&self) -> Option<Function>

pub fn set_onanimationend(&self, value: Option<&Function>)

pub fn onanimationiteration(&self) -> Option<Function>

pub fn set_onanimationiteration(&self, value: Option<&Function>)

pub fn onanimationstart(&self) -> Option<Function>

pub fn set_onanimationstart(&self, value: Option<&Function>)

pub fn ontransitioncancel(&self) -> Option<Function>

pub fn set_ontransitioncancel(&self, value: Option<&Function>)

pub fn ontransitionend(&self) -> Option<Function>

pub fn set_ontransitionend(&self, value: Option<&Function>)

pub fn ontransitionrun(&self) -> Option<Function>

pub fn set_ontransitionrun(&self, value: Option<&Function>)

pub fn ontransitionstart(&self) -> Option<Function>

pub fn set_ontransitionstart(&self, value: Option<&Function>)

pub fn onwebkitanimationend(&self) -> Option<Function>

pub fn set_onwebkitanimationend(&self, value: Option<&Function>)

pub fn onwebkitanimationiteration(&self) -> Option<Function>

pub fn set_onwebkitanimationiteration(&self, value: Option<&Function>)

pub fn onwebkitanimationstart(&self) -> Option<Function>

pub fn set_onwebkitanimationstart(&self, value: Option<&Function>)

pub fn onwebkittransitionend(&self) -> Option<Function>

pub fn set_onwebkittransitionend(&self, value: Option<&Function>)

pub fn onerror(&self) -> Option<Function>

pub fn set_onerror(&self, value: Option<&Function>)

pub fn children(&self) -> HtmlCollection

pub fn first_element_child(&self) -> Option<Element>

pub fn last_element_child(&self) -> Option<Element>

pub fn child_element_count(&self) -> u32

pub fn ontouchstart(&self) -> Option<Function>

pub fn set_ontouchstart(&self, value: Option<&Function>)

pub fn ontouchend(&self) -> Option<Function>

pub fn set_ontouchend(&self, value: Option<&Function>)

pub fn ontouchmove(&self) -> Option<Function>

pub fn set_ontouchmove(&self, value: Option<&Function>)

pub fn ontouchcancel(&self) -> Option<Function>

pub fn set_ontouchcancel(&self, value: Option<&Function>)

pub fn adopt_node(&self, node: &Node) -> Result<Node, JsValue>

pub fn create_attribute(&self, name: &str) -> Result<Attr, JsValue>

pub fn create_attribute_ns( &self, namespace: Option<&str>, name: &str, ) -> Result<Attr, JsValue>

pub fn create_comment(&self, data: &str) -> Comment

pub fn create_document_fragment(&self) -> DocumentFragment

pub fn create_element(&self, local_name: &str) -> Result<Element, JsValue>

pub fn create_element_with_str( &self, local_name: &str, options: &str, ) -> Result<Element, JsValue>

pub fn create_element_ns( &self, namespace: Option<&str>, qualified_name: &str, ) -> Result<Element, JsValue>

pub fn create_element_ns_with_str( &self, namespace: Option<&str>, qualified_name: &str, options: &str, ) -> Result<Element, JsValue>

pub fn create_event(&self, _interface: &str) -> Result<Event, JsValue>

pub fn create_node_iterator(&self, root: &Node) -> Result<NodeIterator, JsValue>

pub fn create_node_iterator_with_what_to_show( &self, root: &Node, what_to_show: u32, ) -> Result<NodeIterator, JsValue>

pub fn create_node_iterator_with_what_to_show_and_filter( &self, root: &Node, what_to_show: u32, filter: Option<&NodeFilter>, ) -> Result<NodeIterator, JsValue>

pub fn create_processing_instruction( &self, target: &str, data: &str, ) -> Result<ProcessingInstruction, JsValue>

pub fn create_range(&self) -> Result<Range, JsValue>

pub fn create_text_node(&self, data: &str) -> Text

pub fn create_tree_walker(&self, root: &Node) -> Result<TreeWalker, JsValue>

pub fn create_tree_walker_with_what_to_show( &self, root: &Node, what_to_show: u32, ) -> Result<TreeWalker, JsValue>

pub fn create_tree_walker_with_what_to_show_and_filter( &self, root: &Node, what_to_show: u32, filter: Option<&NodeFilter>, ) -> Result<TreeWalker, JsValue>

pub fn enable_style_sheets_for_set(&self, name: Option<&str>)

pub fn exit_fullscreen(&self)

pub fn exit_picture_in_picture(&self) -> Promise<Undefined>

pub fn exit_pointer_lock(&self)

pub fn get_animations(&self) -> Array

pub fn get_element_by_id(&self, element_id: &str) -> Option<Element>

pub fn get_elements_by_class_name(&self, class_names: &str) -> HtmlCollection

pub fn get_elements_by_name(&self, element_name: &str) -> NodeList

pub fn get_elements_by_tag_name(&self, local_name: &str) -> HtmlCollection

pub fn get_elements_by_tag_name_ns( &self, namespace: Option<&str>, local_name: &str, ) -> Result<HtmlCollection, JsValue>

pub fn get_selection(&self) -> Result<Option<Selection>, JsValue>

pub fn has_focus(&self) -> Result<bool, JsValue>

pub fn import_node(&self, node: &Node) -> Result<Node, JsValue>

pub fn import_node_with_deep( &self, node: &Node, deep: bool, ) -> Result<Node, JsValue>

pub fn query_selector( &self, selectors: &str, ) -> Result<Option<Element>, JsValue>

pub fn query_selector_all(&self, selectors: &str) -> Result<NodeList, JsValue>

pub fn release_capture(&self)

pub fn element_from_point(&self, x: f32, y: f32) -> Option<Element>

pub fn elements_from_point(&self, x: f32, y: f32) -> Array

pub fn get_box_quads(&self) -> Result<Array, JsValue>

pub fn append_with_node(&self, nodes: &Array) -> Result<(), JsValue>

pub fn append_with_node_0(&self) -> Result<(), JsValue>

pub fn append_with_node_1(&self, nodes_1: &Node) -> Result<(), JsValue>

pub fn append_with_node_2( &self, nodes_1: &Node, nodes_2: &Node, ) -> Result<(), JsValue>

pub fn append_with_node_3( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, ) -> Result<(), JsValue>

pub fn append_with_node_4( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, ) -> Result<(), JsValue>

pub fn append_with_node_5( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, ) -> Result<(), JsValue>

pub fn append_with_node_6( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, nodes_6: &Node, ) -> Result<(), JsValue>

pub fn append_with_node_7( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, nodes_6: &Node, nodes_7: &Node, ) -> Result<(), JsValue>

pub fn append_with_str(&self, nodes: &Array) -> Result<(), JsValue>

pub fn append_with_str_0(&self) -> Result<(), JsValue>

pub fn append_with_str_1(&self, nodes_1: &str) -> Result<(), JsValue>

pub fn append_with_str_2( &self, nodes_1: &str, nodes_2: &str, ) -> Result<(), JsValue>

pub fn append_with_str_3( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, ) -> Result<(), JsValue>

pub fn append_with_str_4( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, ) -> Result<(), JsValue>

pub fn append_with_str_5( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, ) -> Result<(), JsValue>

pub fn append_with_str_6( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, nodes_6: &str, ) -> Result<(), JsValue>

pub fn append_with_str_7( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, nodes_6: &str, nodes_7: &str, ) -> Result<(), JsValue>

pub fn prepend_with_node(&self, nodes: &Array) -> Result<(), JsValue>

pub fn prepend_with_node_0(&self) -> Result<(), JsValue>

pub fn prepend_with_node_1(&self, nodes_1: &Node) -> Result<(), JsValue>

pub fn prepend_with_node_2( &self, nodes_1: &Node, nodes_2: &Node, ) -> Result<(), JsValue>

pub fn prepend_with_node_3( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, ) -> Result<(), JsValue>

pub fn prepend_with_node_4( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, ) -> Result<(), JsValue>

pub fn prepend_with_node_5( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, ) -> Result<(), JsValue>

pub fn prepend_with_node_6( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, nodes_6: &Node, ) -> Result<(), JsValue>

pub fn prepend_with_node_7( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, nodes_6: &Node, nodes_7: &Node, ) -> Result<(), JsValue>

pub fn prepend_with_str(&self, nodes: &Array) -> Result<(), JsValue>

pub fn prepend_with_str_0(&self) -> Result<(), JsValue>

pub fn prepend_with_str_1(&self, nodes_1: &str) -> Result<(), JsValue>

pub fn prepend_with_str_2( &self, nodes_1: &str, nodes_2: &str, ) -> Result<(), JsValue>

pub fn prepend_with_str_3( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, ) -> Result<(), JsValue>

pub fn prepend_with_str_4( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, ) -> Result<(), JsValue>

pub fn prepend_with_str_5( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, ) -> Result<(), JsValue>

pub fn prepend_with_str_6( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, nodes_6: &str, ) -> Result<(), JsValue>

pub fn prepend_with_str_7( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, nodes_6: &str, nodes_7: &str, ) -> Result<(), JsValue>

pub fn replace_children_with_node(&self, nodes: &Array)

pub fn replace_children_with_node_0(&self)

pub fn replace_children_with_node_1(&self, nodes_1: &Node)

pub fn replace_children_with_node_2(&self, nodes_1: &Node, nodes_2: &Node)

pub fn replace_children_with_node_3( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, )

pub fn replace_children_with_node_4( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, )

pub fn replace_children_with_node_5( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, )

pub fn replace_children_with_node_6( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, nodes_6: &Node, )

pub fn replace_children_with_node_7( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, nodes_6: &Node, nodes_7: &Node, )

pub fn replace_children_with_str(&self, nodes: &Array)

pub fn replace_children_with_str_0(&self)

pub fn replace_children_with_str_1(&self, nodes_1: &str)

pub fn replace_children_with_str_2(&self, nodes_1: &str, nodes_2: &str)

pub fn replace_children_with_str_3( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, )

pub fn replace_children_with_str_4( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, )

pub fn replace_children_with_str_5( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, )

pub fn replace_children_with_str_6( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, nodes_6: &str, )

pub fn replace_children_with_str_7( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, nodes_6: &str, nodes_7: &str, )

pub fn create_ns_resolver(&self, node_resolver: &Node) -> Node

Methods from Deref<Target = Node>

pub fn node_type(&self) -> u16

pub fn node_name(&self) -> String

pub fn base_uri(&self) -> Result<Option<String>, JsValue>

pub fn is_connected(&self) -> bool

pub fn owner_document(&self) -> Option<Document>

pub fn parent_node(&self) -> Option<Node>

pub fn parent_element(&self) -> Option<Element>

pub fn child_nodes(&self) -> NodeList

pub fn first_child(&self) -> Option<Node>

pub fn last_child(&self) -> Option<Node>

pub fn previous_sibling(&self) -> Option<Node>

pub fn next_sibling(&self) -> Option<Node>

pub fn node_value(&self) -> Option<String>

pub fn set_node_value(&self, value: Option<&str>)

pub fn text_content(&self) -> Option<String>

pub fn set_text_content(&self, value: Option<&str>)

pub fn append_child(&self, node: &Node) -> Result<Node, JsValue>

pub fn clone_node(&self) -> Result<Node, JsValue>

pub fn clone_node_with_deep(&self, deep: bool) -> Result<Node, JsValue>

pub fn compare_document_position(&self, other: &Node) -> u16

pub fn contains(&self, other: Option<&Node>) -> bool

pub fn get_root_node(&self) -> Node

pub fn has_child_nodes(&self) -> bool

pub fn insert_before( &self, node: &Node, child: Option<&Node>, ) -> Result<Node, JsValue>

pub fn is_default_namespace(&self, namespace: Option<&str>) -> bool

pub fn is_equal_node(&self, node: Option<&Node>) -> bool

pub fn is_same_node(&self, node: Option<&Node>) -> bool

pub fn lookup_namespace_uri(&self, prefix: Option<&str>) -> Option<String>

pub fn lookup_prefix(&self, namespace: Option<&str>) -> Option<String>

pub fn normalize(&self)

pub fn remove_child(&self, child: &Node) -> Result<Node, JsValue>

pub fn replace_child(&self, node: &Node, child: &Node) -> Result<Node, JsValue>

pub const ELEMENT_NODE: u16

pub const ATTRIBUTE_NODE: u16

pub const TEXT_NODE: u16

pub const CDATA_SECTION_NODE: u16

pub const ENTITY_REFERENCE_NODE: u16

pub const ENTITY_NODE: u16

pub const PROCESSING_INSTRUCTION_NODE: u16

pub const COMMENT_NODE: u16

pub const DOCUMENT_NODE: u16

pub const DOCUMENT_TYPE_NODE: u16

pub const DOCUMENT_FRAGMENT_NODE: u16

pub const NOTATION_NODE: u16

pub const DOCUMENT_POSITION_DISCONNECTED: u16

pub const DOCUMENT_POSITION_PRECEDING: u16

pub const DOCUMENT_POSITION_FOLLOWING: u16

pub const DOCUMENT_POSITION_CONTAINS: u16

pub const DOCUMENT_POSITION_CONTAINED_BY: u16

pub const DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC: u16

Methods from Deref<Target = EventTarget>

pub fn add_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>

pub fn add_event_listener_with_event_listener( &self, type_: &str, listener: &EventListener, ) -> Result<(), JsValue>

pub fn add_event_listener_with_callback_and_add_event_listener_options( &self, type_: &str, listener: &Function, options: &AddEventListenerOptions, ) -> Result<(), JsValue>

pub fn add_event_listener_with_event_listener_and_add_event_listener_options( &self, type_: &str, listener: &EventListener, options: &AddEventListenerOptions, ) -> Result<(), JsValue>

pub fn add_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>

pub fn add_event_listener_with_event_listener_and_bool( &self, type_: &str, listener: &EventListener, options: bool, ) -> Result<(), JsValue>

pub fn add_event_listener_with_callback_and_add_event_listener_options_and_wants_untrusted( &self, type_: &str, listener: &Function, options: &AddEventListenerOptions, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>

pub fn add_event_listener_with_event_listener_and_add_event_listener_options_and_wants_untrusted( &self, type_: &str, listener: &EventListener, options: &AddEventListenerOptions, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>

pub fn add_event_listener_with_callback_and_bool_and_wants_untrusted( &self, type_: &str, listener: &Function, options: bool, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>

pub fn add_event_listener_with_event_listener_and_bool_and_wants_untrusted( &self, type_: &str, listener: &EventListener, options: bool, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>

pub fn dispatch_event(&self, event: &Event) -> Result<bool, JsValue>

pub fn remove_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>

pub fn remove_event_listener_with_event_listener( &self, type_: &str, listener: &EventListener, ) -> Result<(), JsValue>

pub fn remove_event_listener_with_callback_and_event_listener_options( &self, type_: &str, listener: &Function, options: &EventListenerOptions, ) -> Result<(), JsValue>

pub fn remove_event_listener_with_event_listener_and_event_listener_options( &self, type_: &str, listener: &EventListener, options: &EventListenerOptions, ) -> Result<(), JsValue>

pub fn remove_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>

pub fn remove_event_listener_with_event_listener_and_bool( &self, type_: &str, listener: &EventListener, options: bool, ) -> Result<(), JsValue>

Methods from Deref<Target = Object>

pub fn constructor(&self) -> Function

pub fn has_own_property(&self, property: &JsValue) -> bool

👎Deprecated:

Use Object::hasOwn instead.

pub fn is_prototype_of(&self, value: &JsValue) -> bool

pub fn property_is_enumerable(&self, property: &JsValue) -> bool

pub fn to_locale_string(&self) -> JsString

pub fn to_string(&self) -> JsString

pub fn to_js_string(&self) -> JsString

pub fn value_of(&self) -> Object

Methods from Deref<Target = JsValue>

pub const NULL: JsValue

pub const UNDEFINED: JsValue

pub const TRUE: JsValue

pub const FALSE: JsValue

pub fn unchecked_into_f64(&self) -> f64

Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.

pub fn has_type<T>(&self) -> bool
where T: JsCast,

Check if this value is an instance of a specific JS type.

pub fn checked_div(&self, rhs: &JsValue) -> JsValue

Checked division.

pub fn pow(&self, rhs: &JsValue) -> JsValue

Power operation.

pub fn bit_and(&self, rhs: &JsValue) -> JsValue

Bitwise AND.

pub fn bit_or(&self, rhs: &JsValue) -> JsValue

Bitwise OR.

pub fn bit_xor(&self, rhs: &JsValue) -> JsValue

Bitwise XOR.

pub fn bit_not(&self) -> JsValue

Bitwise NOT.

pub fn shl(&self, rhs: &JsValue) -> JsValue

Left shift.

pub fn shr(&self, rhs: &JsValue) -> JsValue

Signed right shift.

pub fn unsigned_shr(&self, rhs: &JsValue) -> u32

Unsigned right shift.

pub fn add(&self, rhs: &JsValue) -> JsValue

Add.

pub fn sub(&self, rhs: &JsValue) -> JsValue

Subtract.

pub fn mul(&self, rhs: &JsValue) -> JsValue

Multiply.

pub fn div(&self, rhs: &JsValue) -> JsValue

Divide.

pub fn rem(&self, rhs: &JsValue) -> JsValue

Remainder.

pub fn neg(&self) -> JsValue

Negate.

pub fn lt(&self, other: &JsValue) -> bool

Less than comparison.

pub fn le(&self, other: &JsValue) -> bool

Less than or equal comparison.

pub fn gt(&self, other: &JsValue) -> bool

Greater than comparison.

pub fn ge(&self, other: &JsValue) -> bool

Greater than or equal comparison.

pub fn loose_eq(&self, other: &JsValue) -> bool

Loose equality (==).

pub fn is_falsy(&self) -> bool

Check if this value is a falsy value in JavaScript.

pub fn is_truthy(&self) -> bool

Check if this value is a truthy value in JavaScript.

pub fn is_object(&self) -> bool

Check if this value is an object.

pub fn is_function(&self) -> bool

Check if this value is a function.

pub fn is_string(&self) -> bool

Check if this value is a string.

pub fn is_symbol(&self) -> bool

Check if this value is a symbol.

pub fn is_bigint(&self) -> bool

Check if this value is a bigint.

pub fn is_array(&self) -> bool

Check if this value is an Array.

pub fn is_undefined(&self) -> bool

Check if this value is undefined.

pub fn is_null(&self) -> bool

Check if this value is null.

pub fn is_null_or_undefined(&self) -> bool

Check if this value is null or undefined.

pub fn js_typeof(&self) -> JsValue

Get the typeof this value as a string.

pub fn js_in(&self, obj: &JsValue) -> bool

Check if this value has a property with the given name.

pub fn as_bool(&self) -> Option<bool>

Get the value as a bool.

pub fn as_f64(&self) -> Option<f64>

Get the value as an f64.

pub fn as_string(&self) -> Option<String>

Get the value as a string.

pub fn as_debug_string(&self) -> String

Get a debug string representation of the value.