pub struct Navigator { /* private fields */ }Expand description
The Navigator class.
This API requires the following crate features to be activated: Navigator
Implementations
pub fn permissions(&self) -> Result<Permissions, JsValue>
pub fn do_not_track(&self) -> String
pub fn max_touch_points(&self) -> i32
pub fn active_vr_displays(&self) -> Array
pub fn media_devices(&self) -> Result<MediaDevices, JsValue>
pub fn service_worker(&self) -> ServiceWorkerContainer
pub fn user_activation(&self) -> UserActivation
pub fn hardware_concurrency(&self) -> f64
pub fn device_memory(&self) -> f64
pub fn geolocation(&self) -> Result<Geolocation, JsValue>
pub fn app_code_name(&self) -> Result<String, JsValue>
pub fn app_version(&self) -> Result<String, JsValue>
pub fn user_agent(&self) -> Result<String, JsValue>
pub fn storage(&self) -> StorageManager
pub fn get_gamepads(&self) -> Result<Array, JsValue>
pub fn get_vr_displays(&self) -> Result<Promise, JsValue>
pub fn request_midi_access(&self) -> Result<Promise, JsValue>
pub fn request_media_key_system_access( &self, key_system: &str, supported_configurations: &JsValue, ) -> Promise
pub fn send_beacon_with_opt_js_u8_array( &self, url: &str, data: Option<&Uint8Array>, ) -> Result<bool, JsValue>
pub fn send_beacon_with_opt_url_search_params( &self, url: &str, data: Option<&UrlSearchParams>, ) -> Result<bool, JsValue>
pub fn send_beacon_with_opt_readable_stream( &self, url: &str, data: Option<&ReadableStream>, ) -> Result<bool, JsValue>
pub fn vibrate_with_duration(&self, pattern: u32) -> bool
pub fn vibrate_with_pattern(&self, pattern: &JsValue) -> bool
pub fn taint_enabled(&self) -> bool
Methods from Deref<Target = Object>
pub fn constructor(&self) -> Function
pub fn has_own_property(&self, property: &JsValue) -> bool
👎Deprecated:
Use Object::hasOwn instead.
pub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn to_locale_string(&self) -> JsString
pub fn to_string(&self) -> JsString
pub fn to_js_string(&self) -> JsString
pub fn value_of(&self) -> Object
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Check if this value is null or undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.