#[repr(transparent)]pub struct Navigator { /* private fields */ }Expand description
The Navigator class.
This API requires the following crate features to be activated: Navigator
Implementations
Getter for the permissions field of this object.
This API requires the following crate features to be activated: Navigator, Permissions
Getter for the mimeTypes field of this object.
This API requires the following crate features to be activated: MimeTypeArray, Navigator
Getter for the plugins field of this object.
This API requires the following crate features to be activated: Navigator, PluginArray
Getter for the doNotTrack field of this object.
This API requires the following crate features to be activated: Navigator
Getter for the maxTouchPoints field of this object.
This API requires the following crate features to be activated: Navigator
Getter for the mediaCapabilities field of this object.
This API requires the following crate features to be activated: MediaCapabilities, Navigator
Getter for the connection field of this object.
This API requires the following crate features to be activated: Navigator, NetworkInformation
Getter for the activeVRDisplays field of this object.
This API requires the following crate features to be activated: Navigator
Getter for the mediaDevices field of this object.
This API requires the following crate features to be activated: MediaDevices, Navigator
Getter for the serviceWorker field of this object.
This API requires the following crate features to be activated: Navigator, ServiceWorkerContainer
Getter for the presentation field of this object.
This API requires the following crate features to be activated: Navigator, Presentation
Getter for the credentials field of this object.
This API requires the following crate features to be activated: CredentialsContainer, Navigator
Getter for the bluetooth field of this object.
This API requires the following crate features to be activated: Bluetooth, Navigator
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Getter for the clipboard field of this object.
This API requires the following crate features to be activated: Clipboard, Navigator
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Getter for the wakeLock field of this object.
This API requires the following crate features to be activated: Navigator, WakeLock
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Getter for the hid field of this object.
This API requires the following crate features to be activated: Hid, Navigator
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Getter for the usb field of this object.
This API requires the following crate features to be activated: Navigator, Usb
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Getter for the xr field of this object.
This API requires the following crate features to be activated: Navigator, Xr
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Getter for the hardwareConcurrency field of this object.
This API requires the following crate features to be activated: Navigator
Getter for the gpu field of this object.
This API requires the following crate features to be activated: Gpu, Navigator
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Getter for the geolocation field of this object.
This API requires the following crate features to be activated: Geolocation, Navigator
Getter for the appCodeName field of this object.
This API requires the following crate features to be activated: Navigator
Getter for the appName field of this object.
This API requires the following crate features to be activated: Navigator
Getter for the appVersion field of this object.
This API requires the following crate features to be activated: Navigator
Getter for the userAgent field of this object.
This API requires the following crate features to be activated: Navigator
Getter for the product field of this object.
This API requires the following crate features to be activated: Navigator
Getter for the language field of this object.
This API requires the following crate features to be activated: Navigator
Getter for the languages field of this object.
This API requires the following crate features to be activated: Navigator
Getter for the onLine field of this object.
This API requires the following crate features to be activated: Navigator
Getter for the storage field of this object.
This API requires the following crate features to be activated: Navigator, StorageManager
The getGamepads() method.
This API requires the following crate features to be activated: Navigator
The getVRDisplays() method.
This API requires the following crate features to be activated: Navigator
The requestGamepadServiceTest() method.
This API requires the following crate features to be activated: GamepadServiceTest, Navigator
The requestMIDIAccess() method.
This API requires the following crate features to be activated: Navigator
pub fn request_midi_access_with_options(
&self,
options: &MidiOptions
) -> Result<Promise, JsValue>
pub fn request_midi_access_with_options(
&self,
options: &MidiOptions
) -> Result<Promise, JsValue>
The requestMIDIAccess() method.
This API requires the following crate features to be activated: MidiOptions, Navigator
pub fn request_media_key_system_access(
&self,
key_system: &str,
supported_configurations: &JsValue
) -> Promise
pub fn request_media_key_system_access(
&self,
key_system: &str,
supported_configurations: &JsValue
) -> Promise
The requestMediaKeySystemAccess() method.
This API requires the following crate features to be activated: Navigator
The requestVRServiceTest() method.
This API requires the following crate features to be activated: Navigator, VrServiceTest
The sendBeacon() method.
This API requires the following crate features to be activated: Navigator
The sendBeacon() method.
This API requires the following crate features to be activated: Blob, Navigator
The sendBeacon() method.
This API requires the following crate features to be activated: Navigator
The sendBeacon() method.
This API requires the following crate features to be activated: FormData, Navigator
pub fn send_beacon_with_opt_url_search_params(
&self,
url: &str,
data: Option<&UrlSearchParams>
) -> Result<bool, JsValue>
pub fn send_beacon_with_opt_url_search_params(
&self,
url: &str,
data: Option<&UrlSearchParams>
) -> Result<bool, JsValue>
The sendBeacon() method.
This API requires the following crate features to be activated: Navigator, UrlSearchParams
The sendBeacon() method.
This API requires the following crate features to be activated: Navigator
pub fn send_beacon_with_opt_readable_stream(
&self,
url: &str,
data: Option<&ReadableStream>
) -> Result<bool, JsValue>
pub fn send_beacon_with_opt_readable_stream(
&self,
url: &str,
data: Option<&ReadableStream>
) -> Result<bool, JsValue>
The sendBeacon() method.
This API requires the following crate features to be activated: Navigator, ReadableStream
The vibrate() method.
This API requires the following crate features to be activated: Navigator
The vibrate() method.
This API requires the following crate features to be activated: Navigator
The registerContentHandler() method.
This API requires the following crate features to be activated: Navigator
The registerProtocolHandler() method.
This API requires the following crate features to be activated: Navigator
The taintEnabled() method.
This API requires the following crate features to be activated: Navigator
Methods from Deref<Target = Object>
The constructor property returns a reference to the Object constructor
function that created the instance object.
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
The toString() method returns a string representing the object.
The valueOf() method returns the primitive value of the
specified object.
Methods from Deref<Target = JsValue>
Returns the f64 value of this JS value if it’s an instance of a
number.
If this JS value is not an instance of a number then this returns
None.
If this JS value is a string value, this function copies the JS string
value into wasm linear memory, encoded as UTF-8, and returns it as a
Rust String.
To avoid the copying and re-encoding, consider the
JsString::try_from() function from js-sys
instead.
If this JS value is not an instance of a string or if it’s not valid
utf-8 then this returns None.
UTF-16 vs UTF-8
JavaScript strings in general are encoded as UTF-16, but Rust strings
are encoded as UTF-8. This can cause the Rust string to look a bit
different than the JS string sometimes. For more details see the
documentation about the str type which contains a few
caveats about the encodings.
Returns the bool value of this JS value if it’s an instance of a
boolean.
If this JS value is not an instance of a boolean then this returns
None.
Tests whether this JS value is undefined
Tests whether the type of this JS value is function.
Applies the unary typeof JS operator on a JsValue.
Applies the binary in JS operator on the two JsValues.
Compare two JsValues for equality, using the == operator in JS.
Applies the unary ~ JS operator on a JsValue.
Applies the binary >>> JS operator on the two JsValues.
Applies the binary / JS operator on two JsValues, catching and returning any RangeError thrown.
Applies the binary ** JS operator on the two JsValues.
Applies the binary < JS operator on the two JsValues.
Applies the binary <= JS operator on the two JsValues.
Applies the binary >= JS operator on the two JsValues.
Applies the binary > JS operator on the two JsValues.
Applies the unary + JS operator on a JsValue. Can throw.