pub struct PointerEvent { /* private fields */ }Expand description
The PointerEvent class.
This API requires the following crate features to be activated: PointerEvent
Implementations
Sourceimpl PointerEvent
impl PointerEvent
pub fn pointer_id(&self) -> i32
Sourceimpl PointerEvent
impl PointerEvent
pub fn tangential_pressure(&self) -> f32
Sourceimpl PointerEvent
impl PointerEvent
pub fn pointer_type(&self) -> String
Sourceimpl PointerEvent
impl PointerEvent
pub fn is_primary(&self) -> bool
Sourceimpl PointerEvent
impl PointerEvent
Sourceimpl PointerEvent
impl PointerEvent
pub fn new_with_event_init_dict( type_: &str, event_init_dict: &PointerEventInit, ) -> Result<PointerEvent, JsValue>
Sourceimpl PointerEvent
impl PointerEvent
pub fn get_coalesced_events(&self) -> Array
Methods from Deref<Target = MouseEvent>
pub fn x(&self) -> i32
pub fn y(&self) -> i32
pub fn ctrl_key(&self) -> bool
pub fn shift_key(&self) -> bool
pub fn alt_key(&self) -> bool
pub fn meta_key(&self) -> bool
pub fn region(&self) -> Option<String>
pub fn movement_x(&self) -> i32
pub fn movement_y(&self) -> i32
pub fn screen_x(&self) -> f64
pub fn screen_y(&self) -> f64
pub fn client_x(&self) -> f64
pub fn client_y(&self) -> f64
pub fn offset_x(&self) -> f64
pub fn offset_y(&self) -> f64
pub fn page_x(&self) -> f64
pub fn page_y(&self) -> f64
pub fn get_modifier_state(&self, key_arg: &str) -> bool
pub fn init_mouse_event(&self, type_arg: &str)
pub fn init_mouse_event_with_can_bubble_arg( &self, type_arg: &str, can_bubble_arg: bool, )
pub fn init_mouse_event_with_can_bubble_arg_and_cancelable_arg( &self, type_arg: &str, can_bubble_arg: bool, cancelable_arg: bool, )
pub fn init_mouse_event_with_can_bubble_arg_and_cancelable_arg_and_view_arg( &self, type_arg: &str, can_bubble_arg: bool, cancelable_arg: bool, view_arg: Option<&Window>, )
pub fn init_mouse_event_with_can_bubble_arg_and_cancelable_arg_and_view_arg_and_detail_arg( &self, type_arg: &str, can_bubble_arg: bool, cancelable_arg: bool, view_arg: Option<&Window>, detail_arg: i32, )
pub fn init_mouse_event_with_can_bubble_arg_and_cancelable_arg_and_view_arg_and_detail_arg_and_screen_x_arg( &self, type_arg: &str, can_bubble_arg: bool, cancelable_arg: bool, view_arg: Option<&Window>, detail_arg: i32, screen_x_arg: i32, )
pub fn init_mouse_event_with_can_bubble_arg_and_cancelable_arg_and_view_arg_and_detail_arg_and_screen_x_arg_and_screen_y_arg( &self, type_arg: &str, can_bubble_arg: bool, cancelable_arg: bool, view_arg: Option<&Window>, detail_arg: i32, screen_x_arg: i32, screen_y_arg: i32, )
pub fn init_mouse_event_with_can_bubble_arg_and_cancelable_arg_and_view_arg_and_detail_arg_and_screen_x_arg_and_screen_y_arg_and_client_x_arg( &self, type_arg: &str, can_bubble_arg: bool, cancelable_arg: bool, view_arg: Option<&Window>, detail_arg: i32, screen_x_arg: i32, screen_y_arg: i32, client_x_arg: i32, )
pub fn init_mouse_event_with_can_bubble_arg_and_cancelable_arg_and_view_arg_and_detail_arg_and_screen_x_arg_and_screen_y_arg_and_client_x_arg_and_client_y_arg( &self, type_arg: &str, can_bubble_arg: bool, cancelable_arg: bool, view_arg: Option<&Window>, detail_arg: i32, screen_x_arg: i32, screen_y_arg: i32, client_x_arg: i32, client_y_arg: i32, )
pub fn init_mouse_event_with_can_bubble_arg_and_cancelable_arg_and_view_arg_and_detail_arg_and_screen_x_arg_and_screen_y_arg_and_client_x_arg_and_client_y_arg_and_ctrl_key_arg( &self, type_arg: &str, can_bubble_arg: bool, cancelable_arg: bool, view_arg: Option<&Window>, detail_arg: i32, screen_x_arg: i32, screen_y_arg: i32, client_x_arg: i32, client_y_arg: i32, ctrl_key_arg: bool, )
pub fn init_mouse_event_with_can_bubble_arg_and_cancelable_arg_and_view_arg_and_detail_arg_and_screen_x_arg_and_screen_y_arg_and_client_x_arg_and_client_y_arg_and_ctrl_key_arg_and_alt_key_arg( &self, type_arg: &str, can_bubble_arg: bool, cancelable_arg: bool, view_arg: Option<&Window>, detail_arg: i32, screen_x_arg: i32, screen_y_arg: i32, client_x_arg: i32, client_y_arg: i32, ctrl_key_arg: bool, alt_key_arg: bool, )
pub fn init_mouse_event_with_can_bubble_arg_and_cancelable_arg_and_view_arg_and_detail_arg_and_screen_x_arg_and_screen_y_arg_and_client_x_arg_and_client_y_arg_and_ctrl_key_arg_and_alt_key_arg_and_shift_key_arg( &self, type_arg: &str, can_bubble_arg: bool, cancelable_arg: bool, view_arg: Option<&Window>, detail_arg: i32, screen_x_arg: i32, screen_y_arg: i32, client_x_arg: i32, client_y_arg: i32, ctrl_key_arg: bool, alt_key_arg: bool, shift_key_arg: bool, )
pub fn init_mouse_event_with_can_bubble_arg_and_cancelable_arg_and_view_arg_and_detail_arg_and_screen_x_arg_and_screen_y_arg_and_client_x_arg_and_client_y_arg_and_ctrl_key_arg_and_alt_key_arg_and_shift_key_arg_and_meta_key_arg( &self, type_arg: &str, can_bubble_arg: bool, cancelable_arg: bool, view_arg: Option<&Window>, detail_arg: i32, screen_x_arg: i32, screen_y_arg: i32, client_x_arg: i32, client_y_arg: i32, ctrl_key_arg: bool, alt_key_arg: bool, shift_key_arg: bool, meta_key_arg: bool, )
Methods from Deref<Target = UiEvent>
pub fn view(&self) -> Option<Window>
pub fn detail(&self) -> i32
pub fn layer_x(&self) -> i32
pub fn layer_y(&self) -> i32
pub fn page_x(&self) -> i32
pub fn page_y(&self) -> i32
pub fn which(&self) -> u32
pub fn range_parent(&self) -> Option<Node>
pub fn range_offset(&self) -> i32
pub fn init_ui_event(&self, a_type: &str)
pub fn init_ui_event_with_a_can_bubble(&self, a_type: &str, a_can_bubble: bool)
pub fn init_ui_event_with_a_can_bubble_and_a_cancelable( &self, a_type: &str, a_can_bubble: bool, a_cancelable: bool, )
pub fn init_ui_event_with_a_can_bubble_and_a_cancelable_and_a_view( &self, a_type: &str, a_can_bubble: bool, a_cancelable: bool, a_view: Option<&Window>, )
pub fn init_ui_event_with_a_can_bubble_and_a_cancelable_and_a_view_and_a_detail( &self, a_type: &str, a_can_bubble: bool, a_cancelable: bool, a_view: Option<&Window>, a_detail: i32, )
pub const SCROLL_PAGE_UP: i32
pub const SCROLL_PAGE_DOWN: i32
Methods from Deref<Target = Event>
pub fn type_(&self) -> String
pub fn target(&self) -> Option<EventTarget>
pub fn current_target(&self) -> Option<EventTarget>
pub fn event_phase(&self) -> u16
pub fn bubbles(&self) -> bool
pub fn cancelable(&self) -> bool
pub fn default_prevented(&self) -> bool
pub fn composed(&self) -> bool
pub fn is_trusted(&self) -> bool
pub fn time_stamp(&self) -> f64
pub fn cancel_bubble(&self) -> bool
pub fn set_cancel_bubble(&self, value: bool)
pub fn composed_path(&self) -> Array
pub fn init_event(&self, type_: &str)
pub fn init_event_with_bubbles(&self, type_: &str, bubbles: bool)
pub fn init_event_with_bubbles_and_cancelable( &self, type_: &str, bubbles: bool, cancelable: bool, )
pub fn prevent_default(&self)
pub fn stop_immediate_propagation(&self)
pub fn stop_propagation(&self)
pub const NONE: u16
pub const CAPTURING_PHASE: u16
pub const AT_TARGET: u16
pub const BUBBLING_PHASE: u16
Methods from Deref<Target = Object>
pub fn constructor(&self) -> Function
pub fn has_own_property(&self, property: &JsValue) -> bool
👎Deprecated:
Use Object::hasOwn instead.
pub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn to_locale_string(&self) -> JsString
pub fn to_string(&self) -> JsString
pub fn to_js_string(&self) -> JsString
pub fn value_of(&self) -> Object
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Check if this value is null or undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.