#[repr(transparent)]pub struct Response {
pub obj: Object,
}Expand description
The Response class.
This API requires the following crate features to be activated: Response
Fields
obj: ObjectImplementations
Sourceimpl Response
impl Response
Sourcepub fn type_(&self) -> ResponseType
pub fn type_(&self) -> ResponseType
Getter for the type field of this object.
This API requires the following crate features to be activated: Response, ResponseType
Sourceimpl Response
impl Response
Sourceimpl Response
impl Response
Sourcepub fn redirected(&self) -> bool
pub fn redirected(&self) -> bool
Getter for the redirected field of this object.
This API requires the following crate features to be activated: Response
Sourceimpl Response
impl Response
Sourceimpl Response
impl Response
Sourceimpl Response
impl Response
Sourcepub fn status_text(&self) -> String
pub fn status_text(&self) -> String
Getter for the statusText field of this object.
This API requires the following crate features to be activated: Response
Sourceimpl Response
impl Response
Sourceimpl Response
impl Response
Sourceimpl Response
impl Response
Sourcepub fn body(&self) -> Option<ReadableStream>
pub fn body(&self) -> Option<ReadableStream>
Getter for the body field of this object.
This API requires the following crate features to be activated: ReadableStream, Response
Sourceimpl Response
impl Response
Sourceimpl Response
impl Response
Sourceimpl Response
impl Response
Sourceimpl Response
impl Response
Sourcepub fn new_with_opt_js_u8_array(
body: Option<&Uint8Array>,
) -> Result<Response, JsValue>
pub fn new_with_opt_js_u8_array( body: Option<&Uint8Array>, ) -> Result<Response, JsValue>
The new Response(..) constructor, creating a new instance of Response.
This API requires the following crate features to be activated: Response
Sourceimpl Response
impl Response
Sourceimpl Response
impl Response
Sourcepub fn new_with_opt_url_search_params(
body: Option<&UrlSearchParams>,
) -> Result<Response, JsValue>
pub fn new_with_opt_url_search_params( body: Option<&UrlSearchParams>, ) -> Result<Response, JsValue>
The new Response(..) constructor, creating a new instance of Response.
This API requires the following crate features to be activated: Response, UrlSearchParams
Sourceimpl Response
impl Response
Sourceimpl Response
impl Response
Sourcepub fn new_with_opt_readable_stream(
body: Option<&ReadableStream>,
) -> Result<Response, JsValue>
pub fn new_with_opt_readable_stream( body: Option<&ReadableStream>, ) -> Result<Response, JsValue>
The new Response(..) constructor, creating a new instance of Response.
This API requires the following crate features to be activated: ReadableStream, Response
Sourceimpl Response
impl Response
Sourcepub fn new_with_opt_blob_and_init(
body: Option<&Blob>,
init: &ResponseInit,
) -> Result<Response, JsValue>
pub fn new_with_opt_blob_and_init( body: Option<&Blob>, init: &ResponseInit, ) -> Result<Response, JsValue>
The new Response(..) constructor, creating a new instance of Response.
This API requires the following crate features to be activated: Blob, Response, ResponseInit
Sourceimpl Response
impl Response
Sourcepub fn new_with_opt_buffer_source_and_init(
body: Option<&Object>,
init: &ResponseInit,
) -> Result<Response, JsValue>
pub fn new_with_opt_buffer_source_and_init( body: Option<&Object>, init: &ResponseInit, ) -> Result<Response, JsValue>
The new Response(..) constructor, creating a new instance of Response.
This API requires the following crate features to be activated: Response, ResponseInit
Sourceimpl Response
impl Response
Sourcepub fn new_with_opt_u8_array_and_init(
body: Option<&mut [u8]>,
init: &ResponseInit,
) -> Result<Response, JsValue>
pub fn new_with_opt_u8_array_and_init( body: Option<&mut [u8]>, init: &ResponseInit, ) -> Result<Response, JsValue>
The new Response(..) constructor, creating a new instance of Response.
This API requires the following crate features to be activated: Response, ResponseInit
Sourceimpl Response
impl Response
Sourcepub fn new_with_opt_js_u8_array_and_init(
body: Option<&Uint8Array>,
init: &ResponseInit,
) -> Result<Response, JsValue>
pub fn new_with_opt_js_u8_array_and_init( body: Option<&Uint8Array>, init: &ResponseInit, ) -> Result<Response, JsValue>
The new Response(..) constructor, creating a new instance of Response.
This API requires the following crate features to be activated: Response, ResponseInit
Sourceimpl Response
impl Response
Sourcepub fn new_with_opt_form_data_and_init(
body: Option<&FormData>,
init: &ResponseInit,
) -> Result<Response, JsValue>
pub fn new_with_opt_form_data_and_init( body: Option<&FormData>, init: &ResponseInit, ) -> Result<Response, JsValue>
The new Response(..) constructor, creating a new instance of Response.
This API requires the following crate features to be activated: FormData, Response, ResponseInit
Sourceimpl Response
impl Response
Sourcepub fn new_with_opt_url_search_params_and_init(
body: Option<&UrlSearchParams>,
init: &ResponseInit,
) -> Result<Response, JsValue>
pub fn new_with_opt_url_search_params_and_init( body: Option<&UrlSearchParams>, init: &ResponseInit, ) -> Result<Response, JsValue>
The new Response(..) constructor, creating a new instance of Response.
This API requires the following crate features to be activated: Response, ResponseInit, UrlSearchParams
Sourceimpl Response
impl Response
Sourcepub fn new_with_opt_str_and_init(
body: Option<&str>,
init: &ResponseInit,
) -> Result<Response, JsValue>
pub fn new_with_opt_str_and_init( body: Option<&str>, init: &ResponseInit, ) -> Result<Response, JsValue>
The new Response(..) constructor, creating a new instance of Response.
This API requires the following crate features to be activated: Response, ResponseInit
Sourceimpl Response
impl Response
Sourcepub fn new_with_opt_readable_stream_and_init(
body: Option<&ReadableStream>,
init: &ResponseInit,
) -> Result<Response, JsValue>
pub fn new_with_opt_readable_stream_and_init( body: Option<&ReadableStream>, init: &ResponseInit, ) -> Result<Response, JsValue>
The new Response(..) constructor, creating a new instance of Response.
This API requires the following crate features to be activated: ReadableStream, Response, ResponseInit
Sourceimpl Response
impl Response
Sourceimpl Response
impl Response
Sourceimpl Response
impl Response
Sourcepub fn array_buffer(&self) -> Result<Promise, JsValue>
pub fn array_buffer(&self) -> Result<Promise, JsValue>
The arrayBuffer() method.
This API requires the following crate features to be activated: Response
Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
👎Deprecated: Use Object::hasOwn instead.
pub fn has_own_property(&self, property: &JsValue) -> bool
Use Object::hasOwn instead.
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Sourcepub fn to_js_string(&self) -> JsString
pub fn to_js_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Check if this value is null or undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.