Struct web_sys::SourceBuffer
source · [−]#[repr(transparent)]pub struct SourceBuffer { /* private fields */ }Expand description
The SourceBuffer class.
This API requires the following crate features to be activated: SourceBuffer
Implementations
Getter for the mode field of this object.
This API requires the following crate features to be activated: SourceBuffer, SourceBufferAppendMode
Setter for the mode field of this object.
This API requires the following crate features to be activated: SourceBuffer, SourceBufferAppendMode
Getter for the updating field of this object.
This API requires the following crate features to be activated: SourceBuffer
Getter for the buffered field of this object.
This API requires the following crate features to be activated: SourceBuffer, TimeRanges
Getter for the timestampOffset field of this object.
This API requires the following crate features to be activated: SourceBuffer
Setter for the timestampOffset field of this object.
This API requires the following crate features to be activated: SourceBuffer
Getter for the appendWindowStart field of this object.
This API requires the following crate features to be activated: SourceBuffer
Setter for the appendWindowStart field of this object.
This API requires the following crate features to be activated: SourceBuffer
Getter for the appendWindowEnd field of this object.
This API requires the following crate features to be activated: SourceBuffer
Setter for the appendWindowEnd field of this object.
This API requires the following crate features to be activated: SourceBuffer
Getter for the onupdatestart field of this object.
This API requires the following crate features to be activated: SourceBuffer
Setter for the onupdatestart field of this object.
This API requires the following crate features to be activated: SourceBuffer
Getter for the onupdate field of this object.
This API requires the following crate features to be activated: SourceBuffer
Setter for the onupdate field of this object.
This API requires the following crate features to be activated: SourceBuffer
Getter for the onupdateend field of this object.
This API requires the following crate features to be activated: SourceBuffer
Setter for the onupdateend field of this object.
This API requires the following crate features to be activated: SourceBuffer
Getter for the onerror field of this object.
This API requires the following crate features to be activated: SourceBuffer
Setter for the onerror field of this object.
This API requires the following crate features to be activated: SourceBuffer
Getter for the onabort field of this object.
This API requires the following crate features to be activated: SourceBuffer
Setter for the onabort field of this object.
This API requires the following crate features to be activated: SourceBuffer
The appendBuffer() method.
This API requires the following crate features to be activated: SourceBuffer
The appendBuffer() method.
This API requires the following crate features to be activated: SourceBuffer
The appendBuffer() method.
This API requires the following crate features to be activated: SourceBuffer
pub fn append_buffer_async_with_array_buffer(
&self,
data: &ArrayBuffer
) -> Result<Promise, JsValue>
pub fn append_buffer_async_with_array_buffer(
&self,
data: &ArrayBuffer
) -> Result<Promise, JsValue>
The appendBufferAsync() method.
This API requires the following crate features to be activated: SourceBuffer
The appendBufferAsync() method.
This API requires the following crate features to be activated: SourceBuffer
The appendBufferAsync() method.
This API requires the following crate features to be activated: SourceBuffer
The changeType() method.
This API requires the following crate features to be activated: SourceBuffer
The removeAsync() method.
This API requires the following crate features to be activated: SourceBuffer
Methods from Deref<Target = EventTarget>
The addEventListener() method.
This API requires the following crate features to be activated: EventTarget
pub fn add_event_listener_with_event_listener(
&self,
type_: &str,
listener: &EventListener
) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener(
&self,
type_: &str,
listener: &EventListener
) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: EventListener, EventTarget
pub fn add_event_listener_with_callback_and_add_event_listener_options(
&self,
type_: &str,
listener: &Function,
options: &AddEventListenerOptions
) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_add_event_listener_options(
&self,
type_: &str,
listener: &Function,
options: &AddEventListenerOptions
) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: AddEventListenerOptions, EventTarget
pub fn add_event_listener_with_event_listener_and_add_event_listener_options(
&self,
type_: &str,
listener: &EventListener,
options: &AddEventListenerOptions
) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_add_event_listener_options(
&self,
type_: &str,
listener: &EventListener,
options: &AddEventListenerOptions
) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: AddEventListenerOptions, EventListener, EventTarget
The addEventListener() method.
This API requires the following crate features to be activated: EventTarget
pub fn add_event_listener_with_event_listener_and_bool(
&self,
type_: &str,
listener: &EventListener,
options: bool
) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_bool(
&self,
type_: &str,
listener: &EventListener,
options: bool
) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: EventListener, EventTarget
pub fn add_event_listener_with_callback_and_add_event_listener_options_and_wants_untrusted(
&self,
type_: &str,
listener: &Function,
options: &AddEventListenerOptions,
wants_untrusted: Option<bool>
) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_add_event_listener_options_and_wants_untrusted(
&self,
type_: &str,
listener: &Function,
options: &AddEventListenerOptions,
wants_untrusted: Option<bool>
) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: AddEventListenerOptions, EventTarget
pub fn add_event_listener_with_event_listener_and_add_event_listener_options_and_wants_untrusted(
&self,
type_: &str,
listener: &EventListener,
options: &AddEventListenerOptions,
wants_untrusted: Option<bool>
) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_add_event_listener_options_and_wants_untrusted(
&self,
type_: &str,
listener: &EventListener,
options: &AddEventListenerOptions,
wants_untrusted: Option<bool>
) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: AddEventListenerOptions, EventListener, EventTarget
The addEventListener() method.
This API requires the following crate features to be activated: EventTarget
pub fn add_event_listener_with_event_listener_and_bool_and_wants_untrusted(
&self,
type_: &str,
listener: &EventListener,
options: bool,
wants_untrusted: Option<bool>
) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_bool_and_wants_untrusted(
&self,
type_: &str,
listener: &EventListener,
options: bool,
wants_untrusted: Option<bool>
) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: EventListener, EventTarget
The dispatchEvent() method.
This API requires the following crate features to be activated: Event, EventTarget
The removeEventListener() method.
This API requires the following crate features to be activated: EventTarget
pub fn remove_event_listener_with_event_listener(
&self,
type_: &str,
listener: &EventListener
) -> Result<(), JsValue>
pub fn remove_event_listener_with_event_listener(
&self,
type_: &str,
listener: &EventListener
) -> Result<(), JsValue>
The removeEventListener() method.
This API requires the following crate features to be activated: EventListener, EventTarget
pub fn remove_event_listener_with_callback_and_event_listener_options(
&self,
type_: &str,
listener: &Function,
options: &EventListenerOptions
) -> Result<(), JsValue>
pub fn remove_event_listener_with_callback_and_event_listener_options(
&self,
type_: &str,
listener: &Function,
options: &EventListenerOptions
) -> Result<(), JsValue>
The removeEventListener() method.
This API requires the following crate features to be activated: EventListenerOptions, EventTarget
pub fn remove_event_listener_with_event_listener_and_event_listener_options(
&self,
type_: &str,
listener: &EventListener,
options: &EventListenerOptions
) -> Result<(), JsValue>
pub fn remove_event_listener_with_event_listener_and_event_listener_options(
&self,
type_: &str,
listener: &EventListener,
options: &EventListenerOptions
) -> Result<(), JsValue>
The removeEventListener() method.
This API requires the following crate features to be activated: EventListener, EventListenerOptions, EventTarget
The removeEventListener() method.
This API requires the following crate features to be activated: EventTarget
pub fn remove_event_listener_with_event_listener_and_bool(
&self,
type_: &str,
listener: &EventListener,
options: bool
) -> Result<(), JsValue>
pub fn remove_event_listener_with_event_listener_and_bool(
&self,
type_: &str,
listener: &EventListener,
options: bool
) -> Result<(), JsValue>
The removeEventListener() method.
This API requires the following crate features to be activated: EventListener, EventTarget
Methods from Deref<Target = Object>
The constructor property returns a reference to the Object constructor
function that created the instance object.
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
The toString() method returns a string representing the object.
The valueOf() method returns the primitive value of the
specified object.
Methods from Deref<Target = JsValue>
Returns the f64 value of this JS value if it’s an instance of a
number.
If this JS value is not an instance of a number then this returns
None.
If this JS value is a string value, this function copies the JS string
value into wasm linear memory, encoded as UTF-8, and returns it as a
Rust String.
To avoid the copying and re-encoding, consider the
JsString::try_from() function from js-sys
instead.
If this JS value is not an instance of a string or if it’s not valid
utf-8 then this returns None.
UTF-16 vs UTF-8
JavaScript strings in general are encoded as UTF-16, but Rust strings
are encoded as UTF-8. This can cause the Rust string to look a bit
different than the JS string sometimes. For more details see the
documentation about the str type which contains a few
caveats about the encodings.
Returns the bool value of this JS value if it’s an instance of a
boolean.
If this JS value is not an instance of a boolean then this returns
None.
Tests whether this JS value is undefined
Tests whether the type of this JS value is function.
Applies the unary typeof JS operator on a JsValue.
Applies the binary in JS operator on the two JsValues.
Compare two JsValues for equality, using the == operator in JS.
Applies the unary ~ JS operator on a JsValue.
Applies the binary >>> JS operator on the two JsValues.
Applies the binary / JS operator on two JsValues, catching and returning any RangeError thrown.
Applies the binary ** JS operator on the two JsValues.
Applies the binary < JS operator on the two JsValues.
Applies the binary <= JS operator on the two JsValues.
Applies the binary >= JS operator on the two JsValues.
Applies the binary > JS operator on the two JsValues.
Applies the unary + JS operator on a JsValue. Can throw.