SvgElement

Struct SvgElement 

pub struct SvgElement { /* private fields */ }
The SvgElement class.

MDN Documentation

This API requires the following crate features to be activated: SvgElement

Implementations

Source

impl SvgElement

pub fn id(&self) -> String

Source

impl SvgElement

pub fn set_id(&self, value: &str)

Source

impl SvgElement

Source

impl SvgElement

Source

impl SvgElement

pub fn oncopy(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_oncopy(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn oncut(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_oncut(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn onpaste(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_onpaste(&self, value: Option<&Function>)

Source

impl SvgElement

Source

impl SvgElement

pub fn onabort(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_onabort(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn onblur(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_onblur(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn onfocus(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_onfocus(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn oncancel(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_oncancel(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn onauxclick(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_onauxclick(&self, value: Option<&Function>)

Source

impl SvgElement

Source

impl SvgElement

pub fn set_onbeforetoggle(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn oncanplay(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_oncanplay(&self, value: Option<&Function>)

Source

impl SvgElement

Source

impl SvgElement

Source

impl SvgElement

pub fn onchange(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_onchange(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn onclick(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_onclick(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn onclose(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_onclose(&self, value: Option<&Function>)

Source

impl SvgElement

Source

impl SvgElement

pub fn set_oncontextmenu(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn ondblclick(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_ondblclick(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn ondrag(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_ondrag(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn ondragend(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_ondragend(&self, value: Option<&Function>)

Source

impl SvgElement

Source

impl SvgElement

pub fn set_ondragenter(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn ondragexit(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_ondragexit(&self, value: Option<&Function>)

Source

impl SvgElement

Source

impl SvgElement

pub fn set_ondragleave(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn ondragover(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_ondragover(&self, value: Option<&Function>)

Source

impl SvgElement

Source

impl SvgElement

pub fn set_ondragstart(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn ondrop(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_ondrop(&self, value: Option<&Function>)

Source

impl SvgElement

Source

impl SvgElement

Source

impl SvgElement

pub fn onemptied(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_onemptied(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn onended(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_onended(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn oninput(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_oninput(&self, value: Option<&Function>)

Source

impl SvgElement

Source

impl SvgElement

pub fn set_onbeforeinput(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn oninvalid(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_oninvalid(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn onkeydown(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_onkeydown(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn onkeypress(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_onkeypress(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn onkeyup(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_onkeyup(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn onload(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_onload(&self, value: Option<&Function>)

Source

impl SvgElement

Source

impl SvgElement

pub fn set_onloadeddata(&self, value: Option<&Function>)

Source

impl SvgElement

Source

impl SvgElement

Source

impl SvgElement

pub fn onloadend(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_onloadend(&self, value: Option<&Function>)

Source

impl SvgElement

Source

impl SvgElement

pub fn set_onloadstart(&self, value: Option<&Function>)

Source

impl SvgElement

Source

impl SvgElement

pub fn set_onmousedown(&self, value: Option<&Function>)

Source

impl SvgElement

Source

impl SvgElement

pub fn set_onmouseenter(&self, value: Option<&Function>)

Source

impl SvgElement

Source

impl SvgElement

pub fn set_onmouseleave(&self, value: Option<&Function>)

Source

impl SvgElement

Source

impl SvgElement

pub fn set_onmousemove(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn onmouseout(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_onmouseout(&self, value: Option<&Function>)

Source

impl SvgElement

Source

impl SvgElement

pub fn set_onmouseover(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn onmouseup(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_onmouseup(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn onwheel(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_onwheel(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn onpause(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_onpause(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn onplay(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_onplay(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn onplaying(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_onplaying(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn onprogress(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_onprogress(&self, value: Option<&Function>)

Source

impl SvgElement

Source

impl SvgElement

pub fn set_onratechange(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn onreset(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_onreset(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn onresize(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_onresize(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn onscroll(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_onscroll(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn onseeked(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_onseeked(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn onseeking(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_onseeking(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn onselect(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_onselect(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn onshow(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_onshow(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn onstalled(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_onstalled(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn onsubmit(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_onsubmit(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn onsuspend(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_onsuspend(&self, value: Option<&Function>)

Source

impl SvgElement

Source

impl SvgElement

pub fn set_ontimeupdate(&self, value: Option<&Function>)

Source

impl SvgElement

Source

impl SvgElement

pub fn set_onvolumechange(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn onwaiting(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_onwaiting(&self, value: Option<&Function>)

Source

impl SvgElement

Source

impl SvgElement

pub fn set_onselectstart(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn ontoggle(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_ontoggle(&self, value: Option<&Function>)

Source

impl SvgElement

Source

impl SvgElement

pub fn set_onpointercancel(&self, value: Option<&Function>)

Source

impl SvgElement

Source

impl SvgElement

pub fn set_onpointerdown(&self, value: Option<&Function>)

Source

impl SvgElement

Source

impl SvgElement

pub fn set_onpointerup(&self, value: Option<&Function>)

Source

impl SvgElement

Source

impl SvgElement

pub fn set_onpointermove(&self, value: Option<&Function>)

Source

impl SvgElement

Source

impl SvgElement

pub fn set_onpointerout(&self, value: Option<&Function>)

Source

impl SvgElement

Source

impl SvgElement

pub fn set_onpointerover(&self, value: Option<&Function>)

Source

impl SvgElement

Source

impl SvgElement

pub fn set_onpointerenter(&self, value: Option<&Function>)

Source

impl SvgElement

Source

impl SvgElement

pub fn set_onpointerleave(&self, value: Option<&Function>)

Source

impl SvgElement

Source

impl SvgElement

Source

impl SvgElement

Source

impl SvgElement

Source

impl SvgElement

Source

impl SvgElement

Source

impl SvgElement

Source

impl SvgElement

pub fn set_onanimationend(&self, value: Option<&Function>)

Source

impl SvgElement

Source

impl SvgElement

Source

impl SvgElement

Source

impl SvgElement

Source

impl SvgElement

Source

impl SvgElement

Source

impl SvgElement

Source

impl SvgElement

pub fn set_ontransitionend(&self, value: Option<&Function>)

Source

impl SvgElement

Source

impl SvgElement

pub fn set_ontransitionrun(&self, value: Option<&Function>)

Source

impl SvgElement

Source

impl SvgElement

Source

impl SvgElement

Source

impl SvgElement

Source

impl SvgElement

Source

impl SvgElement

Source

impl SvgElement

Source

impl SvgElement

Source

impl SvgElement

Source

impl SvgElement

Source

impl SvgElement

pub fn dataset(&self) -> DomStringMap

Source

impl SvgElement

pub fn nonce(&self) -> String

Source

impl SvgElement

pub fn set_nonce(&self, value: &str)

Source

impl SvgElement

pub fn autofocus(&self) -> bool

Source

impl SvgElement

pub fn set_autofocus(&self, value: bool) -> Result<(), JsValue>

Source

impl SvgElement

pub fn tab_index(&self) -> i32

Source

impl SvgElement

pub fn set_tab_index(&self, value: i32)

Source

impl SvgElement

pub fn onerror(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_onerror(&self, value: Option<&Function>)

Source

impl SvgElement

Source

impl SvgElement

pub fn set_ontouchstart(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn ontouchend(&self) -> Option<Function>

Source

impl SvgElement

pub fn set_ontouchend(&self, value: Option<&Function>)

Source

impl SvgElement

Source

impl SvgElement

pub fn set_ontouchmove(&self, value: Option<&Function>)

Source

impl SvgElement

Source

impl SvgElement

pub fn set_ontouchcancel(&self, value: Option<&Function>)

Source

impl SvgElement

pub fn blur(&self) -> Result<(), JsValue>

Source

impl SvgElement

pub fn focus(&self) -> Result<(), JsValue>

Source

impl SvgElement

pub fn focus_with_options(&self, options: &FocusOptions) -> Result<(), JsValue>

Methods from Deref<Target = Element>

pub fn namespace_uri(&self) -> Option<String>

pub fn prefix(&self) -> Option<String>

pub fn local_name(&self) -> String

pub fn tag_name(&self) -> String

pub fn id(&self) -> String

pub fn set_id(&self, value: &str)

pub fn class_name(&self) -> String

pub fn set_class_name(&self, value: &str)

pub fn class_list(&self) -> DomTokenList

pub fn attributes(&self) -> NamedNodeMap

pub fn scroll_width(&self) -> i32

pub fn scroll_height(&self) -> i32

pub fn client_top(&self) -> i32

pub fn client_left(&self) -> i32

pub fn client_width(&self) -> i32

pub fn client_height(&self) -> i32

pub fn inner_html(&self) -> String

pub fn set_inner_html(&self, value: &str)

pub fn outer_html(&self) -> String

pub fn set_outer_html(&self, value: &str)

pub fn shadow_root(&self) -> Option<ShadowRoot>

pub fn slot(&self) -> String

pub fn set_slot(&self, value: &str)

pub fn scroll_top(&self) -> f64

pub fn set_scroll_top(&self, value: f64)

pub fn scroll_left(&self) -> f64

pub fn set_scroll_left(&self, value: f64)

pub fn previous_element_sibling(&self) -> Option<Element>

pub fn next_element_sibling(&self) -> Option<Element>

pub fn children(&self) -> HtmlCollection

pub fn first_element_child(&self) -> Option<Element>

pub fn last_element_child(&self) -> Option<Element>

pub fn child_element_count(&self) -> u32

pub fn attach_shadow( &self, shadow_root_init_dict: &ShadowRootInit, ) -> Result<ShadowRoot, JsValue>

pub fn closest(&self, selector: &str) -> Result<Option<Element>, JsValue>

pub fn get_attribute(&self, name: &str) -> Option<String>

pub fn get_attribute_ns( &self, namespace: Option<&str>, local_name: &str, ) -> Option<String>

pub fn get_attribute_names(&self) -> Array

pub fn get_attribute_node(&self, name: &str) -> Option<Attr>

pub fn get_attribute_node_ns( &self, namespace_uri: Option<&str>, local_name: &str, ) -> Option<Attr>

pub fn get_bounding_client_rect(&self) -> DomRect

pub fn get_elements_by_class_name(&self, class_names: &str) -> HtmlCollection

pub fn get_elements_by_tag_name(&self, local_name: &str) -> HtmlCollection

pub fn get_elements_by_tag_name_ns( &self, namespace: Option<&str>, local_name: &str, ) -> Result<HtmlCollection, JsValue>

pub fn has_attribute(&self, name: &str) -> bool

pub fn has_attribute_ns( &self, namespace: Option<&str>, local_name: &str, ) -> bool

pub fn has_attributes(&self) -> bool

pub fn has_pointer_capture(&self, pointer_id: i32) -> bool

pub fn insert_adjacent_element( &self, where_: &str, element: &Element, ) -> Result<Option<Element>, JsValue>

pub fn insert_adjacent_html( &self, position: &str, text: &str, ) -> Result<(), JsValue>

pub fn insert_adjacent_text( &self, where_: &str, data: &str, ) -> Result<(), JsValue>

pub fn matches(&self, selector: &str) -> Result<bool, JsValue>

pub fn query_selector( &self, selectors: &str, ) -> Result<Option<Element>, JsValue>

pub fn query_selector_all(&self, selectors: &str) -> Result<NodeList, JsValue>

pub fn release_capture(&self)

pub fn release_pointer_capture(&self, pointer_id: i32) -> Result<(), JsValue>

pub fn remove_attribute(&self, name: &str) -> Result<(), JsValue>

pub fn remove_attribute_ns( &self, namespace: Option<&str>, local_name: &str, ) -> Result<(), JsValue>

pub fn remove_attribute_node( &self, old_attr: &Attr, ) -> Result<Option<Attr>, JsValue>

pub fn request_fullscreen(&self) -> Result<(), JsValue>

pub fn request_pointer_lock(&self)

pub fn scroll_with_x_and_y(&self, x: f64, y: f64)

pub fn scroll(&self)

pub fn scroll_with_scroll_to_options(&self, options: &ScrollToOptions)

pub fn scroll_by_with_x_and_y(&self, x: f64, y: f64)

pub fn scroll_by(&self)

pub fn scroll_by_with_scroll_to_options(&self, options: &ScrollToOptions)

pub fn scroll_into_view(&self)

pub fn scroll_into_view_with_bool(&self, arg: bool)

pub fn scroll_into_view_with_scroll_into_view_options( &self, arg: &ScrollIntoViewOptions, )

pub fn scroll_to_with_x_and_y(&self, x: f64, y: f64)

pub fn scroll_to(&self)

pub fn scroll_to_with_scroll_to_options(&self, options: &ScrollToOptions)

pub fn set_attribute(&self, name: &str, value: &str) -> Result<(), JsValue>

pub fn set_attribute_ns( &self, namespace: Option<&str>, name: &str, value: &str, ) -> Result<(), JsValue>

pub fn set_attribute_node( &self, new_attr: &Attr, ) -> Result<Option<Attr>, JsValue>

pub fn set_attribute_node_ns( &self, new_attr: &Attr, ) -> Result<Option<Attr>, JsValue>

pub fn set_capture(&self)

pub fn set_capture_with_retarget_to_element(&self, retarget_to_element: bool)

pub fn set_pointer_capture(&self, pointer_id: i32) -> Result<(), JsValue>

pub fn toggle_attribute(&self, name: &str) -> Result<bool, JsValue>

pub fn toggle_attribute_with_force( &self, name: &str, force: bool, ) -> Result<bool, JsValue>

pub fn webkit_matches_selector(&self, selector: &str) -> Result<bool, JsValue>

pub fn animate(&self, keyframes: Option<&Object>) -> Animation

pub fn animate_with_f64( &self, keyframes: Option<&Object>, options: f64, ) -> Animation

pub fn get_animations(&self) -> Array<Animation>

pub fn after_with_node(&self, nodes: &Array) -> Result<(), JsValue>

pub fn after_with_node_0(&self) -> Result<(), JsValue>

pub fn after_with_node_1(&self, nodes_1: &Node) -> Result<(), JsValue>

pub fn after_with_node_2( &self, nodes_1: &Node, nodes_2: &Node, ) -> Result<(), JsValue>

pub fn after_with_node_3( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, ) -> Result<(), JsValue>

pub fn after_with_node_4( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, ) -> Result<(), JsValue>

pub fn after_with_node_5( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, ) -> Result<(), JsValue>

pub fn after_with_node_6( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, nodes_6: &Node, ) -> Result<(), JsValue>

pub fn after_with_node_7( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, nodes_6: &Node, nodes_7: &Node, ) -> Result<(), JsValue>

pub fn after_with_str(&self, nodes: &Array) -> Result<(), JsValue>

pub fn after_with_str_0(&self) -> Result<(), JsValue>

pub fn after_with_str_1(&self, nodes_1: &str) -> Result<(), JsValue>

pub fn after_with_str_2( &self, nodes_1: &str, nodes_2: &str, ) -> Result<(), JsValue>

pub fn after_with_str_3( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, ) -> Result<(), JsValue>

pub fn after_with_str_4( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, ) -> Result<(), JsValue>

pub fn after_with_str_5( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, ) -> Result<(), JsValue>

pub fn after_with_str_6( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, nodes_6: &str, ) -> Result<(), JsValue>

pub fn after_with_str_7( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, nodes_6: &str, nodes_7: &str, ) -> Result<(), JsValue>

pub fn before_with_node(&self, nodes: &Array) -> Result<(), JsValue>

pub fn before_with_node_0(&self) -> Result<(), JsValue>

pub fn before_with_node_1(&self, nodes_1: &Node) -> Result<(), JsValue>

pub fn before_with_node_2( &self, nodes_1: &Node, nodes_2: &Node, ) -> Result<(), JsValue>

pub fn before_with_node_3( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, ) -> Result<(), JsValue>

pub fn before_with_node_4( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, ) -> Result<(), JsValue>

pub fn before_with_node_5( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, ) -> Result<(), JsValue>

pub fn before_with_node_6( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, nodes_6: &Node, ) -> Result<(), JsValue>

pub fn before_with_node_7( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, nodes_6: &Node, nodes_7: &Node, ) -> Result<(), JsValue>

pub fn before_with_str(&self, nodes: &Array) -> Result<(), JsValue>

pub fn before_with_str_0(&self) -> Result<(), JsValue>

pub fn before_with_str_1(&self, nodes_1: &str) -> Result<(), JsValue>

pub fn before_with_str_2( &self, nodes_1: &str, nodes_2: &str, ) -> Result<(), JsValue>

pub fn before_with_str_3( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, ) -> Result<(), JsValue>

pub fn before_with_str_4( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, ) -> Result<(), JsValue>

pub fn before_with_str_5( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, ) -> Result<(), JsValue>

pub fn before_with_str_6( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, nodes_6: &str, ) -> Result<(), JsValue>

pub fn before_with_str_7( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, nodes_6: &str, nodes_7: &str, ) -> Result<(), JsValue>

pub fn remove(&self)

pub fn replace_with_with_node(&self, nodes: &Array) -> Result<(), JsValue>

pub fn replace_with_with_node_0(&self) -> Result<(), JsValue>

pub fn replace_with_with_node_1(&self, nodes_1: &Node) -> Result<(), JsValue>

pub fn replace_with_with_node_2( &self, nodes_1: &Node, nodes_2: &Node, ) -> Result<(), JsValue>

pub fn replace_with_with_node_3( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, ) -> Result<(), JsValue>

pub fn replace_with_with_node_4( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, ) -> Result<(), JsValue>

pub fn replace_with_with_node_5( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, ) -> Result<(), JsValue>

pub fn replace_with_with_node_6( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, nodes_6: &Node, ) -> Result<(), JsValue>

pub fn replace_with_with_node_7( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, nodes_6: &Node, nodes_7: &Node, ) -> Result<(), JsValue>

pub fn replace_with_with_str(&self, nodes: &Array) -> Result<(), JsValue>

pub fn replace_with_with_str_0(&self) -> Result<(), JsValue>

pub fn replace_with_with_str_1(&self, nodes_1: &str) -> Result<(), JsValue>

pub fn replace_with_with_str_2( &self, nodes_1: &str, nodes_2: &str, ) -> Result<(), JsValue>

pub fn replace_with_with_str_3( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, ) -> Result<(), JsValue>

pub fn replace_with_with_str_4( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, ) -> Result<(), JsValue>

pub fn replace_with_with_str_5( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, ) -> Result<(), JsValue>

pub fn replace_with_with_str_6( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, nodes_6: &str, ) -> Result<(), JsValue>

pub fn replace_with_with_str_7( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, nodes_6: &str, nodes_7: &str, ) -> Result<(), JsValue>

pub fn get_box_quads(&self) -> Result<Array, JsValue>

pub fn append_with_node(&self, nodes: &Array) -> Result<(), JsValue>

pub fn append_with_node_0(&self) -> Result<(), JsValue>

pub fn append_with_node_1(&self, nodes_1: &Node) -> Result<(), JsValue>

pub fn append_with_node_2( &self, nodes_1: &Node, nodes_2: &Node, ) -> Result<(), JsValue>

pub fn append_with_node_3( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, ) -> Result<(), JsValue>

pub fn append_with_node_4( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, ) -> Result<(), JsValue>

pub fn append_with_node_5( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, ) -> Result<(), JsValue>

pub fn append_with_node_6( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, nodes_6: &Node, ) -> Result<(), JsValue>

pub fn append_with_node_7( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, nodes_6: &Node, nodes_7: &Node, ) -> Result<(), JsValue>

pub fn append_with_str(&self, nodes: &Array) -> Result<(), JsValue>

pub fn append_with_str_0(&self) -> Result<(), JsValue>

pub fn append_with_str_1(&self, nodes_1: &str) -> Result<(), JsValue>

pub fn append_with_str_2( &self, nodes_1: &str, nodes_2: &str, ) -> Result<(), JsValue>

pub fn append_with_str_3( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, ) -> Result<(), JsValue>

pub fn append_with_str_4( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, ) -> Result<(), JsValue>

pub fn append_with_str_5( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, ) -> Result<(), JsValue>

pub fn append_with_str_6( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, nodes_6: &str, ) -> Result<(), JsValue>

pub fn append_with_str_7( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, nodes_6: &str, nodes_7: &str, ) -> Result<(), JsValue>

pub fn prepend_with_node(&self, nodes: &Array) -> Result<(), JsValue>

pub fn prepend_with_node_0(&self) -> Result<(), JsValue>

pub fn prepend_with_node_1(&self, nodes_1: &Node) -> Result<(), JsValue>

pub fn prepend_with_node_2( &self, nodes_1: &Node, nodes_2: &Node, ) -> Result<(), JsValue>

pub fn prepend_with_node_3( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, ) -> Result<(), JsValue>

pub fn prepend_with_node_4( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, ) -> Result<(), JsValue>

pub fn prepend_with_node_5( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, ) -> Result<(), JsValue>

pub fn prepend_with_node_6( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, nodes_6: &Node, ) -> Result<(), JsValue>

pub fn prepend_with_node_7( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, nodes_6: &Node, nodes_7: &Node, ) -> Result<(), JsValue>

pub fn prepend_with_str(&self, nodes: &Array) -> Result<(), JsValue>

pub fn prepend_with_str_0(&self) -> Result<(), JsValue>

pub fn prepend_with_str_1(&self, nodes_1: &str) -> Result<(), JsValue>

pub fn prepend_with_str_2( &self, nodes_1: &str, nodes_2: &str, ) -> Result<(), JsValue>

pub fn prepend_with_str_3( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, ) -> Result<(), JsValue>

pub fn prepend_with_str_4( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, ) -> Result<(), JsValue>

pub fn prepend_with_str_5( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, ) -> Result<(), JsValue>

pub fn prepend_with_str_6( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, nodes_6: &str, ) -> Result<(), JsValue>

pub fn prepend_with_str_7( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, nodes_6: &str, nodes_7: &str, ) -> Result<(), JsValue>

pub fn replace_children_with_node(&self, nodes: &Array)

pub fn replace_children_with_node_0(&self)

pub fn replace_children_with_node_1(&self, nodes_1: &Node)

pub fn replace_children_with_node_2(&self, nodes_1: &Node, nodes_2: &Node)

pub fn replace_children_with_node_3( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, )

pub fn replace_children_with_node_4( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, )

pub fn replace_children_with_node_5( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, )

pub fn replace_children_with_node_6( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, nodes_6: &Node, )

pub fn replace_children_with_node_7( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, nodes_6: &Node, nodes_7: &Node, )

pub fn replace_children_with_str(&self, nodes: &Array)

pub fn replace_children_with_str_0(&self)

pub fn replace_children_with_str_1(&self, nodes_1: &str)

pub fn replace_children_with_str_2(&self, nodes_1: &str, nodes_2: &str)

pub fn replace_children_with_str_3( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, )

pub fn replace_children_with_str_4( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, )

pub fn replace_children_with_str_5( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, )

pub fn replace_children_with_str_6( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, nodes_6: &str, )

pub fn replace_children_with_str_7( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, nodes_6: &str, nodes_7: &str, )

Methods from Deref<Target = Node>

pub fn node_type(&self) -> u16

pub fn node_name(&self) -> String

pub fn base_uri(&self) -> Result<Option<String>, JsValue>

pub fn is_connected(&self) -> bool

pub fn owner_document(&self) -> Option<Document>

pub fn parent_node(&self) -> Option<Node>

pub fn parent_element(&self) -> Option<Element>

pub fn child_nodes(&self) -> NodeList

pub fn first_child(&self) -> Option<Node>

pub fn last_child(&self) -> Option<Node>

pub fn previous_sibling(&self) -> Option<Node>

pub fn next_sibling(&self) -> Option<Node>

pub fn node_value(&self) -> Option<String>

pub fn set_node_value(&self, value: Option<&str>)

pub fn text_content(&self) -> Option<String>

pub fn set_text_content(&self, value: Option<&str>)

pub fn append_child(&self, node: &Node) -> Result<Node, JsValue>

pub fn clone_node(&self) -> Result<Node, JsValue>

pub fn clone_node_with_deep(&self, deep: bool) -> Result<Node, JsValue>

pub fn compare_document_position(&self, other: &Node) -> u16

pub fn contains(&self, other: Option<&Node>) -> bool

pub fn get_root_node(&self) -> Node

pub fn has_child_nodes(&self) -> bool

pub fn insert_before( &self, node: &Node, child: Option<&Node>, ) -> Result<Node, JsValue>

pub fn is_default_namespace(&self, namespace: Option<&str>) -> bool

pub fn is_equal_node(&self, node: Option<&Node>) -> bool

pub fn is_same_node(&self, node: Option<&Node>) -> bool

pub fn lookup_namespace_uri(&self, prefix: Option<&str>) -> Option<String>

pub fn lookup_prefix(&self, namespace: Option<&str>) -> Option<String>

pub fn normalize(&self)

pub fn remove_child(&self, child: &Node) -> Result<Node, JsValue>

pub fn replace_child(&self, node: &Node, child: &Node) -> Result<Node, JsValue>

pub const ELEMENT_NODE: u16

pub const ATTRIBUTE_NODE: u16

pub const TEXT_NODE: u16

pub const CDATA_SECTION_NODE: u16

pub const ENTITY_REFERENCE_NODE: u16

pub const ENTITY_NODE: u16

pub const PROCESSING_INSTRUCTION_NODE: u16

pub const COMMENT_NODE: u16

pub const DOCUMENT_NODE: u16

pub const DOCUMENT_TYPE_NODE: u16

pub const DOCUMENT_FRAGMENT_NODE: u16

pub const NOTATION_NODE: u16

pub const DOCUMENT_POSITION_DISCONNECTED: u16

pub const DOCUMENT_POSITION_PRECEDING: u16

pub const DOCUMENT_POSITION_FOLLOWING: u16

pub const DOCUMENT_POSITION_CONTAINS: u16

pub const DOCUMENT_POSITION_CONTAINED_BY: u16

pub const DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC: u16

Methods from Deref<Target = EventTarget>

pub fn add_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>

pub fn add_event_listener_with_event_listener( &self, type_: &str, listener: &EventListener, ) -> Result<(), JsValue>

pub fn add_event_listener_with_callback_and_add_event_listener_options( &self, type_: &str, listener: &Function, options: &AddEventListenerOptions, ) -> Result<(), JsValue>

pub fn add_event_listener_with_event_listener_and_add_event_listener_options( &self, type_: &str, listener: &EventListener, options: &AddEventListenerOptions, ) -> Result<(), JsValue>

pub fn add_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>

pub fn add_event_listener_with_event_listener_and_bool( &self, type_: &str, listener: &EventListener, options: bool, ) -> Result<(), JsValue>

pub fn add_event_listener_with_callback_and_add_event_listener_options_and_wants_untrusted( &self, type_: &str, listener: &Function, options: &AddEventListenerOptions, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>

pub fn add_event_listener_with_event_listener_and_add_event_listener_options_and_wants_untrusted( &self, type_: &str, listener: &EventListener, options: &AddEventListenerOptions, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>

pub fn add_event_listener_with_callback_and_bool_and_wants_untrusted( &self, type_: &str, listener: &Function, options: bool, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>

pub fn add_event_listener_with_event_listener_and_bool_and_wants_untrusted( &self, type_: &str, listener: &EventListener, options: bool, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>

pub fn dispatch_event(&self, event: &Event) -> Result<bool, JsValue>

pub fn remove_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>

pub fn remove_event_listener_with_event_listener( &self, type_: &str, listener: &EventListener, ) -> Result<(), JsValue>

pub fn remove_event_listener_with_callback_and_event_listener_options( &self, type_: &str, listener: &Function, options: &EventListenerOptions, ) -> Result<(), JsValue>

pub fn remove_event_listener_with_event_listener_and_event_listener_options( &self, type_: &str, listener: &EventListener, options: &EventListenerOptions, ) -> Result<(), JsValue>

pub fn remove_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>

pub fn remove_event_listener_with_event_listener_and_bool( &self, type_: &str, listener: &EventListener, options: bool, ) -> Result<(), JsValue>

Methods from Deref<Target = Object>

pub fn constructor(&self) -> Function

pub fn has_own_property(&self, property: &JsValue) -> bool

👎Deprecated:

Use Object::hasOwn instead.

pub fn is_prototype_of(&self, value: &JsValue) -> bool

pub fn property_is_enumerable(&self, property: &JsValue) -> bool

pub fn to_locale_string(&self) -> JsString

pub fn to_string(&self) -> JsString

pub fn to_js_string(&self) -> JsString

pub fn value_of(&self) -> Object

Methods from Deref<Target = JsValue>

pub const NULL: JsValue

pub const UNDEFINED: JsValue

pub const TRUE: JsValue

pub const FALSE: JsValue

pub fn unchecked_into_f64(&self) -> f64

Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.

pub fn has_type<T>(&self) -> bool
where T: JsCast,

Check if this value is an instance of a specific JS type.

pub fn checked_div(&self, rhs: &JsValue) -> JsValue

Checked division.

pub fn pow(&self, rhs: &JsValue) -> JsValue

Power operation.

pub fn bit_and(&self, rhs: &JsValue) -> JsValue

Bitwise AND.

pub fn bit_or(&self, rhs: &JsValue) -> JsValue

Bitwise OR.

pub fn bit_xor(&self, rhs: &JsValue) -> JsValue

Bitwise XOR.

pub fn bit_not(&self) -> JsValue

Bitwise NOT.

pub fn shl(&self, rhs: &JsValue) -> JsValue

Left shift.

pub fn shr(&self, rhs: &JsValue) -> JsValue

Signed right shift.

pub fn unsigned_shr(&self, rhs: &JsValue) -> u32

Unsigned right shift.

pub fn add(&self, rhs: &JsValue) -> JsValue

Add.

pub fn sub(&self, rhs: &JsValue) -> JsValue

Subtract.

pub fn mul(&self, rhs: &JsValue) -> JsValue

Multiply.

pub fn div(&self, rhs: &JsValue) -> JsValue

Divide.

pub fn rem(&self, rhs: &JsValue) -> JsValue

Remainder.

pub fn neg(&self) -> JsValue

Negate.

pub fn lt(&self, other: &JsValue) -> bool

Less than comparison.

pub fn le(&self, other: &JsValue) -> bool

Less than or equal comparison.

pub fn gt(&self, other: &JsValue) -> bool

Greater than comparison.

pub fn ge(&self, other: &JsValue) -> bool

Greater than or equal comparison.

pub fn loose_eq(&self, other: &JsValue) -> bool

Loose equality (==).

pub fn is_falsy(&self) -> bool

Check if this value is a falsy value in JavaScript.

pub fn is_truthy(&self) -> bool

Check if this value is a truthy value in JavaScript.

pub fn is_object(&self) -> bool

Check if this value is an object.

pub fn is_function(&self) -> bool

Check if this value is a function.

pub fn is_string(&self) -> bool

Check if this value is a string.

pub fn is_symbol(&self) -> bool

Check if this value is a symbol.

pub fn is_bigint(&self) -> bool

Check if this value is a bigint.

pub fn is_array(&self) -> bool

Check if this value is an Array.

pub fn is_undefined(&self) -> bool

Check if this value is undefined.

pub fn is_null(&self) -> bool

Check if this value is null.

pub fn is_null_or_undefined(&self) -> bool

Check if this value is null or undefined.

pub fn js_typeof(&self) -> JsValue

Get the typeof this value as a string.

pub fn js_in(&self, obj: &JsValue) -> bool

Check if this value has a property with the given name.

pub fn as_bool(&self) -> Option<bool>

Get the value as a bool.

pub fn as_f64(&self) -> Option<f64>

Get the value as an f64.

pub fn as_string(&self) -> Option<String>

Get the value as a string.

pub fn as_debug_string(&self) -> String

Get a debug string representation of the value.