pub struct TouchEvent { /* private fields */ }Expand description
The TouchEvent class.
This API requires the following crate features to be activated: TouchEvent
Implementations
Sourceimpl TouchEvent
impl TouchEvent
pub fn target_touches(&self) -> TouchList
Sourceimpl TouchEvent
impl TouchEvent
pub fn changed_touches(&self) -> TouchList
Sourceimpl TouchEvent
impl TouchEvent
Sourceimpl TouchEvent
impl TouchEvent
pub fn init_touch_event(&self, type_: &str)
Sourceimpl TouchEvent
impl TouchEvent
pub fn init_touch_event_with_can_bubble(&self, type_: &str, can_bubble: bool)
Sourceimpl TouchEvent
impl TouchEvent
pub fn init_touch_event_with_can_bubble_and_cancelable( &self, type_: &str, can_bubble: bool, cancelable: bool, )
Sourceimpl TouchEvent
impl TouchEvent
Sourceimpl TouchEvent
impl TouchEvent
Sourceimpl TouchEvent
impl TouchEvent
Sourceimpl TouchEvent
impl TouchEvent
Sourceimpl TouchEvent
impl TouchEvent
Sourceimpl TouchEvent
impl TouchEvent
Sourceimpl TouchEvent
impl TouchEvent
pub fn init_touch_event_with_can_bubble_and_cancelable_and_view_and_detail_and_ctrl_key_and_alt_key_and_shift_key_and_meta_key_and_touches( &self, type_: &str, can_bubble: bool, cancelable: bool, view: Option<&Window>, detail: i32, ctrl_key: bool, alt_key: bool, shift_key: bool, meta_key: bool, touches: Option<&TouchList>, )
Sourceimpl TouchEvent
impl TouchEvent
pub fn init_touch_event_with_can_bubble_and_cancelable_and_view_and_detail_and_ctrl_key_and_alt_key_and_shift_key_and_meta_key_and_touches_and_target_touches( &self, type_: &str, can_bubble: bool, cancelable: bool, view: Option<&Window>, detail: i32, ctrl_key: bool, alt_key: bool, shift_key: bool, meta_key: bool, touches: Option<&TouchList>, target_touches: Option<&TouchList>, )
Sourceimpl TouchEvent
impl TouchEvent
pub fn init_touch_event_with_can_bubble_and_cancelable_and_view_and_detail_and_ctrl_key_and_alt_key_and_shift_key_and_meta_key_and_touches_and_target_touches_and_changed_touches( &self, type_: &str, can_bubble: bool, cancelable: bool, view: Option<&Window>, detail: i32, ctrl_key: bool, alt_key: bool, shift_key: bool, meta_key: bool, touches: Option<&TouchList>, target_touches: Option<&TouchList>, changed_touches: Option<&TouchList>, )
Methods from Deref<Target = UiEvent>
pub fn view(&self) -> Option<Window>
pub fn detail(&self) -> i32
pub fn layer_x(&self) -> i32
pub fn layer_y(&self) -> i32
pub fn page_x(&self) -> i32
pub fn page_y(&self) -> i32
pub fn which(&self) -> u32
pub fn range_parent(&self) -> Option<Node>
pub fn range_offset(&self) -> i32
pub fn init_ui_event(&self, a_type: &str)
pub fn init_ui_event_with_a_can_bubble(&self, a_type: &str, a_can_bubble: bool)
pub fn init_ui_event_with_a_can_bubble_and_a_cancelable( &self, a_type: &str, a_can_bubble: bool, a_cancelable: bool, )
pub fn init_ui_event_with_a_can_bubble_and_a_cancelable_and_a_view( &self, a_type: &str, a_can_bubble: bool, a_cancelable: bool, a_view: Option<&Window>, )
pub fn init_ui_event_with_a_can_bubble_and_a_cancelable_and_a_view_and_a_detail( &self, a_type: &str, a_can_bubble: bool, a_cancelable: bool, a_view: Option<&Window>, a_detail: i32, )
pub const SCROLL_PAGE_UP: i32
pub const SCROLL_PAGE_DOWN: i32
Methods from Deref<Target = Event>
pub fn type_(&self) -> String
pub fn target(&self) -> Option<EventTarget>
pub fn current_target(&self) -> Option<EventTarget>
pub fn event_phase(&self) -> u16
pub fn bubbles(&self) -> bool
pub fn cancelable(&self) -> bool
pub fn default_prevented(&self) -> bool
pub fn composed(&self) -> bool
pub fn is_trusted(&self) -> bool
pub fn time_stamp(&self) -> f64
pub fn cancel_bubble(&self) -> bool
pub fn set_cancel_bubble(&self, value: bool)
pub fn composed_path(&self) -> Array
pub fn init_event(&self, type_: &str)
pub fn init_event_with_bubbles(&self, type_: &str, bubbles: bool)
pub fn init_event_with_bubbles_and_cancelable( &self, type_: &str, bubbles: bool, cancelable: bool, )
pub fn prevent_default(&self)
pub fn stop_immediate_propagation(&self)
pub fn stop_propagation(&self)
pub const NONE: u16
pub const CAPTURING_PHASE: u16
pub const AT_TARGET: u16
pub const BUBBLING_PHASE: u16
Methods from Deref<Target = Object>
pub fn constructor(&self) -> Function
pub fn has_own_property(&self, property: &JsValue) -> bool
👎Deprecated:
Use Object::hasOwn instead.
pub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn to_locale_string(&self) -> JsString
pub fn to_string(&self) -> JsString
pub fn to_js_string(&self) -> JsString
pub fn value_of(&self) -> Object
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Check if this value is null or undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.