pub struct WebGlContextAttributes { /* private fields */ }Expand description
The WebGlContextAttributes dictionary.
This API requires the following crate features to be activated: WebGlContextAttributes
Implementations
Sourceimpl WebGlContextAttributes
impl WebGlContextAttributes
pub fn get_antialias(&self) -> Option<bool>
Sourceimpl WebGlContextAttributes
impl WebGlContextAttributes
pub fn set_antialias(&self, val: bool)
Sourceimpl WebGlContextAttributes
impl WebGlContextAttributes
pub fn get_fail_if_major_performance_caveat(&self) -> Option<bool>
Sourceimpl WebGlContextAttributes
impl WebGlContextAttributes
pub fn set_fail_if_major_performance_caveat(&self, val: bool)
Sourceimpl WebGlContextAttributes
impl WebGlContextAttributes
pub fn get_premultiplied_alpha(&self) -> Option<bool>
Sourceimpl WebGlContextAttributes
impl WebGlContextAttributes
pub fn set_premultiplied_alpha(&self, val: bool)
Sourceimpl WebGlContextAttributes
impl WebGlContextAttributes
pub fn get_preserve_drawing_buffer(&self) -> Option<bool>
Sourceimpl WebGlContextAttributes
impl WebGlContextAttributes
pub fn set_preserve_drawing_buffer(&self, val: bool)
Sourceimpl WebGlContextAttributes
impl WebGlContextAttributes
pub fn get_stencil(&self) -> Option<bool>
Sourceimpl WebGlContextAttributes
impl WebGlContextAttributes
pub fn set_stencil(&self, val: bool)
Sourceimpl WebGlContextAttributes
impl WebGlContextAttributes
pub fn get_xr_compatible(&self) -> Option<bool>
Sourceimpl WebGlContextAttributes
impl WebGlContextAttributes
pub fn set_xr_compatible(&self, val: bool)
Sourceimpl WebGlContextAttributes
impl WebGlContextAttributes
Sourcepub fn new() -> Self
pub fn new() -> Self
Construct a new WebGlContextAttributes.
This API requires the following crate features to be activated: WebGlContextAttributes
pub fn alpha(&mut self, val: bool) -> &mut Self
Use set_alpha() instead.
pub fn antialias(&mut self, val: bool) -> &mut Self
Use set_antialias() instead.
pub fn depth(&mut self, val: bool) -> &mut Self
Use set_depth() instead.
pub fn fail_if_major_performance_caveat(&mut self, val: bool) -> &mut Self
Use set_fail_if_major_performance_caveat() instead.
pub fn premultiplied_alpha(&mut self, val: bool) -> &mut Self
Use set_premultiplied_alpha() instead.
pub fn preserve_drawing_buffer(&mut self, val: bool) -> &mut Self
Use set_preserve_drawing_buffer() instead.
pub fn stencil(&mut self, val: bool) -> &mut Self
Use set_stencil() instead.
pub fn xr_compatible(&mut self, val: bool) -> &mut Self
Use set_xr_compatible() instead.
Methods from Deref<Target = Object>
pub fn constructor(&self) -> Function
pub fn has_own_property(&self, property: &JsValue) -> bool
Use Object::hasOwn instead.
pub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn to_locale_string(&self) -> JsString
pub fn to_string(&self) -> JsString
pub fn to_js_string(&self) -> JsString
pub fn value_of(&self) -> Object
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Check if this value is null or undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.