pub struct WorkerGlobalScope { /* private fields */ }Expand description
The WorkerGlobalScope class.
This API requires the following crate features to be activated: WorkerGlobalScope
Implementations
Sourceimpl WorkerGlobalScope
impl WorkerGlobalScope
pub fn self_(&self) -> WorkerGlobalScope
Sourceimpl WorkerGlobalScope
impl WorkerGlobalScope
pub fn location(&self) -> WorkerLocation
Sourceimpl WorkerGlobalScope
impl WorkerGlobalScope
pub fn set_onerror(&self, value: Option<&Function>)
Sourceimpl WorkerGlobalScope
impl WorkerGlobalScope
pub fn set_onoffline(&self, value: Option<&Function>)
Sourceimpl WorkerGlobalScope
impl WorkerGlobalScope
pub fn set_ononline(&self, value: Option<&Function>)
Sourceimpl WorkerGlobalScope
impl WorkerGlobalScope
pub fn indexed_db(&self) -> Result<Option<IdbFactory>, JsValue>
Sourceimpl WorkerGlobalScope
impl WorkerGlobalScope
pub fn performance(&self) -> Option<Performance>
Sourceimpl WorkerGlobalScope
impl WorkerGlobalScope
pub fn is_secure_context(&self) -> bool
Sourceimpl WorkerGlobalScope
impl WorkerGlobalScope
pub fn caches(&self) -> Result<CacheStorage, JsValue>
Sourceimpl WorkerGlobalScope
impl WorkerGlobalScope
pub fn import_scripts_0(&self) -> Result<(), JsValue>
Sourceimpl WorkerGlobalScope
impl WorkerGlobalScope
pub fn clear_interval(&self)
Sourceimpl WorkerGlobalScope
impl WorkerGlobalScope
pub fn clear_interval_with_handle(&self, handle: i32)
Sourceimpl WorkerGlobalScope
impl WorkerGlobalScope
pub fn clear_timeout(&self)
Sourceimpl WorkerGlobalScope
impl WorkerGlobalScope
pub fn clear_timeout_with_handle(&self, handle: i32)
Sourceimpl WorkerGlobalScope
impl WorkerGlobalScope
pub fn create_image_bitmap_with_html_image_element( &self, a_image: &HtmlImageElement, ) -> Result<Promise, JsValue>
Sourceimpl WorkerGlobalScope
impl WorkerGlobalScope
pub fn create_image_bitmap_with_html_canvas_element( &self, a_image: &HtmlCanvasElement, ) -> Result<Promise, JsValue>
Sourceimpl WorkerGlobalScope
impl WorkerGlobalScope
pub fn create_image_bitmap_with_html_video_element( &self, a_image: &HtmlVideoElement, ) -> Result<Promise, JsValue>
Sourceimpl WorkerGlobalScope
impl WorkerGlobalScope
pub fn create_image_bitmap_with_image_bitmap( &self, a_image: &ImageBitmap, ) -> Result<Promise, JsValue>
Sourceimpl WorkerGlobalScope
impl WorkerGlobalScope
pub fn create_image_bitmap_with_offscreen_canvas( &self, a_image: &OffscreenCanvas, ) -> Result<Promise, JsValue>
Sourceimpl WorkerGlobalScope
impl WorkerGlobalScope
pub fn create_image_bitmap_with_html_image_element_and_image_bitmap_options( &self, a_image: &HtmlImageElement, a_options: &ImageBitmapOptions, ) -> Result<Promise, JsValue>
Sourceimpl WorkerGlobalScope
impl WorkerGlobalScope
pub fn create_image_bitmap_with_html_canvas_element_and_image_bitmap_options( &self, a_image: &HtmlCanvasElement, a_options: &ImageBitmapOptions, ) -> Result<Promise, JsValue>
Sourceimpl WorkerGlobalScope
impl WorkerGlobalScope
pub fn create_image_bitmap_with_html_video_element_and_image_bitmap_options( &self, a_image: &HtmlVideoElement, a_options: &ImageBitmapOptions, ) -> Result<Promise, JsValue>
Sourceimpl WorkerGlobalScope
impl WorkerGlobalScope
pub fn create_image_bitmap_with_image_bitmap_and_image_bitmap_options( &self, a_image: &ImageBitmap, a_options: &ImageBitmapOptions, ) -> Result<Promise, JsValue>
Sourceimpl WorkerGlobalScope
impl WorkerGlobalScope
pub fn create_image_bitmap_with_offscreen_canvas_and_image_bitmap_options( &self, a_image: &OffscreenCanvas, a_options: &ImageBitmapOptions, ) -> Result<Promise, JsValue>
Sourceimpl WorkerGlobalScope
impl WorkerGlobalScope
pub fn create_image_bitmap_with_blob_and_image_bitmap_options( &self, a_image: &Blob, a_options: &ImageBitmapOptions, ) -> Result<Promise, JsValue>
Sourceimpl WorkerGlobalScope
impl WorkerGlobalScope
pub fn create_image_bitmap_with_image_data_and_image_bitmap_options( &self, a_image: &ImageData, a_options: &ImageBitmapOptions, ) -> Result<Promise, JsValue>
Sourceimpl WorkerGlobalScope
impl WorkerGlobalScope
pub fn create_image_bitmap_with_html_image_element_and_a_sx_and_a_sy_and_a_sw_and_a_sh( &self, a_image: &HtmlImageElement, a_sx: i32, a_sy: i32, a_sw: i32, a_sh: i32, ) -> Result<Promise, JsValue>
Sourceimpl WorkerGlobalScope
impl WorkerGlobalScope
pub fn create_image_bitmap_with_html_canvas_element_and_a_sx_and_a_sy_and_a_sw_and_a_sh( &self, a_image: &HtmlCanvasElement, a_sx: i32, a_sy: i32, a_sw: i32, a_sh: i32, ) -> Result<Promise, JsValue>
Sourceimpl WorkerGlobalScope
impl WorkerGlobalScope
pub fn create_image_bitmap_with_html_video_element_and_a_sx_and_a_sy_and_a_sw_and_a_sh( &self, a_image: &HtmlVideoElement, a_sx: i32, a_sy: i32, a_sw: i32, a_sh: i32, ) -> Result<Promise, JsValue>
Sourceimpl WorkerGlobalScope
impl WorkerGlobalScope
pub fn create_image_bitmap_with_image_bitmap_and_a_sx_and_a_sy_and_a_sw_and_a_sh( &self, a_image: &ImageBitmap, a_sx: i32, a_sy: i32, a_sw: i32, a_sh: i32, ) -> Result<Promise, JsValue>
Sourceimpl WorkerGlobalScope
impl WorkerGlobalScope
pub fn create_image_bitmap_with_offscreen_canvas_and_a_sx_and_a_sy_and_a_sw_and_a_sh( &self, a_image: &OffscreenCanvas, a_sx: i32, a_sy: i32, a_sw: i32, a_sh: i32, ) -> Result<Promise, JsValue>
Sourceimpl WorkerGlobalScope
impl WorkerGlobalScope
pub fn create_image_bitmap_with_html_image_element_and_a_sx_and_a_sy_and_a_sw_and_a_sh_and_a_options( &self, a_image: &HtmlImageElement, a_sx: i32, a_sy: i32, a_sw: i32, a_sh: i32, a_options: &ImageBitmapOptions, ) -> Result<Promise, JsValue>
Sourceimpl WorkerGlobalScope
impl WorkerGlobalScope
pub fn create_image_bitmap_with_html_canvas_element_and_a_sx_and_a_sy_and_a_sw_and_a_sh_and_a_options( &self, a_image: &HtmlCanvasElement, a_sx: i32, a_sy: i32, a_sw: i32, a_sh: i32, a_options: &ImageBitmapOptions, ) -> Result<Promise, JsValue>
Sourceimpl WorkerGlobalScope
impl WorkerGlobalScope
pub fn create_image_bitmap_with_html_video_element_and_a_sx_and_a_sy_and_a_sw_and_a_sh_and_a_options( &self, a_image: &HtmlVideoElement, a_sx: i32, a_sy: i32, a_sw: i32, a_sh: i32, a_options: &ImageBitmapOptions, ) -> Result<Promise, JsValue>
Sourceimpl WorkerGlobalScope
impl WorkerGlobalScope
pub fn create_image_bitmap_with_image_bitmap_and_a_sx_and_a_sy_and_a_sw_and_a_sh_and_a_options( &self, a_image: &ImageBitmap, a_sx: i32, a_sy: i32, a_sw: i32, a_sh: i32, a_options: &ImageBitmapOptions, ) -> Result<Promise, JsValue>
Sourceimpl WorkerGlobalScope
impl WorkerGlobalScope
pub fn create_image_bitmap_with_offscreen_canvas_and_a_sx_and_a_sy_and_a_sw_and_a_sh_and_a_options( &self, a_image: &OffscreenCanvas, a_sx: i32, a_sy: i32, a_sw: i32, a_sh: i32, a_options: &ImageBitmapOptions, ) -> Result<Promise, JsValue>
Sourceimpl WorkerGlobalScope
impl WorkerGlobalScope
pub fn fetch_with_request(&self, input: &Request) -> Promise
Sourceimpl WorkerGlobalScope
impl WorkerGlobalScope
pub fn fetch_with_str(&self, input: &str) -> Promise
Sourceimpl WorkerGlobalScope
impl WorkerGlobalScope
pub fn fetch_with_request_and_init( &self, input: &Request, init: &RequestInit, ) -> Promise
Sourceimpl WorkerGlobalScope
impl WorkerGlobalScope
pub fn fetch_with_str_and_init( &self, input: &str, init: &RequestInit, ) -> Promise
Sourceimpl WorkerGlobalScope
impl WorkerGlobalScope
pub fn queue_microtask(&self, callback: &Function)
Methods from Deref<Target = EventTarget>
pub fn add_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener( &self, type_: &str, listener: &EventListener, ) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_add_event_listener_options( &self, type_: &str, listener: &Function, options: &AddEventListenerOptions, ) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_add_event_listener_options( &self, type_: &str, listener: &EventListener, options: &AddEventListenerOptions, ) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_bool( &self, type_: &str, listener: &EventListener, options: bool, ) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_add_event_listener_options_and_wants_untrusted( &self, type_: &str, listener: &Function, options: &AddEventListenerOptions, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_add_event_listener_options_and_wants_untrusted( &self, type_: &str, listener: &EventListener, options: &AddEventListenerOptions, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_bool_and_wants_untrusted( &self, type_: &str, listener: &Function, options: bool, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_bool_and_wants_untrusted( &self, type_: &str, listener: &EventListener, options: bool, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>
pub fn dispatch_event(&self, event: &Event) -> Result<bool, JsValue>
pub fn remove_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>
pub fn remove_event_listener_with_event_listener( &self, type_: &str, listener: &EventListener, ) -> Result<(), JsValue>
pub fn remove_event_listener_with_callback_and_event_listener_options( &self, type_: &str, listener: &Function, options: &EventListenerOptions, ) -> Result<(), JsValue>
pub fn remove_event_listener_with_event_listener_and_event_listener_options( &self, type_: &str, listener: &EventListener, options: &EventListenerOptions, ) -> Result<(), JsValue>
pub fn remove_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>
pub fn remove_event_listener_with_event_listener_and_bool( &self, type_: &str, listener: &EventListener, options: bool, ) -> Result<(), JsValue>
Methods from Deref<Target = Object>
pub fn constructor(&self) -> Function
pub fn has_own_property(&self, property: &JsValue) -> bool
👎Deprecated:
Use Object::hasOwn instead.
pub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn to_locale_string(&self) -> JsString
pub fn to_string(&self) -> JsString
pub fn to_js_string(&self) -> JsString
pub fn value_of(&self) -> Object
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Check if this value is null or undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.